package org.apache.commons.validator;

import com.vendor.xzjh.settings.util.ShellUtils;
import java.io.Serializable;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class FormSet implements Serializable {
    protected static final int COUNTRY_FORMSET = 3;
    protected static final int GLOBAL_FORMSET = 1;
    protected static final int LANGUAGE_FORMSET = 2;
    protected static final int VARIANT_FORMSET = 4;
    private static final long serialVersionUID = -8936513232763306055L;
    private final Map<String, String> constants = new HashMap();
    private String country = null;
    private final Map<String, Form> forms = new HashMap();
    private String language = null;
    private transient Log log = LogFactory.getLog(FormSet.class);
    private boolean merged;
    private boolean processed = false;
    private String variant = null;

    /* access modifiers changed from: protected */
    public boolean isMerged() {
        return this.merged;
    }

    /* access modifiers changed from: protected */
    public int getType() {
        if (getVariant() != null) {
            if (getLanguage() != null && getCountry() != null) {
                return 4;
            }
            throw new NullPointerException("When variant is specified, country and language must be specified.");
        } else if (getCountry() != null) {
            if (getLanguage() != null) {
                return 3;
            }
            throw new NullPointerException("When country is specified, language must be specified.");
        } else if (getLanguage() != null) {
            return 2;
        } else {
            return 1;
        }
    }

    /* access modifiers changed from: protected */
    public void merge(FormSet depends) {
        if (depends != null) {
            Map<String, Form> pForms = getForms();
            for (Map.Entry<String, Form> entry : depends.getForms().entrySet()) {
                Form pForm = pForms.get(entry.getKey());
                if (pForm != null) {
                    pForm.merge(entry.getValue());
                } else {
                    addForm(entry.getValue());
                }
            }
        }
        this.merged = true;
    }

    public boolean isProcessed() {
        return this.processed;
    }

    public String getLanguage() {
        return this.language;
    }

    public void setLanguage(String language2) {
        this.language = language2;
    }

    public String getCountry() {
        return this.country;
    }

    public void setCountry(String country2) {
        this.country = country2;
    }

    public String getVariant() {
        return this.variant;
    }

    public void setVariant(String variant2) {
        this.variant = variant2;
    }

    public void addConstant(String name, String value) {
        if (this.constants.containsKey(name)) {
            Log log2 = getLog();
            log2.error("Constant '" + name + "' already exists in FormSet[" + displayKey() + "] - ignoring.");
            return;
        }
        this.constants.put(name, value);
    }

    public void addForm(Form f) {
        String formName = f.getName();
        if (this.forms.containsKey(formName)) {
            Log log2 = getLog();
            log2.error("Form '" + formName + "' already exists in FormSet[" + displayKey() + "] - ignoring.");
            return;
        }
        this.forms.put(f.getName(), f);
    }

    public Form getForm(String formName) {
        return this.forms.get(formName);
    }

    public Map<String, Form> getForms() {
        return Collections.unmodifiableMap(this.forms);
    }

    /* access modifiers changed from: package-private */
    public synchronized void process(Map<String, String> globalConstants) {
        for (Form f : this.forms.values()) {
            f.process(globalConstants, this.constants, this.forms);
        }
        this.processed = true;
    }

    public String displayKey() {
        StringBuilder results = new StringBuilder();
        String str = this.language;
        if (str != null && str.length() > 0) {
            results.append("language=");
            results.append(this.language);
        }
        String str2 = this.country;
        if (str2 != null && str2.length() > 0) {
            if (results.length() > 0) {
                results.append(", ");
            }
            results.append("country=");
            results.append(this.country);
        }
        String str3 = this.variant;
        if (str3 != null && str3.length() > 0) {
            if (results.length() > 0) {
                results.append(", ");
            }
            results.append("variant=");
            results.append(this.variant);
        }
        if (results.length() == 0) {
            results.append("default");
        }
        return results.toString();
    }

    public String toString() {
        StringBuilder results = new StringBuilder();
        results.append("FormSet: language=");
        results.append(this.language);
        results.append("  country=");
        results.append(this.country);
        results.append("  variant=");
        results.append(this.variant);
        results.append(ShellUtils.COMMAND_LINE_END);
        for (Form form : getForms().values()) {
            results.append("   ");
            results.append(form);
            results.append(ShellUtils.COMMAND_LINE_END);
        }
        return results.toString();
    }

    private Log getLog() {
        if (this.log == null) {
            this.log = LogFactory.getLog(FormSet.class);
        }
        return this.log;
    }
}
