package org.apache.commons.validator;

import java.io.Serializable;
import java.text.DateFormat;
import java.text.NumberFormat;
import java.text.ParseException;
import java.text.ParsePosition;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class GenericTypeValidator implements Serializable {
    private static final Log LOG = LogFactory.getLog(GenericTypeValidator.class);
    private static final long serialVersionUID = 5487162314134261703L;

    public static Byte formatByte(String value) {
        if (value == null) {
            return null;
        }
        try {
            return Byte.valueOf(value);
        } catch (NumberFormatException e) {
            return null;
        }
    }

    public static Byte formatByte(String value, Locale locale) {
        NumberFormat formatter;
        if (value == null) {
            return null;
        }
        if (locale != null) {
            formatter = NumberFormat.getNumberInstance(locale);
        } else {
            formatter = NumberFormat.getNumberInstance(Locale.getDefault());
        }
        formatter.setParseIntegerOnly(true);
        ParsePosition pos = new ParsePosition(0);
        Number num = formatter.parse(value, pos);
        if (pos.getErrorIndex() != -1 || pos.getIndex() != value.length() || num.doubleValue() < -128.0d || num.doubleValue() > 127.0d) {
            return null;
        }
        return Byte.valueOf(num.byteValue());
    }

    public static Short formatShort(String value) {
        if (value == null) {
            return null;
        }
        try {
            return Short.valueOf(value);
        } catch (NumberFormatException e) {
            return null;
        }
    }

    public static Short formatShort(String value, Locale locale) {
        NumberFormat formatter;
        if (value == null) {
            return null;
        }
        if (locale != null) {
            formatter = NumberFormat.getNumberInstance(locale);
        } else {
            formatter = NumberFormat.getNumberInstance(Locale.getDefault());
        }
        formatter.setParseIntegerOnly(true);
        ParsePosition pos = new ParsePosition(0);
        Number num = formatter.parse(value, pos);
        if (pos.getErrorIndex() != -1 || pos.getIndex() != value.length() || num.doubleValue() < -32768.0d || num.doubleValue() > 32767.0d) {
            return null;
        }
        return Short.valueOf(num.shortValue());
    }

    public static Integer formatInt(String value) {
        if (value == null) {
            return null;
        }
        try {
            return Integer.valueOf(value);
        } catch (NumberFormatException e) {
            return null;
        }
    }

    public static Integer formatInt(String value, Locale locale) {
        NumberFormat formatter;
        if (value == null) {
            return null;
        }
        if (locale != null) {
            formatter = NumberFormat.getNumberInstance(locale);
        } else {
            formatter = NumberFormat.getNumberInstance(Locale.getDefault());
        }
        formatter.setParseIntegerOnly(true);
        ParsePosition pos = new ParsePosition(0);
        Number num = formatter.parse(value, pos);
        if (pos.getErrorIndex() != -1 || pos.getIndex() != value.length() || num.doubleValue() < -2.147483648E9d || num.doubleValue() > 2.147483647E9d) {
            return null;
        }
        return Integer.valueOf(num.intValue());
    }

    public static Long formatLong(String value) {
        if (value == null) {
            return null;
        }
        try {
            return Long.valueOf(value);
        } catch (NumberFormatException e) {
            return null;
        }
    }

    public static Long formatLong(String value, Locale locale) {
        NumberFormat formatter;
        if (value == null) {
            return null;
        }
        if (locale != null) {
            formatter = NumberFormat.getNumberInstance(locale);
        } else {
            formatter = NumberFormat.getNumberInstance(Locale.getDefault());
        }
        formatter.setParseIntegerOnly(true);
        ParsePosition pos = new ParsePosition(0);
        Number num = formatter.parse(value, pos);
        if (pos.getErrorIndex() != -1 || pos.getIndex() != value.length() || num.doubleValue() < -9.223372036854776E18d || num.doubleValue() > 9.223372036854776E18d) {
            return null;
        }
        return Long.valueOf(num.longValue());
    }

    public static Float formatFloat(String value) {
        if (value == null) {
            return null;
        }
        try {
            return Float.valueOf(value);
        } catch (NumberFormatException e) {
            return null;
        }
    }

    public static Float formatFloat(String value, Locale locale) {
        NumberFormat formatter;
        if (value == null) {
            return null;
        }
        if (locale != null) {
            formatter = NumberFormat.getInstance(locale);
        } else {
            formatter = NumberFormat.getInstance(Locale.getDefault());
        }
        ParsePosition pos = new ParsePosition(0);
        Number num = formatter.parse(value, pos);
        if (pos.getErrorIndex() != -1 || pos.getIndex() != value.length() || num.doubleValue() < -3.4028234663852886E38d || num.doubleValue() > 3.4028234663852886E38d) {
            return null;
        }
        return Float.valueOf(num.floatValue());
    }

    public static Double formatDouble(String value) {
        if (value == null) {
            return null;
        }
        try {
            return Double.valueOf(value);
        } catch (NumberFormatException e) {
            return null;
        }
    }

    public static Double formatDouble(String value, Locale locale) {
        NumberFormat formatter;
        if (value == null) {
            return null;
        }
        if (locale != null) {
            formatter = NumberFormat.getInstance(locale);
        } else {
            formatter = NumberFormat.getInstance(Locale.getDefault());
        }
        ParsePosition pos = new ParsePosition(0);
        Number num = formatter.parse(value, pos);
        if (pos.getErrorIndex() != -1 || pos.getIndex() != value.length() || num.doubleValue() < -1.7976931348623157E308d || num.doubleValue() > Double.MAX_VALUE) {
            return null;
        }
        return Double.valueOf(num.doubleValue());
    }

    public static Date formatDate(String value, Locale locale) {
        DateFormat formatterDefault;
        DateFormat formatterShort;
        if (value == null) {
            return null;
        }
        if (locale != null) {
            try {
                formatterShort = DateFormat.getDateInstance(3, locale);
                formatterDefault = DateFormat.getDateInstance(2, locale);
            } catch (ParseException e) {
                Log log = LOG;
                if (!log.isDebugEnabled()) {
                    return null;
                }
                log.debug("Date parse failed value=[" + value + "], " + "locale=[" + locale + "] " + e);
                return null;
            }
        } else {
            formatterShort = DateFormat.getDateInstance(3, Locale.getDefault());
            formatterDefault = DateFormat.getDateInstance(2, Locale.getDefault());
        }
        formatterShort.setLenient(false);
        formatterDefault.setLenient(false);
        try {
            return formatterShort.parse(value);
        } catch (ParseException e2) {
            return formatterDefault.parse(value);
        }
    }

    public static Date formatDate(String value, String datePattern, boolean strict) {
        if (value == null || datePattern == null || datePattern.length() == 0) {
            return null;
        }
        try {
            SimpleDateFormat formatter = new SimpleDateFormat(datePattern);
            formatter.setLenient(false);
            Date date = formatter.parse(value);
            if (!strict || datePattern.length() == value.length()) {
                return date;
            }
            return null;
        } catch (ParseException e) {
            Log log = LOG;
            if (!log.isDebugEnabled()) {
                return null;
            }
            log.debug("Date parse failed value=[" + value + "], " + "pattern=[" + datePattern + "], " + "strict=[" + strict + "] " + e);
            return null;
        }
    }

    public static Long formatCreditCard(String value) {
        if (GenericValidator.isCreditCard(value)) {
            return Long.valueOf(value);
        }
        return null;
    }
}
