package org.apache.commons.validator;

import com.vendor.xzjh.settings.util.ShellUtils;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Serializable;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.StringTokenizer;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.commons.validator.util.ValidatorUtils;

public class ValidatorAction implements Serializable {
    private static final long serialVersionUID = 1339713700053204597L;
    private String classname = null;
    private final List<String> dependencyList = Collections.synchronizedList(new ArrayList());
    private String depends = null;
    private Object instance = null;
    private String javascript = null;
    private String jsFunction = null;
    private String jsFunctionName = null;
    private transient Log log = LogFactory.getLog(ValidatorAction.class);
    private String method = null;
    private final List<String> methodParameterList = new ArrayList();
    private String methodParams = "java.lang.Object,org.apache.commons.validator.ValidatorAction,org.apache.commons.validator.Field";
    private String msg = null;
    private String name = null;
    private Class<?>[] parameterClasses = null;
    private Class<?> validationClass = null;
    private Method validationMethod = null;

    public String getName() {
        return this.name;
    }

    public void setName(String name2) {
        this.name = name2;
    }

    public String getClassname() {
        return this.classname;
    }

    public void setClassname(String classname2) {
        this.classname = classname2;
    }

    public String getMethod() {
        return this.method;
    }

    public void setMethod(String method2) {
        this.method = method2;
    }

    public String getMethodParams() {
        return this.methodParams;
    }

    public void setMethodParams(String methodParams2) {
        this.methodParams = methodParams2;
        this.methodParameterList.clear();
        StringTokenizer st = new StringTokenizer(methodParams2, ",");
        while (st.hasMoreTokens()) {
            String value = st.nextToken().trim();
            if (value != null && value.length() > 0) {
                this.methodParameterList.add(value);
            }
        }
    }

    public String getDepends() {
        return this.depends;
    }

    public void setDepends(String depends2) {
        this.depends = depends2;
        this.dependencyList.clear();
        StringTokenizer st = new StringTokenizer(depends2, ",");
        while (st.hasMoreTokens()) {
            String depend = st.nextToken().trim();
            if (depend != null && depend.length() > 0) {
                this.dependencyList.add(depend);
            }
        }
    }

    public String getMsg() {
        return this.msg;
    }

    public void setMsg(String msg2) {
        this.msg = msg2;
    }

    public String getJsFunctionName() {
        return this.jsFunctionName;
    }

    public void setJsFunctionName(String jsFunctionName2) {
        this.jsFunctionName = jsFunctionName2;
    }

    public void setJsFunction(String jsFunction2) {
        if (this.javascript == null) {
            this.jsFunction = jsFunction2;
            return;
        }
        throw new IllegalStateException("Cannot call setJsFunction() after calling setJavascript()");
    }

    public String getJavascript() {
        return this.javascript;
    }

    public void setJavascript(String javascript2) {
        if (this.jsFunction == null) {
            this.javascript = javascript2;
            return;
        }
        throw new IllegalStateException("Cannot call setJavascript() after calling setJsFunction()");
    }

    /* access modifiers changed from: protected */
    public void init() {
        loadJavascriptFunction();
    }

    /* access modifiers changed from: protected */
    public synchronized void loadJavascriptFunction() {
        if (!javascriptAlreadyLoaded()) {
            if (getLog().isTraceEnabled()) {
                getLog().trace("  Loading function begun");
            }
            if (this.jsFunction == null) {
                this.jsFunction = generateJsFunction();
            }
            String javascriptFileName = formatJavascriptFileName();
            if (getLog().isTraceEnabled()) {
                Log log2 = getLog();
                log2.trace("  Loading js function '" + javascriptFileName + "'");
            }
            this.javascript = readJavascriptFile(javascriptFileName);
            if (getLog().isTraceEnabled()) {
                getLog().trace("  Loading javascript function completed");
            }
        }
    }

    private String readJavascriptFile(String javascriptFileName) {
        ClassLoader classLoader = Thread.currentThread().getContextClassLoader();
        if (classLoader == null) {
            classLoader = getClass().getClassLoader();
        }
        InputStream is = classLoader.getResourceAsStream(javascriptFileName);
        if (is == null) {
            is = getClass().getResourceAsStream(javascriptFileName);
        }
        if (is == null) {
            Log log2 = getLog();
            log2.debug("  Unable to read javascript name " + javascriptFileName);
            return null;
        }
        StringBuilder buffer = new StringBuilder();
        BufferedReader reader = new BufferedReader(new InputStreamReader(is));
        while (true) {
            try {
                String line = reader.readLine();
                if (line != null) {
                    buffer.append(line);
                    buffer.append(ShellUtils.COMMAND_LINE_END);
                } else {
                    try {
                        break;
                    } catch (IOException e) {
                        getLog().error("Error closing stream to javascript file.", e);
                    }
                }
            } catch (IOException e2) {
                getLog().error("Error reading javascript file.", e2);
                reader.close();
            } catch (Throwable th) {
                try {
                    reader.close();
                } catch (IOException e3) {
                    getLog().error("Error closing stream to javascript file.", e3);
                }
                throw th;
            }
        }
        reader.close();
        String function = buffer.toString();
        if (function.equals("")) {
            return null;
        }
        return function;
    }

    private String formatJavascriptFileName() {
        String fname = this.jsFunction.substring(1);
        if (this.jsFunction.startsWith("/")) {
            return fname;
        }
        return this.jsFunction.replace('.', '/') + ".js";
    }

    private boolean javascriptAlreadyLoaded() {
        return this.javascript != null;
    }

    private String generateJsFunction() {
        StringBuilder jsName = new StringBuilder("org.apache.commons.validator.javascript");
        jsName.append(".validate");
        jsName.append(this.name.substring(0, 1).toUpperCase());
        String str = this.name;
        jsName.append(str.substring(1, str.length()));
        return jsName.toString();
    }

    public boolean isDependency(String validatorName) {
        return this.dependencyList.contains(validatorName);
    }

    public List<String> getDependencyList() {
        return Collections.unmodifiableList(this.dependencyList);
    }

    public String toString() {
        return "ValidatorAction: " + this.name + ShellUtils.COMMAND_LINE_END;
    }

    /* access modifiers changed from: package-private */
    public boolean executeValidationMethod(Field field, Map<String, Object> params, ValidatorResults results, int pos) throws ValidatorException {
        params.put(Validator.VALIDATOR_ACTION_PARAM, this);
        try {
            if (this.validationMethod == null) {
                synchronized (this) {
                    ClassLoader loader = getClassLoader(params);
                    loadValidationClass(loader);
                    loadParameterClasses(loader);
                    loadValidationMethod();
                }
            }
            Object[] paramValues = getParameterValues(params);
            if (field.isIndexed()) {
                handleIndexedField(field, pos, paramValues);
            }
            Object result = null;
            try {
                result = this.validationMethod.invoke(getValidationClassInstance(), paramValues);
            } catch (IllegalArgumentException e) {
                throw new ValidatorException(e.getMessage());
            } catch (IllegalAccessException e2) {
                throw new ValidatorException(e2.getMessage());
            } catch (InvocationTargetException e3) {
                if (e3.getTargetException() instanceof Exception) {
                    throw ((Exception) e3.getTargetException());
                } else if (e3.getTargetException() instanceof Error) {
                    throw ((Error) e3.getTargetException());
                }
            }
            boolean valid = isValid(result);
            if (!valid || (valid && !onlyReturnErrors(params))) {
                results.add(field, this.name, valid, result);
            }
            if (!valid) {
                return false;
            }
            return true;
        } catch (Exception e4) {
            if (!(e4 instanceof ValidatorException)) {
                Log log2 = getLog();
                log2.error("Unhandled exception thrown during validation: " + e4.getMessage(), e4);
                results.add(field, this.name, false);
                return false;
            }
            throw ((ValidatorException) e4);
        }
    }

    private void loadValidationMethod() throws ValidatorException {
        if (this.validationMethod == null) {
            try {
                this.validationMethod = this.validationClass.getMethod(this.method, this.parameterClasses);
            } catch (NoSuchMethodException e) {
                throw new ValidatorException("No such validation method: " + e.getMessage());
            }
        }
    }

    private void loadValidationClass(ClassLoader loader) throws ValidatorException {
        if (this.validationClass == null) {
            try {
                this.validationClass = loader.loadClass(this.classname);
            } catch (ClassNotFoundException e) {
                throw new ValidatorException(e.toString());
            }
        }
    }

    private void loadParameterClasses(ClassLoader loader) throws ValidatorException {
        if (this.parameterClasses == null) {
            Class<?>[] parameterClasses2 = new Class[this.methodParameterList.size()];
            for (int i = 0; i < this.methodParameterList.size(); i++) {
                try {
                    parameterClasses2[i] = loader.loadClass(this.methodParameterList.get(i));
                } catch (ClassNotFoundException e) {
                    throw new ValidatorException(e.getMessage());
                }
            }
            this.parameterClasses = parameterClasses2;
        }
    }

    private Object[] getParameterValues(Map<String, ? super Object> params) {
        Object[] paramValue = new Object[this.methodParameterList.size()];
        for (int i = 0; i < this.methodParameterList.size(); i++) {
            paramValue[i] = params.get(this.methodParameterList.get(i));
        }
        return paramValue;
    }

    private Object getValidationClassInstance() throws ValidatorException {
        if (Modifier.isStatic(this.validationMethod.getModifiers())) {
            this.instance = null;
        } else if (this.instance == null) {
            try {
                this.instance = this.validationClass.newInstance();
            } catch (InstantiationException e) {
                throw new ValidatorException("Couldn't create instance of " + this.classname + ".  " + e.getMessage());
            } catch (IllegalAccessException e2) {
                throw new ValidatorException("Couldn't create instance of " + this.classname + ".  " + e2.getMessage());
            }
        }
        return this.instance;
    }

    private void handleIndexedField(Field field, int pos, Object[] paramValues) throws ValidatorException {
        int beanIndex = this.methodParameterList.indexOf(Validator.BEAN_PARAM);
        int fieldIndex = this.methodParameterList.indexOf(Validator.FIELD_PARAM);
        paramValues[beanIndex] = field.getIndexedProperty(paramValues[beanIndex])[pos];
        Field indexedField = (Field) field.clone();
        String key = indexedField.getKey();
        indexedField.setKey(ValidatorUtils.replace(key, Field.TOKEN_INDEXED, "[" + pos + "]"));
        paramValues[fieldIndex] = indexedField;
    }

    private boolean isValid(Object result) {
        if (result instanceof Boolean) {
            return ((Boolean) result).booleanValue();
        }
        return result != null;
    }

    private ClassLoader getClassLoader(Map<String, Object> params) {
        return ((Validator) params.get(Validator.VALIDATOR_PARAM)).getClassLoader();
    }

    private boolean onlyReturnErrors(Map<String, Object> params) {
        return ((Validator) params.get(Validator.VALIDATOR_PARAM)).getOnlyReturnErrors();
    }

    private Log getLog() {
        if (this.log == null) {
            this.log = LogFactory.getLog(ValidatorAction.class);
        }
        return this.log;
    }
}
