package org.apache.commons.validator;

import java.io.IOException;
import java.io.InputStream;
import java.io.Serializable;
import java.net.URL;
import java.util.Collections;
import java.util.Locale;
import java.util.Map;
import org.apache.commons.collections.FastHashMap;
import org.apache.commons.digester.Digester;
import org.apache.commons.digester.Rule;
import org.apache.commons.digester.xmlrules.DigesterLoader;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

public class ValidatorResources implements Serializable {
    private static final String ARGS_PATTERN = "form-validation/formset/form/field/arg";
    private static final String[] REGISTRATIONS = {"-//Apache Software Foundation//DTD Commons Validator Rules Configuration 1.0//EN", "/org/apache/commons/validator/resources/validator_1_0.dtd", "-//Apache Software Foundation//DTD Commons Validator Rules Configuration 1.0.1//EN", "/org/apache/commons/validator/resources/validator_1_0_1.dtd", "-//Apache Software Foundation//DTD Commons Validator Rules Configuration 1.1//EN", "/org/apache/commons/validator/resources/validator_1_1.dtd", "-//Apache Software Foundation//DTD Commons Validator Rules Configuration 1.1.3//EN", "/org/apache/commons/validator/resources/validator_1_1_3.dtd", "-//Apache Software Foundation//DTD Commons Validator Rules Configuration 1.2.0//EN", "/org/apache/commons/validator/resources/validator_1_2_0.dtd", "-//Apache Software Foundation//DTD Commons Validator Rules Configuration 1.3.0//EN", "/org/apache/commons/validator/resources/validator_1_3_0.dtd", "-//Apache Software Foundation//DTD Commons Validator Rules Configuration 1.4.0//EN", "/org/apache/commons/validator/resources/validator_1_4_0.dtd"};
    private static final String VALIDATOR_RULES = "digester-rules.xml";
    protected static Locale defaultLocale = Locale.getDefault();
    private static final long serialVersionUID = -8203745881446239554L;
    protected FormSet defaultFormSet;
    @Deprecated
    protected FastHashMap hActions;
    @Deprecated
    protected FastHashMap hConstants;
    @Deprecated
    protected FastHashMap hFormSets;
    private transient Log log;

    public ValidatorResources() {
        this.log = LogFactory.getLog(ValidatorResources.class);
        this.hFormSets = new FastHashMap();
        this.hConstants = new FastHashMap();
        this.hActions = new FastHashMap();
    }

    public ValidatorResources(InputStream in) throws IOException, SAXException {
        this(new InputStream[]{in});
    }

    public ValidatorResources(InputStream[] streams) throws IOException, SAXException {
        this.log = LogFactory.getLog(ValidatorResources.class);
        this.hFormSets = new FastHashMap();
        this.hConstants = new FastHashMap();
        this.hActions = new FastHashMap();
        Digester digester = initDigester();
        for (int i = 0; i < streams.length; i++) {
            if (streams[i] != null) {
                digester.push(this);
                digester.parse(streams[i]);
            } else {
                throw new IllegalArgumentException("Stream[" + i + "] is null");
            }
        }
        process();
    }

    public ValidatorResources(String uri) throws IOException, SAXException {
        this(new String[]{uri});
    }

    public ValidatorResources(String[] uris) throws IOException, SAXException {
        this.log = LogFactory.getLog(ValidatorResources.class);
        this.hFormSets = new FastHashMap();
        this.hConstants = new FastHashMap();
        this.hActions = new FastHashMap();
        Digester digester = initDigester();
        for (String str : uris) {
            digester.push(this);
            digester.parse(str);
        }
        process();
    }

    public ValidatorResources(URL url) throws IOException, SAXException {
        this(new URL[]{url});
    }

    public ValidatorResources(URL[] urls) throws IOException, SAXException {
        this.log = LogFactory.getLog(ValidatorResources.class);
        this.hFormSets = new FastHashMap();
        this.hConstants = new FastHashMap();
        this.hActions = new FastHashMap();
        Digester digester = initDigester();
        for (URL url : urls) {
            digester.push(this);
            digester.parse(url);
        }
        process();
    }

    private Digester initDigester() {
        URL rulesUrl = getClass().getResource(VALIDATOR_RULES);
        if (rulesUrl == null) {
            rulesUrl = ValidatorResources.class.getResource(VALIDATOR_RULES);
        }
        if (getLog().isDebugEnabled()) {
            Log log2 = getLog();
            log2.debug("Loading rules from '" + rulesUrl + "'");
        }
        Digester digester = DigesterLoader.createDigester(rulesUrl);
        digester.setNamespaceAware(true);
        digester.setValidating(true);
        digester.setUseContextClassLoader(true);
        addOldArgRules(digester);
        int i = 0;
        while (true) {
            String[] strArr = REGISTRATIONS;
            if (i >= strArr.length) {
                return digester;
            }
            URL url = getClass().getResource(strArr[i + 1]);
            if (url != null) {
                digester.register(strArr[i], url.toString());
            }
            i += 2;
        }
    }

    private void addOldArgRules(Digester digester) {
        Rule rule = new Rule() {
            /* class org.apache.commons.validator.ValidatorResources.AnonymousClass1 */

            public void begin(String namespace, String name, Attributes attributes) throws Exception {
                Arg arg = new Arg();
                arg.setKey(attributes.getValue("key"));
                arg.setName(attributes.getValue("name"));
                if ("false".equalsIgnoreCase(attributes.getValue("resource"))) {
                    arg.setResource(false);
                }
                try {
                    arg.setPosition(Integer.parseInt(name.substring("arg".length())));
                } catch (Exception ex) {
                    Log log = ValidatorResources.this.getLog();
                    log.error("Error parsing Arg position: " + name + " " + arg + " " + ex);
                }
                ((Field) getDigester().peek(0)).addArg(arg);
            }
        };
        digester.addRule("form-validation/formset/form/field/arg0", rule);
        digester.addRule("form-validation/formset/form/field/arg1", rule);
        digester.addRule("form-validation/formset/form/field/arg2", rule);
        digester.addRule("form-validation/formset/form/field/arg3", rule);
    }

    public void addFormSet(FormSet fs) {
        String key = buildKey(fs);
        if (key.length() == 0) {
            if (getLog().isWarnEnabled() && this.defaultFormSet != null) {
                getLog().warn("Overriding default FormSet definition.");
            }
            this.defaultFormSet = fs;
            return;
        }
        if (getFormSets().get(key) == null) {
            if (getLog().isDebugEnabled()) {
                Log log2 = getLog();
                log2.debug("Adding FormSet '" + fs.toString() + "'.");
            }
        } else if (getLog().isWarnEnabled()) {
            Log log3 = getLog();
            log3.warn("Overriding FormSet definition. Duplicate for locale: " + key);
        }
        getFormSets().put(key, fs);
    }

    public void addConstant(String name, String value) {
        if (getLog().isDebugEnabled()) {
            Log log2 = getLog();
            log2.debug("Adding Global Constant: " + name + "," + value);
        }
        this.hConstants.put(name, value);
    }

    public void addValidatorAction(ValidatorAction va) {
        va.init();
        getActions().put(va.getName(), va);
        if (getLog().isDebugEnabled()) {
            Log log2 = getLog();
            log2.debug("Add ValidatorAction: " + va.getName() + "," + va.getClassname());
        }
    }

    public ValidatorAction getValidatorAction(String key) {
        return getActions().get(key);
    }

    public Map<String, ValidatorAction> getValidatorActions() {
        return Collections.unmodifiableMap(getActions());
    }

    /* access modifiers changed from: protected */
    public String buildKey(FormSet fs) {
        return buildLocale(fs.getLanguage(), fs.getCountry(), fs.getVariant());
    }

    private String buildLocale(String lang, String country, String variant) {
        String str;
        String str2 = "";
        String key = (lang == null || lang.length() <= 0) ? str2 : lang;
        StringBuilder sb = new StringBuilder();
        sb.append(key);
        if (country == null || country.length() <= 0) {
            str = str2;
        } else {
            str = "_" + country;
        }
        sb.append(str);
        String key2 = sb.toString();
        StringBuilder sb2 = new StringBuilder();
        sb2.append(key2);
        if (variant != null && variant.length() > 0) {
            str2 = "_" + variant;
        }
        sb2.append(str2);
        return sb2.toString();
    }

    public Form getForm(Locale locale, String formKey) {
        return getForm(locale.getLanguage(), locale.getCountry(), locale.getVariant(), formKey);
    }

    public Form getForm(String language, String country, String variant, String formKey) {
        FormSet formSet;
        FormSet formSet2;
        FormSet formSet3;
        Form form = null;
        String key = buildLocale(language, country, variant);
        if (key.length() > 0 && (formSet3 = getFormSets().get(key)) != null) {
            form = formSet3.getForm(formKey);
        }
        if (form == null) {
            key = buildLocale(language, country, null);
            if (key.length() > 0 && (formSet2 = getFormSets().get(key)) != null) {
                form = formSet2.getForm(formKey);
            }
        }
        if (form == null) {
            key = buildLocale(language, null, null);
            if (key.length() > 0 && (formSet = getFormSets().get(key)) != null) {
                form = formSet.getForm(formKey);
            }
        }
        if (form == null) {
            form = this.defaultFormSet.getForm(formKey);
            key = "default";
        }
        if (form == null) {
            if (getLog().isWarnEnabled()) {
                Log log2 = getLog();
                log2.warn("Form '" + formKey + "' not found for locale '" + key + "'");
            }
        } else if (getLog().isDebugEnabled()) {
            Log log3 = getLog();
            log3.debug("Form '" + formKey + "' found in formset '" + key + "' for locale '" + key + "'");
        }
        return form;
    }

    public void process() {
        this.hFormSets.setFast(true);
        this.hConstants.setFast(true);
        this.hActions.setFast(true);
        processForms();
    }

    private void processForms() {
        if (this.defaultFormSet == null) {
            this.defaultFormSet = new FormSet();
        }
        this.defaultFormSet.process(getConstants());
        for (String key : getFormSets().keySet()) {
            FormSet fs = getFormSets().get(key);
            fs.merge(getParent(fs));
        }
        for (FormSet fs2 : getFormSets().values()) {
            if (!fs2.isProcessed()) {
                fs2.process(getConstants());
            }
        }
    }

    private FormSet getParent(FormSet fs) {
        if (fs.getType() == 2) {
            return this.defaultFormSet;
        }
        if (fs.getType() == 3) {
            FormSet parent = getFormSets().get(buildLocale(fs.getLanguage(), null, null));
            if (parent == null) {
                return this.defaultFormSet;
            }
            return parent;
        } else if (fs.getType() != 4) {
            return null;
        } else {
            FormSet parent2 = getFormSets().get(buildLocale(fs.getLanguage(), fs.getCountry(), null));
            if (parent2 != null) {
                return parent2;
            }
            FormSet parent3 = getFormSets().get(buildLocale(fs.getLanguage(), null, null));
            if (parent3 == null) {
                return this.defaultFormSet;
            }
            return parent3;
        }
    }

    /* access modifiers changed from: package-private */
    public FormSet getFormSet(String language, String country, String variant) {
        String key = buildLocale(language, country, variant);
        if (key.length() == 0) {
            return this.defaultFormSet;
        }
        return getFormSets().get(key);
    }

    /* access modifiers changed from: protected */
    public Map<String, FormSet> getFormSets() {
        return this.hFormSets;
    }

    /* access modifiers changed from: protected */
    public Map<String, String> getConstants() {
        return this.hConstants;
    }

    /* access modifiers changed from: protected */
    public Map<String, ValidatorAction> getActions() {
        return this.hActions;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Log getLog() {
        if (this.log == null) {
            this.log = LogFactory.getLog(ValidatorResources.class);
        }
        return this.log;
    }
}
