package org.apache.commons.validator;

import java.io.PrintStream;
import java.text.DateFormat;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import junit.framework.TestCase;
import org.apache.commons.validator.util.ValidatorUtils;

public class ValidatorTest extends TestCase {
    public ValidatorTest(String name) {
        super(name);
    }

    public void testManualObject() {
        ValidatorResources resources = setupDateResources("date", "date");
        TestBean bean = new TestBean();
        bean.setDate("2/3/1999");
        Validator validator = new Validator(resources, "testForm");
        validator.setParameter(Validator.BEAN_PARAM, bean);
        try {
            ValidatorResults results = validator.validate();
            assertNotNull("Results are null.", results);
            ValidatorResult result = results.getValidatorResult("date");
            assertNotNull("Results are null.", results);
            assertTrue("ValidatorResult does not contain '" + "date" + "' validator result.", result.containsAction("date"));
            assertTrue("Validation of the date formatting has failed.", result.isValid("date"));
        } catch (Exception e) {
            fail("An exception was thrown while calling Validator.validate()");
        }
        bean.setDate("2/30/1999");
        try {
            ValidatorResults results2 = validator.validate();
            assertNotNull("Results are null.", results2);
            ValidatorResult result2 = results2.getValidatorResult("date");
            assertNotNull("Results are null.", results2);
            assertTrue("ValidatorResult does not contain '" + "date" + "' validator result.", result2.containsAction("date"));
            assertTrue("Validation of the date formatting has passed when it should have failed.", !result2.isValid("date"));
        } catch (Exception e2) {
            fail("An exception was thrown while calling Validator.validate()");
        }
    }

    public void testOnlyReturnErrors() throws ValidatorException {
        ValidatorResources resources = setupDateResources("date", "date");
        TestBean bean = new TestBean();
        bean.setDate("2/3/1999");
        Validator validator = new Validator(resources, "testForm");
        validator.setParameter(Validator.BEAN_PARAM, bean);
        ValidatorResults results = validator.validate();
        assertNotNull(results);
        assertTrue(results.getPropertyNames().contains("date"));
        validator.setOnlyReturnErrors(true);
        assertFalse(validator.validate().getPropertyNames().contains("date"));
    }

    public void testOnlyValidateField() throws ValidatorException {
        ValidatorResources resources = setupDateResources("date", "date");
        TestBean bean = new TestBean();
        bean.setDate("2/3/1999");
        Validator validator = new Validator(resources, "testForm", "date");
        validator.setParameter(Validator.BEAN_PARAM, bean);
        ValidatorResults results = validator.validate();
        assertNotNull(results);
        assertTrue(results.getPropertyNames().contains("date"));
    }

    private ValidatorResources setupDateResources(String property, String action) {
        ValidatorResources resources = new ValidatorResources();
        ValidatorAction va = new ValidatorAction();
        va.setName(action);
        va.setClassname("org.apache.commons.validator.ValidatorTest");
        va.setMethod("formatDate");
        va.setMethodParams("java.lang.Object,org.apache.commons.validator.Field");
        FormSet fs = new FormSet();
        Form form = new Form();
        form.setName("testForm");
        Field field = new Field();
        field.setProperty(property);
        field.setDepends(action);
        form.addField(field);
        fs.addForm(form);
        resources.addValidatorAction(va);
        resources.addFormSet(fs);
        resources.process();
        return resources;
    }

    public void testManualBoolean() {
        ValidatorResources resources = new ValidatorResources();
        ValidatorAction va = new ValidatorAction();
        va.setName("capLetter");
        va.setClassname("org.apache.commons.validator.ValidatorTest");
        va.setMethod("isCapLetter");
        va.setMethodParams("java.lang.Object,org.apache.commons.validator.Field,java.util.List");
        FormSet fs = new FormSet();
        Form form = new Form();
        form.setName("testForm");
        Field field = new Field();
        field.setProperty("letter");
        field.setDepends("capLetter");
        form.addField(field);
        fs.addForm(form);
        resources.addValidatorAction(va);
        resources.addFormSet(fs);
        resources.process();
        List<?> l = new ArrayList<>();
        TestBean bean = new TestBean();
        bean.setLetter("A");
        Validator validator = new Validator(resources, "testForm");
        validator.setParameter(Validator.BEAN_PARAM, bean);
        validator.setParameter("java.util.List", l);
        try {
            validator.validate();
        } catch (Exception e) {
            fail("An exception was thrown while calling Validator.validate()");
        }
        assertEquals("Validation of the letter 'A'.", 0, l.size());
        l.clear();
        bean.setLetter("AA");
        try {
            validator.validate();
        } catch (Exception e2) {
            fail("An exception was thrown while calling Validator.validate()");
        }
        assertEquals("Validation of the letter 'AA'.", 1, l.size());
    }

    public static boolean isCapLetter(Object bean, Field field, List<String> l) {
        String value = ValidatorUtils.getValueAsString(bean, field.getProperty());
        if (value == null || value.length() != 1) {
            l.add("Error");
            return false;
        } else if (value.charAt(0) >= 'A' && value.charAt(0) <= 'Z') {
            return true;
        } else {
            l.add("Error");
            return false;
        }
    }

    public static Date formatDate(Object bean, Field field) {
        String value = ValidatorUtils.getValueAsString(bean, field.getProperty());
        try {
            DateFormat formatter = DateFormat.getDateInstance(3, Locale.US);
            formatter.setLenient(false);
            return formatter.parse(value);
        } catch (ParseException e) {
            PrintStream printStream = System.out;
            printStream.println("ValidatorTest.formatDate() - " + e.getMessage());
            return null;
        }
    }

    public class TestBean {
        private String date = null;
        private String letter = null;

        public TestBean() {
        }

        public String getLetter() {
            return this.letter;
        }

        public void setLetter(String letter2) {
            this.letter = letter2;
        }

        public String getDate() {
            return this.date;
        }

        public void setDate(String date2) {
            this.date = date2;
        }
    }
}
