package org.apache.commons.validator.routines;

import java.text.DateFormat;
import java.text.DateFormatSymbols;
import java.text.Format;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Locale;
import java.util.TimeZone;

public abstract class AbstractCalendarValidator extends AbstractFormatValidator {
    private static final long serialVersionUID = -1410008585975827379L;
    private final int dateStyle;
    private final int timeStyle;

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractFormatValidator
    public abstract Object processParsedValue(Object obj, Format format);

    public AbstractCalendarValidator(boolean strict, int dateStyle2, int timeStyle2) {
        super(strict);
        this.dateStyle = dateStyle2;
        this.timeStyle = timeStyle2;
    }

    @Override // org.apache.commons.validator.routines.AbstractFormatValidator
    public boolean isValid(String value, String pattern, Locale locale) {
        return parse(value, pattern, locale, null) != null;
    }

    public String format(Object value, TimeZone timeZone) {
        return format(value, null, null, timeZone);
    }

    public String format(Object value, String pattern, TimeZone timeZone) {
        return format(value, pattern, null, timeZone);
    }

    public String format(Object value, Locale locale, TimeZone timeZone) {
        return format(value, null, locale, timeZone);
    }

    @Override // org.apache.commons.validator.routines.AbstractFormatValidator
    public String format(Object value, String pattern, Locale locale) {
        return format(value, pattern, locale, null);
    }

    public String format(Object value, String pattern, Locale locale, TimeZone timeZone) {
        DateFormat formatter = (DateFormat) getFormat(pattern, locale);
        if (timeZone != null) {
            formatter.setTimeZone(timeZone);
        } else if (value instanceof Calendar) {
            formatter.setTimeZone(((Calendar) value).getTimeZone());
        }
        return format(value, formatter);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractFormatValidator
    public String format(Object value, Format formatter) {
        if (value == null) {
            return null;
        }
        if (value instanceof Calendar) {
            value = ((Calendar) value).getTime();
        }
        return formatter.format(value);
    }

    /* access modifiers changed from: protected */
    public Object parse(String value, String pattern, Locale locale, TimeZone timeZone) {
        String value2 = value == null ? null : value.trim();
        if (value2 == null || value2.length() == 0) {
            return null;
        }
        DateFormat formatter = (DateFormat) getFormat(pattern, locale);
        if (timeZone != null) {
            formatter.setTimeZone(timeZone);
        }
        return parse(value2, formatter);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractFormatValidator
    public Format getFormat(String pattern, Locale locale) {
        DateFormat formatter;
        if (!(pattern != null && pattern.length() > 0)) {
            formatter = (DateFormat) getFormat(locale);
        } else if (locale == null) {
            formatter = new SimpleDateFormat(pattern);
        } else {
            formatter = new SimpleDateFormat(pattern, new DateFormatSymbols(locale));
        }
        formatter.setLenient(false);
        return formatter;
    }

    /* access modifiers changed from: protected */
    public Format getFormat(Locale locale) {
        DateFormat formatter;
        int i;
        int useDateStyle = this.dateStyle;
        if (useDateStyle < 0 || (i = this.timeStyle) < 0) {
            int i2 = this.timeStyle;
            if (i2 < 0) {
                if (useDateStyle < 0) {
                    useDateStyle = 3;
                }
                if (locale == null) {
                    formatter = DateFormat.getDateInstance(useDateStyle);
                } else {
                    formatter = DateFormat.getDateInstance(useDateStyle, locale);
                }
            } else if (locale == null) {
                formatter = DateFormat.getTimeInstance(i2);
            } else {
                formatter = DateFormat.getTimeInstance(i2, locale);
            }
        } else if (locale == null) {
            formatter = DateFormat.getDateTimeInstance(useDateStyle, i);
        } else {
            formatter = DateFormat.getDateTimeInstance(useDateStyle, i, locale);
        }
        formatter.setLenient(false);
        return formatter;
    }

    /* access modifiers changed from: protected */
    public int compare(Calendar value, Calendar compare, int field) {
        int result = calculateCompareResult(value, compare, 1);
        if (result != 0 || field == 1) {
            return result;
        }
        if (field == 3) {
            return calculateCompareResult(value, compare, 3);
        }
        if (field == 6) {
            return calculateCompareResult(value, compare, 6);
        }
        int result2 = calculateCompareResult(value, compare, 2);
        if (result2 != 0 || field == 2) {
            return result2;
        }
        if (field == 4) {
            return calculateCompareResult(value, compare, 4);
        }
        int result3 = calculateCompareResult(value, compare, 5);
        if (result3 != 0 || field == 5 || field == 7 || field == 8) {
            return result3;
        }
        return compareTime(value, compare, field);
    }

    /* access modifiers changed from: protected */
    public int compareTime(Calendar value, Calendar compare, int field) {
        int result = calculateCompareResult(value, compare, 11);
        if (result != 0 || field == 10 || field == 11) {
            return result;
        }
        int result2 = calculateCompareResult(value, compare, 12);
        if (result2 != 0 || field == 12) {
            return result2;
        }
        int result3 = calculateCompareResult(value, compare, 13);
        if (result3 != 0 || field == 13) {
            return result3;
        }
        if (field == 14) {
            return calculateCompareResult(value, compare, 14);
        }
        throw new IllegalArgumentException("Invalid field: " + field);
    }

    /* access modifiers changed from: protected */
    public int compareQuarters(Calendar value, Calendar compare, int monthOfFirstQuarter) {
        int valueQuarter = calculateQuarter(value, monthOfFirstQuarter);
        int compareQuarter = calculateQuarter(compare, monthOfFirstQuarter);
        if (valueQuarter < compareQuarter) {
            return -1;
        }
        if (valueQuarter > compareQuarter) {
            return 1;
        }
        return 0;
    }

    private int calculateQuarter(Calendar calendar, int monthOfFirstQuarter) {
        int year = calendar.get(1);
        int month = calendar.get(2) + 1;
        int quarter = ((month >= monthOfFirstQuarter ? month - monthOfFirstQuarter : (12 - monthOfFirstQuarter) + month) / 3) + 1;
        if (month < monthOfFirstQuarter) {
            year--;
        }
        return (year * 10) + quarter;
    }

    private int calculateCompareResult(Calendar value, Calendar compare, int field) {
        int difference = value.get(field) - compare.get(field);
        if (difference < 0) {
            return -1;
        }
        if (difference > 0) {
            return 1;
        }
        return 0;
    }
}
