package org.apache.commons.validator.routines;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;
import junit.framework.TestCase;

public abstract class AbstractCalendarValidatorTest extends TestCase {
    protected static final TimeZone EET = TimeZone.getTimeZone("EET");
    protected static final TimeZone EST = TimeZone.getTimeZone("EST");
    protected static final TimeZone GMT = TimeZone.getTimeZone("GMT");
    protected static final TimeZone UTC = TimeZone.getTimeZone("UTC");
    protected String[] localeInvalid = {"01/00/2005", "00/01/2005", "13/01/2005", "04/31/2005", "03/32/2005", "02/29/2005", "01/01/200X", "01/0X/2005", "0X/01/2005", "01-01-2005", "01/2005", "01//2005"};
    protected String[] localeValid = {"01/01/2005", "12/31/2005", "02/29/2004", "04/30/2005", "12/31/05", "1/1/2005", "1/1/05"};
    protected Date[] patternExpect = {createDate(null, 20050101, 0), createDate(null, 20051231, 0), createDate(null, 20040229, 0), createDate(null, 20050430, 0), createDate(null, 20051231, 0), createDate(null, 20050101, 0), createDate(null, 20050101, 0)};
    protected String[] patternInvalid = {"2005-00-01", "2005-01-00", "2005-13-03", "2005-04-31", "2005-03-32", "2005-02-29", "200X-01-01", "2005-0X-01", "2005-01-0X", "01/01/2005", "2005-01", "2005--01", "2005-01-"};
    protected String[] patternValid = {"2005-01-01", "2005-12-31", "2004-02-29", "2005-04-30", "05-12-31", "2005-1-1", "05-1-1"};
    protected AbstractCalendarValidator validator;

    public AbstractCalendarValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws Exception {
        AbstractCalendarValidatorTest.super.setUp();
    }

    /* access modifiers changed from: protected */
    public void tearDown() throws Exception {
        AbstractCalendarValidatorTest.super.tearDown();
        this.validator = null;
    }

    public void testPatternValid() {
        for (int i = 0; i < this.patternValid.length; i++) {
            String text = i + " value=[" + this.patternValid[i] + "] failed ";
            Object date = this.validator.parse(this.patternValid[i], "yy-MM-dd", null, null);
            assertNotNull("validateObj() " + text + date, date);
            StringBuilder sb = new StringBuilder();
            sb.append("isValid() ");
            sb.append(text);
            assertTrue(sb.toString(), this.validator.isValid(this.patternValid[i], "yy-MM-dd"));
            if (date instanceof Calendar) {
                date = ((Calendar) date).getTime();
            }
            assertEquals("compare " + text, this.patternExpect[i], date);
        }
    }

    public void testPatternInvalid() {
        for (int i = 0; i < this.patternInvalid.length; i++) {
            String text = i + " value=[" + this.patternInvalid[i] + "] passed ";
            Object date = this.validator.parse(this.patternInvalid[i], "yy-MM-dd", null, null);
            assertNull("validateObj() " + text + date, date);
            StringBuilder sb = new StringBuilder();
            sb.append("isValid() ");
            sb.append(text);
            assertFalse(sb.toString(), this.validator.isValid(this.patternInvalid[i], "yy-MM-dd"));
        }
    }

    public void testLocaleValid() {
        for (int i = 0; i < this.localeValid.length; i++) {
            String text = i + " value=[" + this.localeValid[i] + "] failed ";
            Object date = this.validator.parse(this.localeValid[i], null, Locale.US, null);
            assertNotNull("validateObj() " + text + date, date);
            StringBuilder sb = new StringBuilder();
            sb.append("isValid() ");
            sb.append(text);
            assertTrue(sb.toString(), this.validator.isValid(this.localeValid[i], Locale.US));
            if (date instanceof Calendar) {
                date = ((Calendar) date).getTime();
            }
            assertEquals("compare " + text, this.patternExpect[i], date);
        }
    }

    public void testLocaleInvalid() {
        for (int i = 0; i < this.localeInvalid.length; i++) {
            String text = i + " value=[" + this.localeInvalid[i] + "] passed ";
            Object date = this.validator.parse(this.localeInvalid[i], null, Locale.US, null);
            assertNull("validateObj() " + text + date, date);
            StringBuilder sb = new StringBuilder();
            sb.append("isValid() ");
            sb.append(text);
            assertFalse(sb.toString(), this.validator.isValid(this.localeInvalid[i], Locale.US));
        }
    }

    public void testFormat() {
        Object test = this.validator.parse("2005-11-28", "yyyy-MM-dd", null, null);
        assertNotNull("Test Date ", test);
        assertEquals("Format pattern", "28.11.05", this.validator.format(test, "dd.MM.yy"));
        assertEquals("Format locale", "11/28/05", this.validator.format(test, Locale.US));
    }

    public void testSerialization() {
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        try {
            ObjectOutputStream oos = new ObjectOutputStream(baos);
            oos.writeObject(this.validator);
            oos.flush();
            oos.close();
        } catch (Exception e) {
            fail(this.validator.getClass().getName() + " error during serialization: " + e);
        }
        Object result = null;
        try {
            ByteArrayInputStream bais = new ByteArrayInputStream(baos.toByteArray());
            result = new ObjectInputStream(bais).readObject();
            bais.close();
        } catch (Exception e2) {
            fail(this.validator.getClass().getName() + " error during deserialization: " + e2);
        }
        assertNotNull(result);
    }

    protected static Calendar createCalendar(TimeZone zone, int date, int time) {
        Calendar calendar = zone == null ? Calendar.getInstance() : Calendar.getInstance(zone);
        int year = (date / 10000) * 10000;
        int mth = ((date / 100) * 100) - year;
        int hour = (time / 10000) * 10000;
        int min = ((time / 100) * 100) - hour;
        calendar.set(1, year / 10000);
        calendar.set(2, (mth / 100) - 1);
        calendar.set(5, date - (year + mth));
        calendar.set(11, hour / 10000);
        calendar.set(12, min / 100);
        calendar.set(13, time - (hour + min));
        calendar.set(14, 0);
        return calendar;
    }

    protected static Date createDate(TimeZone zone, int date, int time) {
        return createCalendar(zone, date, time).getTime();
    }
}
