package org.apache.commons.validator.routines;

import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.text.Format;
import java.text.NumberFormat;
import java.util.Locale;

public abstract class AbstractNumberValidator extends AbstractFormatValidator {
    public static final int CURRENCY_FORMAT = 1;
    public static final int PERCENT_FORMAT = 2;
    public static final int STANDARD_FORMAT = 0;
    private static final long serialVersionUID = -3088817875906765463L;
    private final boolean allowFractions;
    private final int formatType;

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractFormatValidator
    public abstract Object processParsedValue(Object obj, Format format);

    public AbstractNumberValidator(boolean strict, int formatType2, boolean allowFractions2) {
        super(strict);
        this.allowFractions = allowFractions2;
        this.formatType = formatType2;
    }

    public boolean isAllowFractions() {
        return this.allowFractions;
    }

    public int getFormatType() {
        return this.formatType;
    }

    @Override // org.apache.commons.validator.routines.AbstractFormatValidator
    public boolean isValid(String value, String pattern, Locale locale) {
        return parse(value, pattern, locale) != null;
    }

    public boolean isInRange(Number value, Number min, Number max) {
        return minValue(value, min) && maxValue(value, max);
    }

    public boolean minValue(Number value, Number min) {
        if (isAllowFractions()) {
            if (value.doubleValue() >= min.doubleValue()) {
                return true;
            }
            return false;
        } else if (value.longValue() >= min.longValue()) {
            return true;
        } else {
            return false;
        }
    }

    public boolean maxValue(Number value, Number max) {
        if (isAllowFractions()) {
            if (value.doubleValue() <= max.doubleValue()) {
                return true;
            }
            return false;
        } else if (value.longValue() <= max.longValue()) {
            return true;
        } else {
            return false;
        }
    }

    /* access modifiers changed from: protected */
    public Object parse(String value, String pattern, Locale locale) {
        String value2 = value == null ? null : value.trim();
        if (value2 == null || value2.length() == 0) {
            return null;
        }
        return parse(value2, getFormat(pattern, locale));
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractFormatValidator
    public Format getFormat(String pattern, Locale locale) {
        NumberFormat formatter;
        if (!(pattern != null && pattern.length() > 0)) {
            formatter = (NumberFormat) getFormat(locale);
        } else if (locale == null) {
            formatter = new DecimalFormat(pattern);
        } else {
            formatter = new DecimalFormat(pattern, new DecimalFormatSymbols(locale));
        }
        if (!isAllowFractions()) {
            formatter.setParseIntegerOnly(true);
        }
        return formatter;
    }

    /* access modifiers changed from: protected */
    public int determineScale(NumberFormat format) {
        if (!isStrict()) {
            return -1;
        }
        if (!isAllowFractions() || format.isParseIntegerOnly()) {
            return 0;
        }
        int minimumFraction = format.getMinimumFractionDigits();
        if (minimumFraction != format.getMaximumFractionDigits()) {
            return -1;
        }
        if (format instanceof DecimalFormat) {
            int multiplier = ((DecimalFormat) format).getMultiplier();
            if (multiplier == 100) {
                return minimumFraction + 2;
            }
            if (multiplier == 1000) {
                return minimumFraction + 3;
            }
            return minimumFraction;
        } else if (this.formatType == 2) {
            return minimumFraction + 2;
        } else {
            return minimumFraction;
        }
    }

    /* access modifiers changed from: protected */
    public Format getFormat(Locale locale) {
        NumberFormat formatter;
        int i = this.formatType;
        if (i != 1) {
            if (i != 2) {
                if (locale == null) {
                    formatter = NumberFormat.getInstance();
                } else {
                    formatter = NumberFormat.getInstance(locale);
                }
                if (isAllowFractions()) {
                    return formatter;
                }
                formatter.setParseIntegerOnly(true);
                return formatter;
            } else if (locale == null) {
                return NumberFormat.getPercentInstance();
            } else {
                return NumberFormat.getPercentInstance(locale);
            }
        } else if (locale == null) {
            return NumberFormat.getCurrencyInstance();
        } else {
            return NumberFormat.getCurrencyInstance(locale);
        }
    }
}
