package org.apache.commons.validator.routines;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.Locale;
import junit.framework.TestCase;

public abstract class AbstractNumberValidatorTest extends TestCase {
    protected String[] invalid;
    protected String[] invalidStrict;
    protected Number localeExpected;
    protected String localePattern;
    protected String localeValue;
    protected Number max;
    protected Number maxPlusOne;
    protected Number min;
    protected Number minMinusOne;
    protected AbstractNumberValidator strictValidator;
    protected Locale testLocale;
    protected Number testNumber;
    protected String testPattern;
    protected String testStringDE;
    protected String testStringUS;
    protected Number testZero;
    protected String[] valid;
    protected Number[] validCompare;
    protected String[] validStrict;
    protected Number[] validStrictCompare;
    protected AbstractNumberValidator validator;

    public AbstractNumberValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws Exception {
        AbstractNumberValidatorTest.super.setUp();
        Locale.setDefault(Locale.US);
    }

    /* access modifiers changed from: protected */
    public void tearDown() throws Exception {
        AbstractNumberValidatorTest.super.tearDown();
        this.validator = null;
        this.strictValidator = null;
    }

    public void testFormatType() {
        assertEquals("Format Type A", 0, this.validator.getFormatType());
        assertEquals("Format Type B", 0, this.validator.getFormatType());
    }

    public void testValidateMinMax() {
        DecimalFormat fmt = new DecimalFormat("#");
        Number number = this.max;
        if (number != null) {
            assertEquals("Test Max", number, this.validator.parse(fmt.format(number), "#", null));
            assertNull("Test Max + 1", this.validator.parse(fmt.format(this.maxPlusOne), "#", null));
            Number number2 = this.min;
            assertEquals("Test Min", number2, this.validator.parse(fmt.format(number2), "#", null));
            assertNull("Test min - 1", this.validator.parse(fmt.format(this.minMinusOne), "#", null));
        }
    }

    public void testInvalidStrict() {
        for (int i = 0; i < this.invalidStrict.length; i++) {
            String text = "idx=[" + i + "] value=[" + this.invalidStrict[i] + "]";
            assertNull("(A) " + text, this.strictValidator.parse(this.invalidStrict[i], null, Locale.US));
            assertFalse("(B) " + text, this.strictValidator.isValid(this.invalidStrict[i], null, Locale.US));
            assertNull("(C) " + text, this.strictValidator.parse(this.invalidStrict[i], this.testPattern, null));
            assertFalse("(D) " + text, this.strictValidator.isValid(this.invalidStrict[i], this.testPattern, null));
        }
    }

    public void testInvalidNotStrict() {
        for (int i = 0; i < this.invalid.length; i++) {
            String text = "idx=[" + i + "] value=[" + this.invalid[i] + "]";
            assertNull("(A) " + text, this.validator.parse(this.invalid[i], null, Locale.US));
            assertFalse("(B) " + text, this.validator.isValid(this.invalid[i], null, Locale.US));
            assertNull("(C) " + text, this.validator.parse(this.invalid[i], this.testPattern, null));
            assertFalse("(D) " + text, this.validator.isValid(this.invalid[i], this.testPattern, null));
        }
    }

    public void testValidStrict() {
        for (int i = 0; i < this.validStrict.length; i++) {
            String text = "idx=[" + i + "] value=[" + this.validStrictCompare[i] + "]";
            assertEquals("(A) " + text, this.validStrictCompare[i], this.strictValidator.parse(this.validStrict[i], null, Locale.US));
            assertTrue("(B) " + text, this.strictValidator.isValid(this.validStrict[i], null, Locale.US));
            assertEquals("(C) " + text, this.validStrictCompare[i], this.strictValidator.parse(this.validStrict[i], this.testPattern, null));
            assertTrue("(D) " + text, this.strictValidator.isValid(this.validStrict[i], this.testPattern, null));
        }
    }

    public void testValidNotStrict() {
        for (int i = 0; i < this.valid.length; i++) {
            String text = "idx=[" + i + "] value=[" + this.validCompare[i] + "]";
            assertEquals("(A) " + text, this.validCompare[i], this.validator.parse(this.valid[i], null, Locale.US));
            assertTrue("(B) " + text, this.validator.isValid(this.valid[i], null, Locale.US));
            assertEquals("(C) " + text, this.validCompare[i], this.validator.parse(this.valid[i], this.testPattern, null));
            assertTrue("(D) " + text, this.validator.isValid(this.valid[i], this.testPattern, null));
        }
    }

    public void testValidateLocale() {
        assertEquals("US Locale, US Format", this.testNumber, this.strictValidator.parse(this.testStringUS, null, Locale.US));
        assertNull("US Locale, DE Format", this.strictValidator.parse(this.testStringDE, null, Locale.US));
        assertEquals("DE Locale, DE Format", this.testNumber, this.strictValidator.parse(this.testStringDE, null, Locale.GERMAN));
        assertNull("DE Locale, US Format", this.strictValidator.parse(this.testStringUS, null, Locale.GERMAN));
        assertEquals("Default Locale, US Format", this.testNumber, this.strictValidator.parse(this.testStringUS, null, null));
        assertNull("Default Locale, DE Format", this.strictValidator.parse(this.testStringDE, null, null));
    }

    public void testFormat() {
        Number number = new BigDecimal("1234.5");
        assertEquals("US Locale, US Format", "1,234.5", this.strictValidator.format(number, Locale.US));
        assertEquals("DE Locale, DE Format", "1.234,5", this.strictValidator.format(number, Locale.GERMAN));
        assertEquals("Pattern #,#0.00", "12,34.50", this.strictValidator.format(number, "#,#0.00"));
    }

    public void testRangeMinMax() {
        assertFalse("isInRange() < min", this.strictValidator.isInRange(9, 10, 20));
        assertTrue("isInRange() = min", this.strictValidator.isInRange(10, 10, 20));
        assertTrue("isInRange() in range", this.strictValidator.isInRange(11, 10, 20));
        assertTrue("isInRange() = max", this.strictValidator.isInRange(20, 10, 20));
        assertFalse("isInRange() > max", this.strictValidator.isInRange(21, 10, 20));
        assertFalse("minValue() < min", this.strictValidator.minValue(9, 10));
        assertTrue("minValue() = min", this.strictValidator.minValue(10, 10));
        assertTrue("minValue() > min", this.strictValidator.minValue(11, 10));
        assertTrue("maxValue() < max", this.strictValidator.maxValue(19, 20));
        assertTrue("maxValue() = max", this.strictValidator.maxValue(20, 20));
        assertFalse("maxValue() > max", this.strictValidator.maxValue(21, 20));
    }

    public void testSerialization() {
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        try {
            ObjectOutputStream oos = new ObjectOutputStream(baos);
            oos.writeObject(this.validator);
            oos.flush();
            oos.close();
        } catch (Exception e) {
            fail(this.validator.getClass().getName() + " error during serialization: " + e);
        }
        Object result = null;
        try {
            ByteArrayInputStream bais = new ByteArrayInputStream(baos.toByteArray());
            result = new ObjectInputStream(bais).readObject();
            bais.close();
        } catch (Exception e2) {
            fail(this.validator.getClass().getName() + " error during deserialization: " + e2);
        }
        assertNotNull(result);
    }
}
