package org.apache.commons.validator.routines;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.apache.commons.validator.routines.checkdigit.CheckDigit;
import org.apache.commons.validator.routines.checkdigit.LuhnCheckDigit;

public class CreditCardValidator implements Serializable {
    public static final long AMEX = 1;
    public static final CodeValidator AMEX_VALIDATOR;
    public static final long DINERS = 16;
    public static final CodeValidator DINERS_VALIDATOR;
    public static final long DISCOVER = 8;
    private static final RegexValidator DISCOVER_REGEX;
    public static final CodeValidator DISCOVER_VALIDATOR;
    private static final CheckDigit LUHN_VALIDATOR;
    public static final long MASTERCARD = 4;
    @Deprecated
    public static final long MASTERCARD_PRE_OCT2016 = 64;
    private static final RegexValidator MASTERCARD_REGEX;
    public static final CodeValidator MASTERCARD_VALIDATOR;
    @Deprecated
    public static final CodeValidator MASTERCARD_VALIDATOR_PRE_OCT2016;
    private static final int MAX_CC_LENGTH = 19;
    private static final int MIN_CC_LENGTH = 12;
    public static final long NONE = 0;
    public static final long VISA = 2;
    public static final CodeValidator VISA_VALIDATOR;
    public static final long VPAY = 32;
    public static final CodeValidator VPAY_VALIDATOR;
    private static final long serialVersionUID = 5955978921148959496L;
    private final List<CodeValidator> cardTypes;

    public static class CreditCardRange {
        final String high;
        final int[] lengths;
        final String low;
        final int maxLen;
        final int minLen;

        public CreditCardRange(String low2, String high2, int minLen2, int maxLen2) {
            this.low = low2;
            this.high = high2;
            this.minLen = minLen2;
            this.maxLen = maxLen2;
            this.lengths = null;
        }

        public CreditCardRange(String low2, String high2, int[] lengths2) {
            this.low = low2;
            this.high = high2;
            this.minLen = -1;
            this.maxLen = -1;
            this.lengths = (int[]) lengths2.clone();
        }
    }

    static {
        CheckDigit checkDigit = LuhnCheckDigit.LUHN_CHECK_DIGIT;
        LUHN_VALIDATOR = checkDigit;
        AMEX_VALIDATOR = new CodeValidator("^(3[47]\\d{13})$", checkDigit);
        DINERS_VALIDATOR = new CodeValidator("^(30[0-5]\\d{11}|3095\\d{10}|36\\d{12}|3[8-9]\\d{12})$", checkDigit);
        RegexValidator regexValidator = new RegexValidator(new String[]{"^(6011\\d{12,13})$", "^(64[4-9]\\d{13})$", "^(65\\d{14})$", "^(62[2-8]\\d{13})$"});
        DISCOVER_REGEX = regexValidator;
        DISCOVER_VALIDATOR = new CodeValidator(regexValidator, checkDigit);
        RegexValidator regexValidator2 = new RegexValidator(new String[]{"^(5[1-5]\\d{14})$", "^(2221\\d{12})$", "^(222[2-9]\\d{12})$", "^(22[3-9]\\d{13})$", "^(2[3-6]\\d{14})$", "^(27[01]\\d{13})$", "^(2720\\d{12})$"});
        MASTERCARD_REGEX = regexValidator2;
        MASTERCARD_VALIDATOR = new CodeValidator(regexValidator2, checkDigit);
        MASTERCARD_VALIDATOR_PRE_OCT2016 = new CodeValidator("^(5[1-5]\\d{14})$", checkDigit);
        VISA_VALIDATOR = new CodeValidator("^(4)(\\d{12}|\\d{15})$", checkDigit);
        VPAY_VALIDATOR = new CodeValidator("^(4)(\\d{12,18})$", checkDigit);
    }

    public CreditCardValidator() {
        this(15);
    }

    public CreditCardValidator(long options) {
        ArrayList arrayList = new ArrayList();
        this.cardTypes = arrayList;
        if (isOn(options, 2)) {
            arrayList.add(VISA_VALIDATOR);
        }
        if (isOn(options, 32)) {
            arrayList.add(VPAY_VALIDATOR);
        }
        if (isOn(options, 1)) {
            arrayList.add(AMEX_VALIDATOR);
        }
        if (isOn(options, 4)) {
            arrayList.add(MASTERCARD_VALIDATOR);
        }
        if (isOn(options, 64)) {
            arrayList.add(MASTERCARD_VALIDATOR_PRE_OCT2016);
        }
        if (isOn(options, 8)) {
            arrayList.add(DISCOVER_VALIDATOR);
        }
        if (isOn(options, 16)) {
            arrayList.add(DINERS_VALIDATOR);
        }
    }

    public CreditCardValidator(CodeValidator[] creditCardValidators) {
        ArrayList arrayList = new ArrayList();
        this.cardTypes = arrayList;
        if (creditCardValidators != null) {
            Collections.addAll(arrayList, creditCardValidators);
            return;
        }
        throw new IllegalArgumentException("Card validators are missing");
    }

    public CreditCardValidator(CreditCardRange[] creditCardRanges) {
        ArrayList arrayList = new ArrayList();
        this.cardTypes = arrayList;
        if (creditCardRanges != null) {
            Collections.addAll(arrayList, createRangeValidator(creditCardRanges, LUHN_VALIDATOR));
            return;
        }
        throw new IllegalArgumentException("Card ranges are missing");
    }

    public CreditCardValidator(CodeValidator[] creditCardValidators, CreditCardRange[] creditCardRanges) {
        ArrayList arrayList = new ArrayList();
        this.cardTypes = arrayList;
        if (creditCardValidators == null) {
            throw new IllegalArgumentException("Card validators are missing");
        } else if (creditCardRanges != null) {
            Collections.addAll(arrayList, creditCardValidators);
            Collections.addAll(arrayList, createRangeValidator(creditCardRanges, LUHN_VALIDATOR));
        } else {
            throw new IllegalArgumentException("Card ranges are missing");
        }
    }

    public static CreditCardValidator genericCreditCardValidator(int minLen, int maxLen) {
        return new CreditCardValidator(new CodeValidator[]{new CodeValidator("(\\d+)", minLen, maxLen, LUHN_VALIDATOR)});
    }

    public static CreditCardValidator genericCreditCardValidator(int length) {
        return genericCreditCardValidator(length, length);
    }

    public static CreditCardValidator genericCreditCardValidator() {
        return genericCreditCardValidator(12, 19);
    }

    public boolean isValid(String card) {
        if (card == null || card.length() == 0) {
            return false;
        }
        for (CodeValidator cardType : this.cardTypes) {
            if (cardType.isValid(card)) {
                return true;
            }
        }
        return false;
    }

    public Object validate(String card) {
        if (card == null || card.length() == 0) {
            return null;
        }
        for (CodeValidator cardType : this.cardTypes) {
            Object result = cardType.validate(card);
            if (result != null) {
                return result;
            }
        }
        return null;
    }

    static boolean validLength(int valueLength, CreditCardRange range) {
        if (range.lengths != null) {
            for (int length : range.lengths) {
                if (valueLength == length) {
                    return true;
                }
            }
            return false;
        } else if (valueLength < range.minLen || valueLength > range.maxLen) {
            return false;
        } else {
            return true;
        }
    }

    static CodeValidator createRangeValidator(CreditCardRange[] creditCardRanges, CheckDigit digitCheck) {
        return new CodeValidator(new RegexValidator("(\\d+)", creditCardRanges) {
            /* class org.apache.commons.validator.routines.CreditCardValidator.AnonymousClass1 */
            private static final long serialVersionUID = 1;
            private CreditCardRange[] ccr;
            final /* synthetic */ CreditCardRange[] val$creditCardRanges;

            {
                this.val$creditCardRanges = r2;
                this.ccr = (CreditCardRange[]) r2.clone();
            }

            @Override // org.apache.commons.validator.routines.RegexValidator
            public String validate(String value) {
                if (super.match(value) == null) {
                    return null;
                }
                int length = value.length();
                CreditCardRange[] arr$ = this.ccr;
                for (CreditCardRange range : arr$) {
                    if (CreditCardValidator.validLength(length, range)) {
                        if (range.high == null) {
                            if (value.startsWith(range.low)) {
                                return value;
                            }
                        } else if (range.low.compareTo(value) <= 0 && range.high.compareTo(value.substring(0, range.high.length())) >= 0) {
                            return value;
                        }
                    }
                }
                return null;
            }

            @Override // org.apache.commons.validator.routines.RegexValidator
            public boolean isValid(String value) {
                return validate(value) != null;
            }

            @Override // org.apache.commons.validator.routines.RegexValidator
            public String[] match(String value) {
                return new String[]{validate(value)};
            }
        }, digitCheck);
    }

    private boolean isOn(long options, long flag) {
        return (options & flag) > 0;
    }
}
