package org.apache.commons.validator.routines;

import java.math.BigDecimal;
import java.text.DecimalFormatSymbols;
import java.util.Locale;
import junit.framework.TestCase;

public class CurrencyValidatorTest extends TestCase {
    private static final char CURRENCY_SYMBOL = 164;
    private String UK_POUND;
    private String US_DOLLAR;

    public CurrencyValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws Exception {
        CurrencyValidatorTest.super.setUp();
        this.US_DOLLAR = new DecimalFormatSymbols(Locale.US).getCurrencySymbol();
        this.UK_POUND = new DecimalFormatSymbols(Locale.UK).getCurrencySymbol();
    }

    /* access modifiers changed from: protected */
    public void tearDown() throws Exception {
        CurrencyValidatorTest.super.tearDown();
    }

    public void testFormatType() {
        assertEquals("Format Type A", 1, CurrencyValidator.getInstance().getFormatType());
        assertEquals("Format Type B", 1, CurrencyValidator.getInstance().getFormatType());
    }

    public void testValid() {
        Locale origDefault = Locale.getDefault();
        Locale.setDefault(Locale.UK);
        BigDecimalValidator validator = CurrencyValidator.getInstance();
        BigDecimal expected = new BigDecimal("1234.56");
        BigDecimal negative = new BigDecimal("-1234.56");
        BigDecimal noDecimal = new BigDecimal("1234.00");
        BigDecimal oneDecimal = new BigDecimal("1234.50");
        assertEquals("Default locale", expected, validator.validate(this.UK_POUND + "1,234.56"));
        assertEquals("UK locale", expected, validator.validate(this.UK_POUND + "1,234.56", Locale.UK));
        assertEquals("UK negative", negative, validator.validate("-" + this.UK_POUND + "1,234.56", Locale.UK));
        StringBuilder sb = new StringBuilder();
        sb.append(this.UK_POUND);
        sb.append("1,234");
        assertEquals("UK no decimal", noDecimal, validator.validate(sb.toString(), Locale.UK));
        assertEquals("UK 1 decimal", oneDecimal, validator.validate(this.UK_POUND + "1,234.5", Locale.UK));
        assertEquals("UK 3 decimal", expected, validator.validate(this.UK_POUND + "1,234.567", Locale.UK));
        assertEquals("UK no symbol", expected, validator.validate("1,234.56", Locale.UK));
        assertEquals("US locale", expected, validator.validate(this.US_DOLLAR + "1,234.56", Locale.US));
        assertEquals("US negative", negative, validator.validate("(" + this.US_DOLLAR + "1,234.56)", Locale.US));
        StringBuilder sb2 = new StringBuilder();
        sb2.append(this.US_DOLLAR);
        sb2.append("1,234");
        assertEquals("US no decimal", noDecimal, validator.validate(sb2.toString(), Locale.US));
        assertEquals("US 1 decimal", oneDecimal, validator.validate(this.US_DOLLAR + "1,234.5", Locale.US));
        assertEquals("US 3 decimal", expected, validator.validate(this.US_DOLLAR + "1,234.567", Locale.US));
        assertEquals("US no symbol", expected, validator.validate("1,234.56", Locale.US));
        Locale.setDefault(origDefault);
    }

    public void testInvalid() {
        BigDecimalValidator validator = CurrencyValidator.getInstance();
        assertFalse("isValid() Null Value", validator.isValid(null));
        assertFalse("isValid() Empty Value", validator.isValid(""));
        assertNull("validate() Null Value", validator.validate(null));
        assertNull("validate() Empty Value", validator.validate(""));
        assertFalse("UK wrong symbol", validator.isValid(this.US_DOLLAR + "1,234.56", Locale.UK));
        assertFalse("UK wrong negative", validator.isValid("(" + this.UK_POUND + "1,234.56)", Locale.UK));
        StringBuilder sb = new StringBuilder();
        sb.append(this.UK_POUND);
        sb.append("1,234.56");
        assertFalse("US wrong symbol", validator.isValid(sb.toString(), Locale.US));
        assertFalse("US wrong negative", validator.isValid("-" + this.US_DOLLAR + "1,234.56", Locale.US));
    }

    public void testIntegerValid() {
        Locale origDefault = Locale.getDefault();
        Locale.setDefault(Locale.UK);
        CurrencyValidator validator = new CurrencyValidator();
        BigDecimal expected = new BigDecimal("1234.00");
        BigDecimal negative = new BigDecimal("-1234.00");
        assertEquals("Default locale", expected, validator.validate(this.UK_POUND + "1,234"));
        assertEquals("UK locale", expected, validator.validate(this.UK_POUND + "1,234", Locale.UK));
        assertEquals("UK negative", negative, validator.validate("-" + this.UK_POUND + "1,234", Locale.UK));
        StringBuilder sb = new StringBuilder();
        sb.append(this.US_DOLLAR);
        sb.append("1,234");
        assertEquals("US locale", expected, validator.validate(sb.toString(), Locale.US));
        assertEquals("US negative", negative, validator.validate("(" + this.US_DOLLAR + "1,234)", Locale.US));
        Locale.setDefault(origDefault);
    }

    public void testIntegerInvalid() {
        CurrencyValidator validator = new CurrencyValidator(true, false);
        assertFalse("UK positive", validator.isValid(this.UK_POUND + "1,234.56", Locale.UK));
        assertFalse("UK negative", validator.isValid("-" + this.UK_POUND + "1,234.56", Locale.UK));
        StringBuilder sb = new StringBuilder();
        sb.append(this.US_DOLLAR);
        sb.append("1,234.56");
        assertFalse("US positive", validator.isValid(sb.toString(), Locale.US));
        assertFalse("US negative", validator.isValid("(" + this.US_DOLLAR + "1,234.56)", Locale.US));
    }

    public void testPattern() {
        Locale origDefault = Locale.getDefault();
        Locale.setDefault(Locale.UK);
        BigDecimalValidator validator = CurrencyValidator.getInstance();
        String pattern = "¤#,##0.000" + ";[" + "¤#,##0.000" + "]";
        BigDecimal expected = new BigDecimal("1234.567");
        BigDecimal negative = new BigDecimal("-1234.567");
        assertEquals("default", expected, validator.validate(this.UK_POUND + "1,234.567", pattern));
        assertEquals("negative", negative, validator.validate("[" + this.UK_POUND + "1,234.567]", pattern));
        assertEquals("no symbol +ve", expected, validator.validate("1,234.567", pattern));
        assertEquals("no symbol -ve", negative, validator.validate("[1,234.567]", pattern));
        assertEquals("default", expected, validator.validate(this.US_DOLLAR + "1,234.567", pattern, Locale.US));
        assertEquals("negative", negative, validator.validate("[" + this.US_DOLLAR + "1,234.567]", pattern, Locale.US));
        assertEquals("no symbol +ve", expected, validator.validate("1,234.567", pattern, Locale.US));
        assertEquals("no symbol -ve", negative, validator.validate("[1,234.567]", pattern, Locale.US));
        assertFalse("invalid symbol", validator.isValid(this.US_DOLLAR + "1,234.567", pattern));
        assertFalse("invalid symbol", validator.isValid(this.UK_POUND + "1,234.567", pattern, Locale.US));
        Locale.setDefault(origDefault);
    }
}
