package org.apache.commons.validator.routines;

import java.text.DateFormat;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;

public class DateValidatorTest extends AbstractCalendarValidatorTest {
    private DateValidator dateValidator;

    public DateValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractCalendarValidatorTest
    public void setUp() throws Exception {
        super.setUp();
        DateValidator dateValidator2 = new DateValidator();
        this.dateValidator = dateValidator2;
        this.validator = dateValidator2;
    }

    public void testLocaleProviders() throws Exception {
        String localeProviders = System.getProperty("java.locale.providers");
        if (localeProviders != null) {
            assertTrue("java.locale.providers must start with COMPAT", localeProviders.startsWith("COMPAT"));
        }
        DateFormat dateformat = DateFormat.getDateTimeInstance(3, 2, Locale.US);
        dateformat.setTimeZone(TimeZone.getTimeZone("GMT"));
        assertNotNull(dateformat.parse("3/20/15 10:59:00 PM"));
    }

    public void testDateValidatorMethods() {
        Locale.setDefault(Locale.US);
        Locale locale = Locale.GERMAN;
        boolean z = false;
        Date expected = createCalendar(null, 20051231, 0).getTime();
        assertEquals("validate(A) default", expected, DateValidator.getInstance().validate("12/31/05"));
        assertEquals("validate(A) locale ", expected, DateValidator.getInstance().validate("31.12.2005", locale));
        assertEquals("validate(A) pattern", expected, DateValidator.getInstance().validate("2005-12-31", "yyyy-MM-dd"));
        assertEquals("validate(A) both", expected, DateValidator.getInstance().validate("31 Dez 2005", "dd MMM yyyy", Locale.GERMAN));
        assertTrue("isValid(A) default", DateValidator.getInstance().isValid("12/31/05"));
        assertTrue("isValid(A) locale ", DateValidator.getInstance().isValid("31.12.2005", locale));
        assertTrue("isValid(A) pattern", DateValidator.getInstance().isValid("2005-12-31", "yyyy-MM-dd"));
        assertTrue("isValid(A) both", DateValidator.getInstance().isValid("31 Dez 2005", "dd MMM yyyy", Locale.GERMAN));
        assertNull("validate(B) default", DateValidator.getInstance().validate("XXXX"));
        assertNull("validate(B) locale ", DateValidator.getInstance().validate("XXXX", locale));
        assertNull("validate(B) pattern", DateValidator.getInstance().validate("XXXX", "yyyy-MM-dd"));
        assertNull("validate(B) both", DateValidator.getInstance().validate("31 Dec 2005", "dd MMM yyyy", Locale.GERMAN));
        assertFalse("isValid(B) default", DateValidator.getInstance().isValid("XXXX"));
        assertFalse("isValid(B) locale ", DateValidator.getInstance().isValid("XXXX", locale));
        assertFalse("isValid(B) pattern", DateValidator.getInstance().isValid("XXXX", "yyyy-MM-dd"));
        assertFalse("isValid(B) both", DateValidator.getInstance().isValid("31 Dec 2005", "dd MMM yyyy", Locale.GERMAN));
        TimeZone zone = TimeZone.getDefault().getRawOffset() == EET.getRawOffset() ? EST : EET;
        Date expectedZone = createCalendar(zone, 20051231, 0).getTime();
        String str = "default/zone same " + zone;
        if (expected.getTime() == expectedZone.getTime()) {
            z = true;
        }
        assertFalse(str, z);
        assertEquals("validate(C) default", expectedZone, DateValidator.getInstance().validate("12/31/05", zone));
        assertEquals("validate(C) locale ", expectedZone, DateValidator.getInstance().validate("31.12.2005", locale, zone));
        assertEquals("validate(C) pattern", expectedZone, DateValidator.getInstance().validate("2005-12-31", "yyyy-MM-dd", zone));
        assertEquals("validate(C) both", expectedZone, DateValidator.getInstance().validate("31 Dez 2005", "dd MMM yyyy", Locale.GERMAN, zone));
    }

    public void testCompare() {
        Date diffHour = createDate(GMT, 20050823, 115922);
        Date value = createDate(GMT, 20050823, 124522);
        Date date20050824 = createDate(GMT, 20050824, 124522);
        Date date20050822 = createDate(GMT, 20050822, 124522);
        Date date20050830 = createDate(GMT, 20050830, 124522);
        Date date20050816 = createDate(GMT, 20050816, 124522);
        Date date20050901 = createDate(GMT, 20050901, 124522);
        Date date20050801 = createDate(GMT, 20050801, 124522);
        Date date20050731 = createDate(GMT, 20050731, 124522);
        Date date20051101 = createDate(GMT, 20051101, 124522);
        Date date20051001 = createDate(GMT, 20051001, 124522);
        Date date20050701 = createDate(GMT, 20050701, 124522);
        Date date20050630 = createDate(GMT, 20050630, 124522);
        Date date20050110 = createDate(GMT, 20050110, 124522);
        Date date20060101 = createDate(GMT, 20060101, 124522);
        Date date20050101 = createDate(GMT, 20050101, 124522);
        Date date20041231 = createDate(GMT, 20041231, 124522);
        assertEquals("date LT", -1, this.dateValidator.compareDates(value, date20050824, GMT));
        assertEquals("date EQ", 0, this.dateValidator.compareDates(value, diffHour, GMT));
        assertEquals("date GT", 1, this.dateValidator.compareDates(value, date20050822, GMT));
        assertEquals("week LT", -1, this.dateValidator.compareWeeks(value, date20050830, GMT));
        assertEquals("week =1", 0, this.dateValidator.compareWeeks(value, date20050824, GMT));
        assertEquals("week =2", 0, this.dateValidator.compareWeeks(value, date20050822, GMT));
        assertEquals("week =3", 0, this.dateValidator.compareWeeks(value, date20050822, GMT));
        assertEquals("week GT", 1, this.dateValidator.compareWeeks(value, date20050816, GMT));
        assertEquals("mnth LT", -1, this.dateValidator.compareMonths(value, date20050901, GMT));
        assertEquals("mnth =1", 0, this.dateValidator.compareMonths(value, date20050830, GMT));
        assertEquals("mnth =2", 0, this.dateValidator.compareMonths(value, date20050801, GMT));
        assertEquals("mnth =3", 0, this.dateValidator.compareMonths(value, date20050816, GMT));
        assertEquals("mnth GT", 1, this.dateValidator.compareMonths(value, date20050731, GMT));
        assertEquals("qtrA <1", -1, this.dateValidator.compareQuarters(value, date20051101, GMT));
        assertEquals("qtrA <2", -1, this.dateValidator.compareQuarters(value, date20051001, GMT));
        assertEquals("qtrA =1", 0, this.dateValidator.compareQuarters(value, date20050901, GMT));
        assertEquals("qtrA =2", 0, this.dateValidator.compareQuarters(value, date20050701, GMT));
        assertEquals("qtrA =3", 0, this.dateValidator.compareQuarters(value, date20050731, GMT));
        assertEquals("qtrA GT", 1, this.dateValidator.compareQuarters(value, date20050630, GMT));
        assertEquals("qtrB LT", -1, this.dateValidator.compareQuarters(value, date20051101, GMT, 2));
        assertEquals("qtrB =1", 0, this.dateValidator.compareQuarters(value, date20051001, GMT, 2));
        assertEquals("qtrB =2", 0, this.dateValidator.compareQuarters(value, date20050901, GMT, 2));
        assertEquals("qtrB =3", 1, this.dateValidator.compareQuarters(value, date20050701, GMT, 2));
        assertEquals("qtrB =4", 1, this.dateValidator.compareQuarters(value, date20050731, GMT, 2));
        assertEquals("qtrB GT", 1, this.dateValidator.compareQuarters(value, date20050630, GMT, 2));
        assertEquals("qtrB prev", 1, this.dateValidator.compareQuarters(value, date20050110, GMT, 2));
        assertEquals("year LT", -1, this.dateValidator.compareYears(value, date20060101, GMT));
        assertEquals("year EQ", 0, this.dateValidator.compareYears(value, date20050101, GMT));
        assertEquals("year GT", 1, this.dateValidator.compareYears(value, date20041231, GMT));
        Date sameDayTwoAm = createDate(GMT, 20050823, 20000);
        assertEquals("date LT", -1, this.dateValidator.compareDates(value, date20050824, EST));
        assertEquals("date EQ", 0, this.dateValidator.compareDates(value, diffHour, EST));
        assertEquals("date EQ", 1, this.dateValidator.compareDates(value, sameDayTwoAm, EST));
        assertEquals("date GT", 1, this.dateValidator.compareDates(value, date20050822, EST));
    }
}
