package org.apache.commons.validator.routines;

import java.io.BufferedReader;
import java.io.Closeable;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintStream;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.net.HttpURLConnection;
import java.net.IDN;
import java.net.URL;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Locale;
import java.util.Map;
import java.util.Set;
import java.util.TreeMap;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import junit.framework.TestCase;
import org.apache.commons.validator.routines.DomainValidator;

public class DomainValidatorTest extends TestCase {
    private DomainValidator validator;

    public void setUp() {
        this.validator = DomainValidator.getInstance();
    }

    public void testValidDomains() {
        assertTrue("apache.org should validate", this.validator.isValid("apache.org"));
        assertTrue("www.google.com should validate", this.validator.isValid("www.google.com"));
        assertTrue("test-domain.com should validate", this.validator.isValid("test-domain.com"));
        assertTrue("test---domain.com should validate", this.validator.isValid("test---domain.com"));
        assertTrue("test-d-o-m-ain.com should validate", this.validator.isValid("test-d-o-m-ain.com"));
        assertTrue("two-letter domain label should validate", this.validator.isValid("as.uk"));
        assertTrue("case-insensitive ApAchE.Org should validate", this.validator.isValid("ApAchE.Org"));
        assertTrue("single-character domain label should validate", this.validator.isValid("z.com"));
        assertTrue("i.have.an-example.domain.name should validate", this.validator.isValid("i.have.an-example.domain.name"));
    }

    public void testInvalidDomains() {
        assertFalse("bare TLD .org shouldn't validate", this.validator.isValid(".org"));
        assertFalse("domain name with spaces shouldn't validate", this.validator.isValid(" apache.org "));
        assertFalse("domain name containing spaces shouldn't validate", this.validator.isValid("apa che.org"));
        assertFalse("domain name starting with dash shouldn't validate", this.validator.isValid("-testdomain.name"));
        assertFalse("domain name ending with dash shouldn't validate", this.validator.isValid("testdomain-.name"));
        assertFalse("domain name starting with multiple dashes shouldn't validate", this.validator.isValid("---c.com"));
        assertFalse("domain name ending with multiple dashes shouldn't validate", this.validator.isValid("c--.com"));
        assertFalse("domain name with invalid TLD shouldn't validate", this.validator.isValid("apache.rog"));
        assertFalse("URL shouldn't validate", this.validator.isValid("http://www.apache.org"));
        assertFalse("Empty string shouldn't validate as domain name", this.validator.isValid(" "));
        assertFalse("Null shouldn't validate as domain name", this.validator.isValid(null));
    }

    public void testTopLevelDomains() {
        assertTrue(".arpa should validate as iTLD", this.validator.isValidInfrastructureTld(".arpa"));
        assertFalse(".com shouldn't validate as iTLD", this.validator.isValidInfrastructureTld(".com"));
        assertTrue(".name should validate as gTLD", this.validator.isValidGenericTld(".name"));
        assertFalse(".us shouldn't validate as gTLD", this.validator.isValidGenericTld(".us"));
        assertTrue(".uk should validate as ccTLD", this.validator.isValidCountryCodeTld(".uk"));
        assertFalse(".org shouldn't validate as ccTLD", this.validator.isValidCountryCodeTld(".org"));
        assertTrue(".COM should validate as TLD", this.validator.isValidTld(".COM"));
        assertTrue(".BiZ should validate as TLD", this.validator.isValidTld(".BiZ"));
        assertFalse("invalid TLD shouldn't validate", this.validator.isValid(".nope"));
        assertFalse("empty string shouldn't validate as TLD", this.validator.isValid(""));
        assertFalse("null shouldn't validate as TLD", this.validator.isValid(null));
    }

    public void testAllowLocal() {
        DomainValidator noLocal = DomainValidator.getInstance(false);
        DomainValidator allowLocal = DomainValidator.getInstance(true);
        assertEquals(noLocal, this.validator);
        assertFalse("localhost.localdomain should validate", noLocal.isValid("localhost.localdomain"));
        assertFalse("localhost should validate", noLocal.isValid("localhost"));
        assertTrue("localhost.localdomain should validate", allowLocal.isValid("localhost.localdomain"));
        assertTrue("localhost should validate", allowLocal.isValid("localhost"));
        assertTrue("hostname should validate", allowLocal.isValid("hostname"));
        assertTrue("machinename should validate", allowLocal.isValid("machinename"));
        assertTrue("apache.org should validate", allowLocal.isValid("apache.org"));
        assertFalse("domain name with spaces shouldn't validate", allowLocal.isValid(" apache.org "));
    }

    public void testIDN() {
        assertTrue("bücher.ch in IDN should validate", this.validator.isValid("www.xn--bcher-kva.ch"));
    }

    public void testIDNJava6OrLater() {
        if (System.getProperty("java.version").compareTo("1.6") < 0) {
            System.out.println("Cannot run Unicode IDN tests");
            return;
        }
        assertTrue("bücher.ch should validate", this.validator.isValid("www.bücher.ch"));
        assertTrue("xn--d1abbgf6aiiy.xn--p1ai should validate", this.validator.isValid("xn--d1abbgf6aiiy.xn--p1ai"));
        assertTrue("президент.рф should validate", this.validator.isValid("президент.рф"));
        assertFalse("www.�.ch FFFD should fail", this.validator.isValid("www.�.ch"));
    }

    public void testRFC2396domainlabel() {
        assertTrue("a.ch should validate", this.validator.isValid("a.ch"));
        assertTrue("9.ch should validate", this.validator.isValid("9.ch"));
        assertTrue("az.ch should validate", this.validator.isValid("az.ch"));
        assertTrue("09.ch should validate", this.validator.isValid("09.ch"));
        assertTrue("9-1.ch should validate", this.validator.isValid("9-1.ch"));
        assertFalse("91-.ch should not validate", this.validator.isValid("91-.ch"));
        assertFalse("-.ch should not validate", this.validator.isValid("-.ch"));
    }

    public void testRFC2396toplabel() {
        assertTrue("a.c (alpha) should validate", this.validator.isValidDomainSyntax("a.c"));
        assertTrue("a.cc (alpha alpha) should validate", this.validator.isValidDomainSyntax("a.cc"));
        assertTrue("a.c9 (alpha alphanum) should validate", this.validator.isValidDomainSyntax("a.c9"));
        assertTrue("a.c-9 (alpha - alphanum) should validate", this.validator.isValidDomainSyntax("a.c-9"));
        assertTrue("a.c-z (alpha - alpha) should validate", this.validator.isValidDomainSyntax("a.c-z"));
        assertFalse("a.9c (alphanum alpha) should fail", this.validator.isValidDomainSyntax("a.9c"));
        assertFalse("a.c- (alpha -) should fail", this.validator.isValidDomainSyntax("a.c-"));
        assertFalse("a.- (-) should fail", this.validator.isValidDomainSyntax("a.-"));
        assertFalse("a.-9 (- alphanum) should fail", this.validator.isValidDomainSyntax("a.-9"));
    }

    public void testDomainNoDots() {
        assertTrue("a (alpha) should validate", this.validator.isValidDomainSyntax("a"));
        assertTrue("9 (alphanum) should validate", this.validator.isValidDomainSyntax("9"));
        assertTrue("c-z (alpha - alpha) should validate", this.validator.isValidDomainSyntax("c-z"));
        assertFalse("c- (alpha -) should fail", this.validator.isValidDomainSyntax("c-"));
        assertFalse("-c (- alpha) should fail", this.validator.isValidDomainSyntax("-c"));
        assertFalse("- (-) should fail", this.validator.isValidDomainSyntax("-"));
    }

    public void testValidator297() {
        assertTrue("xn--d1abbgf6aiiy.xn--p1ai should validate", this.validator.isValid("xn--d1abbgf6aiiy.xn--p1ai"));
    }

    public void testValidator306() {
        assertEquals(63, "abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz0123456789A".length());
        assertTrue("63 chars label should validate", this.validator.isValidDomainSyntax("abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz0123456789A.com"));
        assertFalse("64 chars label should fail", this.validator.isValidDomainSyntax("abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz0123456789Ax.com"));
        assertTrue("63 chars TLD should validate", this.validator.isValidDomainSyntax("test.abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz0123456789A"));
        assertFalse("64 chars TLD should fail", this.validator.isValidDomainSyntax("test.xabcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz0123456789A"));
        String longDomain = "abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz0123456789A.abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz0123456789A.abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz0123456789A." + "abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz0123456789A".substring(0, 61);
        assertEquals(253, longDomain.length());
        assertTrue("253 chars domain should validate", this.validator.isValidDomainSyntax(longDomain));
        assertFalse("254 chars domain should fail", this.validator.isValidDomainSyntax(longDomain + "x"));
    }

    public void testUnicodeToASCII() {
        String[] asciidots = {"", ",", ".", "a.", "a.b", "a..b", "a...b", ".a", "..a"};
        for (String s : asciidots) {
            assertEquals(s, DomainValidator.unicodeToASCII(s));
        }
        String[][] otherDots = {new String[]{"b。", "b."}, new String[]{"b．", "b."}, new String[]{"b｡", "b."}, new String[]{"。", "."}, new String[]{"．", "."}, new String[]{"｡", "."}};
        for (String[] s2 : otherDots) {
            assertEquals(s2[1], DomainValidator.unicodeToASCII(s2[0]));
        }
    }

    public void testIsIDNtoASCIIBroken() {
        System.out.println(">>DomainValidatorTest.testIsIDNtoASCIIBroken()");
        boolean ok = ".".equals(IDN.toASCII("."));
        PrintStream printStream = System.out;
        StringBuilder sb = new StringBuilder();
        sb.append("IDN.toASCII is ");
        sb.append(ok ? "OK" : "BROKEN");
        printStream.println(sb.toString());
        String[] props = {"java.version", "java.vendor", "java.vm.specification.version", "java.vm.specification.vendor", "java.vm.specification.name", "java.vm.version", "java.vm.vendor", "java.vm.name", "java.specification.version", "java.specification.vendor", "java.specification.name", "java.class.version"};
        for (String t : props) {
            System.out.println(t + "=" + System.getProperty(t));
        }
        System.out.println("<<DomainValidatorTest.testIsIDNtoASCIIBroken()");
        assertTrue(true);
    }

    public void test_INFRASTRUCTURE_TLDS_sortedAndLowerCase() throws Exception {
        assertTrue(isSortedLowerCase("INFRASTRUCTURE_TLDS"));
    }

    public void test_COUNTRY_CODE_TLDS_sortedAndLowerCase() throws Exception {
        assertTrue(isSortedLowerCase("COUNTRY_CODE_TLDS"));
    }

    public void test_GENERIC_TLDS_sortedAndLowerCase() throws Exception {
        assertTrue(isSortedLowerCase("GENERIC_TLDS"));
    }

    public void test_LOCAL_TLDS_sortedAndLowerCase() throws Exception {
        assertTrue(isSortedLowerCase("LOCAL_TLDS"));
    }

    public void testEnumIsPublic() {
        assertTrue(Modifier.isPublic(DomainValidator.ArrayType.class.getModifiers()));
    }

    public void testGetArray() {
        assertNotNull(DomainValidator.getTLDEntries(DomainValidator.ArrayType.COUNTRY_CODE_MINUS));
        assertNotNull(DomainValidator.getTLDEntries(DomainValidator.ArrayType.COUNTRY_CODE_PLUS));
        assertNotNull(DomainValidator.getTLDEntries(DomainValidator.ArrayType.GENERIC_MINUS));
        assertNotNull(DomainValidator.getTLDEntries(DomainValidator.ArrayType.GENERIC_PLUS));
        assertNotNull(DomainValidator.getTLDEntries(DomainValidator.ArrayType.LOCAL_MINUS));
        assertNotNull(DomainValidator.getTLDEntries(DomainValidator.ArrayType.LOCAL_PLUS));
        assertNotNull(DomainValidator.getTLDEntries(DomainValidator.ArrayType.COUNTRY_CODE_RO));
        assertNotNull(DomainValidator.getTLDEntries(DomainValidator.ArrayType.GENERIC_RO));
        assertNotNull(DomainValidator.getTLDEntries(DomainValidator.ArrayType.INFRASTRUCTURE_RO));
        assertNotNull(DomainValidator.getTLDEntries(DomainValidator.ArrayType.LOCAL_RO));
    }

    /* JADX INFO: Multiple debug info for r5v8 java.lang.String: [D('dv' org.apache.commons.validator.routines.DomainValidator), D('type' java.lang.String)] */
    /* JADX INFO: Multiple debug info for r7v11 java.lang.String: [D('comment' java.lang.String), D('timestamp' long)] */
    public static void main(String[] a) throws Exception {
        long timestamp;
        DomainValidator dv;
        File txtFile;
        File htmlFile;
        Map<String, String> missingCC;
        String unicodeTld;
        boolean OK = true;
        for (String list : new String[]{"INFRASTRUCTURE_TLDS", "COUNTRY_CODE_TLDS", "GENERIC_TLDS", "LOCAL_TLDS"}) {
            OK &= isSortedLowerCase(list);
        }
        if (!OK) {
            System.out.println("Fix arrays before retrying; cannot continue");
            return;
        }
        Set<String> ianaTlds = new HashSet<>();
        DomainValidator dv2 = DomainValidator.getInstance();
        File txtFile2 = new File("target/tlds-alpha-by-domain.txt");
        long timestamp2 = download(txtFile2, "https://data.iana.org/TLD/tlds-alpha-by-domain.txt", 0);
        File htmlFile2 = new File("target/tlds-alpha-by-domain.html");
        download(htmlFile2, "https://www.iana.org/domains/root/db", timestamp2);
        BufferedReader br = new BufferedReader(new FileReader(txtFile2));
        String line = br.readLine();
        if (line.startsWith("# Version ")) {
            String header = line.substring(2);
            Map<String, String[]> htmlInfo = getHtmlInfo(htmlFile2);
            Map<String, String> missingTLD = new TreeMap<>();
            Map<String, String> missingCC2 = new TreeMap<>();
            while (true) {
                String line2 = br.readLine();
                if (line2 == null) {
                    break;
                }
                if (!line2.startsWith("#")) {
                    String asciiTld = line2.toLowerCase(Locale.ENGLISH);
                    txtFile = txtFile2;
                    if (line2.startsWith("XN--")) {
                        unicodeTld = IDN.toUnicode(line2);
                    } else {
                        unicodeTld = asciiTld;
                    }
                    if (!dv2.isValidTld(asciiTld)) {
                        String[] info = htmlInfo.get(asciiTld);
                        if (info != null) {
                            dv = dv2;
                            String type = info[0];
                            timestamp = timestamp2;
                            String comment = info[1];
                            if ("country-code".equals(type)) {
                                missingCC = missingCC2;
                                missingCC.put(asciiTld, unicodeTld + " " + comment);
                                htmlFile = htmlFile2;
                            } else {
                                missingCC = missingCC2;
                                htmlFile = htmlFile2;
                                missingTLD.put(asciiTld, unicodeTld + " " + comment);
                            }
                        } else {
                            dv = dv2;
                            timestamp = timestamp2;
                            missingCC = missingCC2;
                            htmlFile = htmlFile2;
                            System.err.println("Expected to find HTML info for " + asciiTld);
                        }
                    } else {
                        dv = dv2;
                        timestamp = timestamp2;
                        missingCC = missingCC2;
                        htmlFile = htmlFile2;
                    }
                    ianaTlds.add(asciiTld);
                } else {
                    dv = dv2;
                    txtFile = txtFile2;
                    timestamp = timestamp2;
                    missingCC = missingCC2;
                    htmlFile = htmlFile2;
                }
                OK = OK;
                htmlFile2 = htmlFile;
                txtFile2 = txtFile;
                dv2 = dv;
                missingCC2 = missingCC;
                timestamp2 = timestamp;
            }
            br.close();
            for (String key : new TreeMap(htmlInfo).keySet()) {
                if (!ianaTlds.contains(key)) {
                    if (isNotInRootZone(key)) {
                        System.out.println("INFO: HTML entry not yet in root zone: " + key);
                    } else {
                        System.err.println("WARN: Expected to find text entry for html: " + key);
                    }
                }
            }
            if (!missingTLD.isEmpty()) {
                printMap(header, missingTLD, "TLD");
            }
            if (!missingCC2.isEmpty()) {
                printMap(header, missingCC2, "CC");
            }
            isInIanaList("INFRASTRUCTURE_TLDS", ianaTlds);
            isInIanaList("COUNTRY_CODE_TLDS", ianaTlds);
            isInIanaList("GENERIC_TLDS", ianaTlds);
            System.out.println("Finished checks");
            return;
        }
        br.close();
        throw new IOException("File does not have expected Version header");
    }

    private static void printMap(String header, Map<String, String> map, String string) {
        PrintStream printStream = System.out;
        printStream.println("Entries missing from " + string + " List\n");
        if (header != null) {
            PrintStream printStream2 = System.out;
            printStream2.println("        // Taken from " + header);
        }
        for (Map.Entry<String, String> me : map.entrySet()) {
            PrintStream printStream3 = System.out;
            printStream3.println("        \"" + me.getKey() + "\", // " + me.getValue());
        }
        System.out.println("\nDone");
    }

    private static Map<String, String[]> getHtmlInfo(File f) throws IOException {
        Map<String, String[]> info = new HashMap<>();
        Pattern domain = Pattern.compile(".*<a href=\"/domains/root/db/([^.]+)\\.html");
        Pattern type = Pattern.compile("\\s+<td>([^<]+)</td>");
        Pattern comment = Pattern.compile("\\s+<td>([^<]+)</td>");
        BufferedReader br = new BufferedReader(new FileReader(f));
        while (true) {
            String line = br.readLine();
            if (line != null) {
                Matcher m = domain.matcher(line);
                if (m.lookingAt()) {
                    String dom = m.group(1);
                    String com2 = "??";
                    String line2 = br.readLine();
                    while (line2.matches("^\\s*$")) {
                        line2 = br.readLine();
                    }
                    Matcher t = type.matcher(line2);
                    if (t.lookingAt()) {
                        String typ = t.group(1);
                        String line3 = br.readLine();
                        if (line3.matches("\\s+<!--.*")) {
                            while (!line3.matches(".*-->.*")) {
                                line3 = br.readLine();
                            }
                            line3 = br.readLine();
                        }
                        while (!line3.matches(".*</td>.*")) {
                            line3 = line3 + " " + br.readLine();
                        }
                        Matcher n = comment.matcher(line3);
                        if (n.lookingAt()) {
                            com2 = n.group(1);
                        }
                        if (!com2.contains("Not assigned") && !com2.contains("Retired") && !typ.equals("test")) {
                            info.put(dom.toLowerCase(Locale.ENGLISH), new String[]{typ, com2});
                        }
                    } else {
                        System.err.println("Unexpected type: " + line2);
                    }
                }
            } else {
                br.close();
                return info;
            }
        }
    }

    private static long download(File f, String tldurl, long timestamp) throws IOException {
        long modTime;
        if (f.canRead()) {
            modTime = f.lastModified();
            if (modTime > System.currentTimeMillis() - 3600000) {
                PrintStream printStream = System.out;
                printStream.println("Skipping download - found recent " + f);
                return modTime;
            }
        } else {
            modTime = 0;
        }
        HttpURLConnection hc = (HttpURLConnection) new URL(tldurl).openConnection();
        if (modTime > 0) {
            String since = new SimpleDateFormat("EEE, dd MMM yyyy HH:mm:ss z").format(new Date(modTime));
            hc.addRequestProperty("If-Modified-Since", since);
            PrintStream printStream2 = System.out;
            printStream2.println("Found " + f + " with date " + since);
        }
        if (hc.getResponseCode() == 304) {
            PrintStream printStream3 = System.out;
            printStream3.println("Already have most recent " + tldurl);
        } else {
            PrintStream printStream4 = System.out;
            printStream4.println("Downloading " + tldurl);
            byte[] buff = new byte[1024];
            InputStream is = hc.getInputStream();
            FileOutputStream fos = new FileOutputStream(f);
            while (true) {
                int len = is.read(buff);
                if (len == -1) {
                    break;
                }
                fos.write(buff, 0, len);
            }
            fos.close();
            is.close();
            System.out.println("Done");
        }
        return f.lastModified();
    }

    private static boolean isNotInRootZone(String domain) {
        String inputLine;
        String tldurl = "http://www.iana.org/domains/root/db/" + domain + ".html";
        File rootCheck = new File("target", "tld_" + domain + ".html");
        BufferedReader in = null;
        try {
            download(rootCheck, tldurl, 0);
            in = new BufferedReader(new FileReader(rootCheck));
            do {
                inputLine = in.readLine();
                if (inputLine == null) {
                    in.close();
                    closeQuietly(in);
                    return false;
                }
            } while (!inputLine.contains("This domain is not present in the root zone at this time."));
            closeQuietly(in);
            return true;
        } catch (IOException e) {
        } catch (Throwable th) {
            closeQuietly(null);
            throw th;
        }
    }

    private static void closeQuietly(Closeable in) {
        if (in != null) {
            try {
                in.close();
            } catch (IOException e) {
            }
        }
    }

    private static boolean isInIanaList(String arrayName, Set<String> ianaTlds) throws Exception {
        Field f = DomainValidator.class.getDeclaredField(arrayName);
        boolean isPrivate = Modifier.isPrivate(f.getModifiers());
        if (isPrivate) {
            f.setAccessible(true);
        }
        try {
            return isInIanaList(arrayName, (String[]) f.get(null), ianaTlds);
        } finally {
            if (isPrivate) {
                f.setAccessible(false);
            }
        }
    }

    private static boolean isInIanaList(String name, String[] array, Set<String> ianaTlds) {
        for (int i = 0; i < array.length; i++) {
            if (!ianaTlds.contains(array[i])) {
                PrintStream printStream = System.out;
                printStream.println(name + " contains unexpected value: " + array[i]);
            }
        }
        return true;
    }

    private static boolean isSortedLowerCase(String arrayName) throws Exception {
        Field f = DomainValidator.class.getDeclaredField(arrayName);
        boolean isPrivate = Modifier.isPrivate(f.getModifiers());
        if (isPrivate) {
            f.setAccessible(true);
        }
        try {
            return isSortedLowerCase(arrayName, (String[]) f.get(null));
        } finally {
            if (isPrivate) {
                f.setAccessible(false);
            }
        }
    }

    private static boolean isLowerCase(String string) {
        return string.equals(string.toLowerCase(Locale.ENGLISH));
    }

    private static boolean isSortedLowerCase(String name, String[] array) {
        boolean sorted = true;
        boolean strictlySorted = true;
        int length = array.length;
        boolean lowerCase = isLowerCase(array[length - 1]);
        for (int i = 0; i < length - 1; i++) {
            String entry = array[i];
            String nextEntry = array[i + 1];
            int cmp = entry.compareTo(nextEntry);
            if (cmp > 0) {
                PrintStream printStream = System.out;
                printStream.println("Out of order entry: " + entry + " < " + nextEntry + " in " + name);
                sorted = false;
            } else if (cmp == 0) {
                strictlySorted = false;
                PrintStream printStream2 = System.out;
                printStream2.println("Duplicated entry: " + entry + " in " + name);
            }
            if (!isLowerCase(entry)) {
                PrintStream printStream3 = System.out;
                printStream3.println("Non lowerCase entry: " + entry + " in " + name);
                lowerCase = false;
            }
        }
        return sorted && strictlySorted && lowerCase;
    }
}
