package org.apache.commons.validator.routines;

import java.io.Serializable;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class EmailValidator implements Serializable {
    private static final Pattern EMAIL_PATTERN = Pattern.compile(EMAIL_REGEX);
    private static final String EMAIL_REGEX = "^(.+)@(\\S+)$";
    private static final EmailValidator EMAIL_VALIDATOR = new EmailValidator(false, false);
    private static final EmailValidator EMAIL_VALIDATOR_WITH_LOCAL = new EmailValidator(true, false);
    private static final EmailValidator EMAIL_VALIDATOR_WITH_LOCAL_WITH_TLD = new EmailValidator(true, true);
    private static final EmailValidator EMAIL_VALIDATOR_WITH_TLD = new EmailValidator(false, true);
    private static final Pattern IP_DOMAIN_PATTERN = Pattern.compile(IP_DOMAIN_REGEX);
    private static final String IP_DOMAIN_REGEX = "^\\[(.*)\\]$";
    private static final int MAX_USERNAME_LEN = 64;
    private static final String QUOTED_USER = "(\"(\\\\\"|[^\"])*\")";
    private static final String SPECIAL_CHARS = "\\p{Cntrl}\\(\\)<>@,;:'\\\\\\\"\\.\\[\\]";
    private static final Pattern USER_PATTERN = Pattern.compile(USER_REGEX);
    private static final String USER_REGEX = "^(((\\\\.)|[^\\s\\p{Cntrl}\\(\\)<>@,;:'\\\\\\\"\\.\\[\\]]|')+|(\"(\\\\\"|[^\"])*\"))(\\.(((\\\\.)|[^\\s\\p{Cntrl}\\(\\)<>@,;:'\\\\\\\"\\.\\[\\]]|')+|(\"(\\\\\"|[^\"])*\")))*$";
    private static final String VALID_CHARS = "(\\\\.)|[^\\s\\p{Cntrl}\\(\\)<>@,;:'\\\\\\\"\\.\\[\\]]";
    private static final String WORD = "(((\\\\.)|[^\\s\\p{Cntrl}\\(\\)<>@,;:'\\\\\\\"\\.\\[\\]]|')+|(\"(\\\\\"|[^\"])*\"))";
    private static final long serialVersionUID = 1705927040799295880L;
    private final boolean allowTld;
    private final DomainValidator domainValidator;

    public static EmailValidator getInstance() {
        return EMAIL_VALIDATOR;
    }

    public static EmailValidator getInstance(boolean allowLocal, boolean allowTld2) {
        if (allowLocal) {
            if (allowTld2) {
                return EMAIL_VALIDATOR_WITH_LOCAL_WITH_TLD;
            }
            return EMAIL_VALIDATOR_WITH_LOCAL;
        } else if (allowTld2) {
            return EMAIL_VALIDATOR_WITH_TLD;
        } else {
            return EMAIL_VALIDATOR;
        }
    }

    public static EmailValidator getInstance(boolean allowLocal) {
        return getInstance(allowLocal, false);
    }

    public EmailValidator(boolean allowLocal, boolean allowTld2, DomainValidator domainValidator2) {
        this.allowTld = allowTld2;
        if (domainValidator2 == null) {
            throw new IllegalArgumentException("DomainValidator cannot be null");
        } else if (domainValidator2.isAllowLocal() == allowLocal) {
            this.domainValidator = domainValidator2;
        } else {
            throw new IllegalArgumentException("DomainValidator must agree with allowLocal setting");
        }
    }

    protected EmailValidator(boolean allowLocal, boolean allowTld2) {
        this.allowTld = allowTld2;
        this.domainValidator = DomainValidator.getInstance(allowLocal);
    }

    protected EmailValidator(boolean allowLocal) {
        this(allowLocal, false);
    }

    public boolean isValid(String email) {
        if (email == null || email.endsWith(".")) {
            return false;
        }
        Matcher emailMatcher = EMAIL_PATTERN.matcher(email);
        if (emailMatcher.matches() && isValidUser(emailMatcher.group(1)) && isValidDomain(emailMatcher.group(2))) {
            return true;
        }
        return false;
    }

    /* access modifiers changed from: protected */
    public boolean isValidDomain(String domain) {
        Matcher ipDomainMatcher = IP_DOMAIN_PATTERN.matcher(domain);
        if (ipDomainMatcher.matches()) {
            return InetAddressValidator.getInstance().isValid(ipDomainMatcher.group(1));
        }
        if (!this.allowTld) {
            return this.domainValidator.isValid(domain);
        }
        if (this.domainValidator.isValid(domain)) {
            return true;
        }
        if (domain.startsWith(".") || !this.domainValidator.isValidTld(domain)) {
            return false;
        }
        return true;
    }

    /* access modifiers changed from: protected */
    public boolean isValidUser(String user) {
        if (user == null || user.length() > 64) {
            return false;
        }
        return USER_PATTERN.matcher(user).matches();
    }
}
