package org.apache.commons.validator.routines;

import androidx.core.app.NotificationCompat;
import java.util.ArrayList;
import java.util.List;
import org.apache.commons.validator.ResultPair;
import org.apache.commons.validator.Var;
import org.apache.commons.validator.routines.DomainValidator;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Ignore;
import org.junit.Test;

public class EmailValidatorTest {
    protected static String ACTION = NotificationCompat.CATEGORY_EMAIL;
    protected static String FORM_KEY = "emailForm";
    private static final ResultPair[] testEmailFromPerl = {new ResultPair("abigail@example.com", true), new ResultPair("abigail@example.com ", true), new ResultPair(" abigail@example.com", true), new ResultPair("abigail @example.com ", true), new ResultPair("*@example.net", true), new ResultPair("\"\\\"\"@foo.bar", true), new ResultPair("fred&barny@example.com", true), new ResultPair("---@example.com", true), new ResultPair("foo-bar@example.net", true), new ResultPair("\"127.0.0.1\"@[127.0.0.1]", true), new ResultPair("Abigail <abigail@example.com>", true), new ResultPair("Abigail<abigail@example.com>", true), new ResultPair("Abigail<@a,@b,@c:abigail@example.com>", true), new ResultPair("\"This is a phrase\"<abigail@example.com>", true), new ResultPair("\"Abigail \"<abigail@example.com>", true), new ResultPair("\"Joe & J. Harvey\" <example @Org>", true), new ResultPair("Abigail <abigail @ example.com>", true), new ResultPair("Abigail made this <  abigail   @   example  .    com    >", true), new ResultPair("Abigail(the bitch)@example.com", true), new ResultPair("Abigail <abigail @ example . (bar) com >", true), new ResultPair("Abigail < (one)  abigail (two) @(three)example . (bar) com (quz) >", true), new ResultPair("Abigail (foo) (((baz)(nested) (comment)) ! ) < (one)  abigail (two) @(three)example . (bar) com (quz) >", true), new ResultPair("Abigail <abigail(fo\\(o)@example.com>", true), new ResultPair("Abigail <abigail(fo\\)o)@example.com> ", true), new ResultPair("(foo) abigail@example.com", true), new ResultPair("abigail@example.com (foo)", true), new ResultPair("\"Abi\\\"gail\" <abigail@example.com>", true), new ResultPair("abigail@[example.com]", true), new ResultPair("abigail@[exa\\[ple.com]", true), new ResultPair("abigail@[exa\\]ple.com]", true), new ResultPair("\":sysmail\"@  Some-Group. Some-Org", true), new ResultPair("Muhammed.(I am  the greatest) Ali @(the)Vegas.WBA", true), new ResultPair("mailbox.sub1.sub2@this-domain", true), new ResultPair("sub-net.mailbox@sub-domain.domain", true), new ResultPair("name:;", true), new ResultPair("':;", true), new ResultPair("name:   ;", true), new ResultPair("Alfred Neuman <Neuman@BBN-TENEXA>", true), new ResultPair("Neuman@BBN-TENEXA", true), new ResultPair("\"George, Ted\" <Shared@Group.Arpanet>", true), new ResultPair("Wilt . (the  Stilt) Chamberlain@NBA.US", true), new ResultPair("Cruisers:  Port@Portugal, Jones@SEA;", true), new ResultPair("$@[]", true), new ResultPair("*()@[]", true), new ResultPair("\"quoted ( brackets\" ( a comment )@example.com", true), new ResultPair("\"Joe & J. Harvey\"\\x0D\\x0A     <ddd\\@ Org>", true), new ResultPair("\"Joe &\\x0D\\x0A J. Harvey\" <ddd \\@ Org>", true), new ResultPair("Gourmets:  Pompous Person <WhoZiWhatZit\\@Cordon-Bleu>,\\x0D\\x0A        Childs\\@WGBH.Boston, \"Galloping Gourmet\"\\@\\x0D\\x0A        ANT.Down-Under (Australian National Television),\\x0D\\x0A        Cheapie\\@Discount-Liquors;", true), new ResultPair("   Just a string", false), new ResultPair(Var.JSTYPE_STRING, false), new ResultPair("(comment)", false), new ResultPair("()@example.com", false), new ResultPair("fred(&)barny@example.com", false), new ResultPair("fred\\ barny@example.com", false), new ResultPair("Abigail <abi gail @ example.com>", false), new ResultPair("Abigail <abigail(fo(o)@example.com>", false), new ResultPair("Abigail <abigail(fo)o)@example.com>", false), new ResultPair("\"Abi\"gail\" <abigail@example.com>", false), new ResultPair("abigail@[exa]ple.com]", false), new ResultPair("abigail@[exa[ple.com]", false), new ResultPair("abigail@[exaple].com]", false), new ResultPair("abigail@", false), new ResultPair("@example.com", false), new ResultPair("phrase: abigail@example.com abigail@example.com ;", false), new ResultPair("invalid�char@example.com", false)};
    private EmailValidator validator;

    @Before
    public void setUp() {
        this.validator = EmailValidator.getInstance();
    }

    @Test
    public void testEmail() {
        Assert.assertTrue(this.validator.isValid("jsmith@apache.org"));
    }

    @Test
    public void testEmailWithNumericAddress() {
        Assert.assertTrue(this.validator.isValid("someone@[216.109.118.76]"));
        Assert.assertTrue(this.validator.isValid("someone@yahoo.com"));
    }

    @Test
    public void testEmailExtension() {
        Assert.assertTrue(this.validator.isValid("jsmith@apache.org"));
        Assert.assertTrue(this.validator.isValid("jsmith@apache.com"));
        Assert.assertTrue(this.validator.isValid("jsmith@apache.net"));
        Assert.assertTrue(this.validator.isValid("jsmith@apache.info"));
        Assert.assertFalse(this.validator.isValid("jsmith@apache."));
        Assert.assertFalse(this.validator.isValid("jsmith@apache.c"));
        Assert.assertTrue(this.validator.isValid("someone@yahoo.museum"));
        Assert.assertFalse(this.validator.isValid("someone@yahoo.mu-seum"));
    }

    @Test
    public void testEmailWithDash() {
        Assert.assertTrue(this.validator.isValid("andy.noble@data-workshop.com"));
        Assert.assertFalse(this.validator.isValid("andy-noble@data-workshop.-com"));
        Assert.assertFalse(this.validator.isValid("andy-noble@data-workshop.c-om"));
        Assert.assertFalse(this.validator.isValid("andy-noble@data-workshop.co-m"));
    }

    @Test
    public void testEmailWithDotEnd() {
        Assert.assertFalse(this.validator.isValid("andy.noble@data-workshop.com."));
    }

    @Test
    public void testEmailWithBogusCharacter() {
        Assert.assertFalse(this.validator.isValid("andy.noble@data-workshop.com"));
        Assert.assertTrue(this.validator.isValid("andy.o'reilly@data-workshop.com"));
        Assert.assertFalse(this.validator.isValid("andy@o'reilly.data-workshop.com"));
        Assert.assertTrue(this.validator.isValid("foo+bar@i.am.not.in.us.example.com"));
        Assert.assertFalse(this.validator.isValid("foo+bar@example+3.com"));
        Assert.assertFalse(this.validator.isValid("test@%*.com"));
        Assert.assertFalse(this.validator.isValid("test@^&#.com"));
    }

    @Test
    public void testVALIDATOR_315() {
        Assert.assertFalse(this.validator.isValid("me@at&t.net"));
        Assert.assertTrue(this.validator.isValid("me@att.net"));
    }

    @Test
    public void testVALIDATOR_278() {
        Assert.assertFalse(this.validator.isValid("someone@-test.com"));
        Assert.assertFalse(this.validator.isValid("someone@test-.com"));
    }

    @Test
    public void testValidator235() {
        if (System.getProperty("java.version").compareTo("1.6") < 0) {
            System.out.println("Cannot run Unicode IDN tests");
            return;
        }
        Assert.assertTrue("xn--d1abbgf6aiiy.xn--p1ai should validate", this.validator.isValid("someone@xn--d1abbgf6aiiy.xn--p1ai"));
        Assert.assertTrue("президент.рф should validate", this.validator.isValid("someone@президент.рф"));
        Assert.assertTrue("www.bücher.ch should validate", this.validator.isValid("someone@www.bücher.ch"));
        Assert.assertFalse("www.�.ch FFFD should fail", this.validator.isValid("someone@www.�.ch"));
        Assert.assertTrue("www.bücher.ch should validate", this.validator.isValid("someone@www.bücher.ch"));
        Assert.assertFalse("www.�.ch FFFD should fail", this.validator.isValid("someone@www.�.ch"));
    }

    @Test
    public void testEmailWithCommas() {
        Assert.assertFalse(this.validator.isValid("joeblow@apa,che.org"));
        Assert.assertFalse(this.validator.isValid("joeblow@apache.o,rg"));
        Assert.assertFalse(this.validator.isValid("joeblow@apache,org"));
    }

    @Test
    public void testEmailWithSpaces() {
        Assert.assertFalse(this.validator.isValid("joeblow @apache.org"));
        Assert.assertFalse(this.validator.isValid("joeblow@ apache.org"));
        Assert.assertFalse(this.validator.isValid(" joeblow@apache.org"));
        Assert.assertFalse(this.validator.isValid("joeblow@apache.org "));
        Assert.assertFalse(this.validator.isValid("joe blow@apache.org "));
        Assert.assertFalse(this.validator.isValid("joeblow@apa che.org "));
        Assert.assertTrue(this.validator.isValid("\"joeblow \"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\" joeblow\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\" joe blow \"@apache.org"));
    }

    @Test
    public void testEmailWithControlChars() {
        for (char c = 0; c < ' '; c = (char) (c + 1)) {
            Assert.assertFalse("Test control char " + ((int) c), this.validator.isValid("foo" + c + "bar@domain.com"));
        }
        Assert.assertFalse("Test control char 127", this.validator.isValid("foobar@domain.com"));
    }

    @Test
    public void testEmailLocalhost() {
        EmailValidator noLocal = EmailValidator.getInstance(false);
        EmailValidator allowLocal = EmailValidator.getInstance(true);
        Assert.assertEquals(this.validator, noLocal);
        Assert.assertTrue("@localhost.localdomain should be accepted but wasn't", allowLocal.isValid("joe@localhost.localdomain"));
        Assert.assertTrue("@localhost should be accepted but wasn't", allowLocal.isValid("joe@localhost"));
        Assert.assertFalse("@localhost.localdomain should be accepted but wasn't", noLocal.isValid("joe@localhost.localdomain"));
        Assert.assertFalse("@localhost should be accepted but wasn't", noLocal.isValid("joe@localhost"));
    }

    @Test
    public void testEmailWithSlashes() {
        Assert.assertTrue("/ and ! valid in username", this.validator.isValid("joe!/blow@apache.org"));
        Assert.assertFalse("/ not valid in domain", this.validator.isValid("joe@ap/ache.org"));
        Assert.assertFalse("! not valid in domain", this.validator.isValid("joe@apac!he.org"));
    }

    @Test
    public void testEmailUserName() {
        Assert.assertTrue(this.validator.isValid("joe1blow@apache.org"));
        Assert.assertTrue(this.validator.isValid("joe$blow@apache.org"));
        Assert.assertTrue(this.validator.isValid("joe-@apache.org"));
        Assert.assertTrue(this.validator.isValid("joe_@apache.org"));
        Assert.assertTrue(this.validator.isValid("joe+@apache.org"));
        Assert.assertTrue(this.validator.isValid("joe!@apache.org"));
        Assert.assertTrue(this.validator.isValid("joe*@apache.org"));
        Assert.assertTrue(this.validator.isValid("joe'@apache.org"));
        Assert.assertTrue(this.validator.isValid("joe%45@apache.org"));
        Assert.assertTrue(this.validator.isValid("joe?@apache.org"));
        Assert.assertTrue(this.validator.isValid("joe&@apache.org"));
        Assert.assertTrue(this.validator.isValid("joe=@apache.org"));
        Assert.assertTrue(this.validator.isValid("+joe@apache.org"));
        Assert.assertTrue(this.validator.isValid("!joe@apache.org"));
        Assert.assertTrue(this.validator.isValid("*joe@apache.org"));
        Assert.assertTrue(this.validator.isValid("'joe@apache.org"));
        Assert.assertTrue(this.validator.isValid("%joe45@apache.org"));
        Assert.assertTrue(this.validator.isValid("?joe@apache.org"));
        Assert.assertTrue(this.validator.isValid("&joe@apache.org"));
        Assert.assertTrue(this.validator.isValid("=joe@apache.org"));
        Assert.assertTrue(this.validator.isValid("+@apache.org"));
        Assert.assertTrue(this.validator.isValid("!@apache.org"));
        Assert.assertTrue(this.validator.isValid("*@apache.org"));
        Assert.assertTrue(this.validator.isValid("'@apache.org"));
        Assert.assertTrue(this.validator.isValid("%@apache.org"));
        Assert.assertTrue(this.validator.isValid("?@apache.org"));
        Assert.assertTrue(this.validator.isValid("&@apache.org"));
        Assert.assertTrue(this.validator.isValid("=@apache.org"));
        Assert.assertFalse(this.validator.isValid("joe.@apache.org"));
        Assert.assertFalse(this.validator.isValid(".joe@apache.org"));
        Assert.assertFalse(this.validator.isValid(".@apache.org"));
        Assert.assertTrue(this.validator.isValid("joe.ok@apache.org"));
        Assert.assertFalse(this.validator.isValid("joe..ok@apache.org"));
        Assert.assertFalse(this.validator.isValid("..@apache.org"));
        Assert.assertFalse(this.validator.isValid("joe(@apache.org"));
        Assert.assertFalse(this.validator.isValid("joe)@apache.org"));
        Assert.assertFalse(this.validator.isValid("joe,@apache.org"));
        Assert.assertFalse(this.validator.isValid("joe;@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe.\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\".joe\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe+\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe@\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe!\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe*\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe'\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe(\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe)\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe,\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe%45\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe;\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe?\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe&\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"joe=\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"..\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("\"john\\\"doe\"@apache.org"));
        Assert.assertTrue(this.validator.isValid("john56789.john56789.john56789.john56789.john56789.john56789.john@example.com"));
        Assert.assertFalse(this.validator.isValid("john56789.john56789.john56789.john56789.john56789.john56789.john5@example.com"));
        Assert.assertTrue(this.validator.isValid("\\>escape\\\\special\\^characters\\<@example.com"));
        Assert.assertTrue(this.validator.isValid("Abc\\@def@example.com"));
        Assert.assertFalse(this.validator.isValid("Abc@def@example.com"));
        Assert.assertTrue(this.validator.isValid("space\\ monkey@example.com"));
    }

    @Test
    @Ignore("VALIDATOR-267")
    public void testEmailFromPerl() {
        int errors = 0;
        int index = 0;
        while (true) {
            ResultPair[] resultPairArr = testEmailFromPerl;
            if (index < resultPairArr.length) {
                String item = resultPairArr[index].item;
                boolean exp = resultPairArr[index].valid;
                boolean act = this.validator.isValid(item);
                if (act != exp) {
                    System.out.printf("%s: expected %s actual %s%n", item, Boolean.valueOf(exp), Boolean.valueOf(act));
                    errors++;
                }
                index++;
            } else {
                Assert.assertEquals("Expected 0 errors", 0, (long) errors);
                return;
            }
        }
    }

    @Test
    public void testValidator293() {
        Assert.assertTrue(this.validator.isValid("abc-@abc.com"));
        Assert.assertTrue(this.validator.isValid("abc_@abc.com"));
        Assert.assertTrue(this.validator.isValid("abc-def@abc.com"));
        Assert.assertTrue(this.validator.isValid("abc_def@abc.com"));
        Assert.assertFalse(this.validator.isValid("abc@abc_def.com"));
    }

    @Test
    public void testValidator365() {
        Assert.assertFalse(this.validator.isValid("Loremipsumdolorsitametconsecteturadipiscingelit.Nullavitaeligulamattisrhoncusnuncegestasmattisleo.Donecnonsapieninmagnatristiquedictumaacturpis.Fusceorciduifacilisisutsapieneuconsequatpharetralectus.Quisqueenimestpulvinarutquamvitaeportamattisex.Nullamquismaurisplaceratconvallisjustoquisportamauris.Innullalacusconvalliseufringillautvenenatissitametdiam.Maecenasluctusligulascelerisquepulvinarfeugiat.Sedmolestienullaaliquetorciluctusidpharetranislfinibus.Suspendissemalesuadatinciduntduisitametportaarcusollicitudinnec.Donecetmassamagna.Curabitururnadiampretiumveldignissimporttitorfringillaeuneque.Duisantetelluspharetraidtinciduntinterdummolestiesitametfelis.Utquisquamsitametantesagittisdapibusacnonodio.Namrutrummolestiediamidmattis.Cumsociisnatoquepenatibusetmagnisdisparturientmontesnasceturridiculusmus.Morbiposueresedmetusacconsectetur.Etiamquisipsumvitaejustotempusmaximus.Sedultriciesplaceratvolutpat.Integerlacuslectusmaximusacornarequissagittissitametjusto.Cumsociisnatoquepenatibusetmagnisdisparturientmontesnasceturridiculusmus.Maecenasindictumpurussedrutrumex.Nullafacilisi.Integerfinibusfinibusmietpharetranislfaucibusvel.Maecenasegetdolorlacinialobortisjustovelullamcorpersem.Vivamusaliquetpurusidvariusornaresapienrisusrutrumnisitinciduntmollissemnequeidmetus.Etiamquiseleifendpurus.Nuncfelisnuncscelerisqueiddignissimnecfinibusalibero.Nuncsemperenimnequesitamethendreritpurusfacilisisac.Maurisdapibussemperfelisdignissimgravida.Aeneanultricesblanditnequealiquamfinibusodioscelerisqueac.Aliquamnecmassaeumaurisfaucibusfringilla.Etiamconsequatligulanisisitametaliquamnibhtemporquis.Nuncinterdumdignissimnullaatsodalesarcusagittiseu.Proinpharetrametusneclacuspulvinarsedvolutpatliberoornare.Sedligulanislpulvinarnonlectuseublanditfacilisisante.Sedmollisnislalacusauctorsuscipit.Inhachabitasseplateadictumst.Phasellussitametvelittemporvenenatisfeliseuegestasrisus.Aliquameteratsitametnibhcommodofinibus.Morbiefficiturodiovelpulvinariaculis.Aeneantemporipsummassaaconsecteturturpisfaucibusultrices.Praesentsodalesmaurisquisportafermentum.Etiamnisinislvenenatisvelauctorutullamcorperinjusto.Proinvelligulaerat.Phasellusvestibulumgravidamassanonfeugiat.Maecenaspharetraeuismodmetusegetefficitur.Suspendisseamet@gmail.com"));
    }

    @Test
    public void testEmailAtTLD() {
        Assert.assertTrue(EmailValidator.getInstance(false, true).isValid("test@com"));
    }

    @Test
    public void testValidator359() {
        Assert.assertFalse(EmailValidator.getInstance(false, true).isValid("test@.com"));
    }

    @Test
    public void testValidator374() {
        Assert.assertTrue(this.validator.isValid("abc@school.school"));
    }

    @Test(expected = IllegalArgumentException.class)
    public void testValidator473_1() {
        new EmailValidator(false, false, null);
    }

    @Test(expected = IllegalArgumentException.class)
    public void testValidator473_2() {
        new EmailValidator(false, false, DomainValidator.getInstance(true, new ArrayList<>()));
    }

    @Test(expected = IllegalArgumentException.class)
    public void testValidator473_3() {
        new EmailValidator(true, false, DomainValidator.getInstance(false, new ArrayList<>()));
    }

    @Test
    public void testValidator473_4() {
        Assert.assertFalse(this.validator.isValidDomain("test.local"));
        List<DomainValidator.Item> items = new ArrayList<>();
        items.add(new DomainValidator.Item(DomainValidator.ArrayType.GENERIC_PLUS, new String[]{"local"}));
        Assert.assertTrue(new EmailValidator(true, false, DomainValidator.getInstance(true, items)).isValidDomain("test.local"));
    }

    public static void main(String[] args) {
        EmailValidator validator2 = EmailValidator.getInstance();
        for (String arg : args) {
            System.out.printf("%s: %s%n", arg, Boolean.valueOf(validator2.isValid(arg)));
        }
    }
}
