package org.apache.commons.validator.routines;

import java.text.DecimalFormat;
import java.util.Locale;

public class FloatValidatorTest extends AbstractNumberValidatorTest {
    public FloatValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractNumberValidatorTest
    public void setUp() throws Exception {
        super.setUp();
        this.validator = new FloatValidator(false, 0);
        this.strictValidator = new FloatValidator();
        this.testPattern = "#,###.#";
        this.max = Float.valueOf(Float.MAX_VALUE);
        this.maxPlusOne = Double.valueOf(this.max.doubleValue() * 10.0d);
        this.min = Float.valueOf(-3.4028235E38f);
        this.minMinusOne = Double.valueOf(this.min.doubleValue() * 10.0d);
        this.invalidStrict = new String[]{null, "", "X", "X12", "12X", "1X2"};
        this.invalid = new String[]{null, "", "X", "X12"};
        this.testNumber = Float.valueOf(1234.5f);
        this.testZero = Float.valueOf(0.0f);
        this.validStrict = new String[]{"0", "1234.5", "1,234.5"};
        this.validStrictCompare = new Number[]{this.testZero, this.testNumber, this.testNumber};
        this.valid = new String[]{"0", "1234.5", "1,234.5", "1,234.5", "1234.5X"};
        this.validCompare = new Number[]{this.testZero, this.testNumber, this.testNumber, this.testNumber, this.testNumber};
        this.testStringUS = "1,234.5";
        this.testStringDE = "1.234,5";
        this.localeValue = this.testStringDE;
        this.localePattern = "#.###,#";
        this.testLocale = Locale.GERMANY;
        this.localeExpected = this.testNumber;
    }

    public void testFloatValidatorMethods() {
        Locale locale = Locale.GERMAN;
        Float expected = Float.valueOf(12345.0f);
        assertEquals("validate(A) default", expected, FloatValidator.getInstance().validate("12,345"));
        assertEquals("validate(A) locale ", expected, FloatValidator.getInstance().validate("12.345", locale));
        assertEquals("validate(A) pattern", expected, FloatValidator.getInstance().validate("1,23,45", "0,00,00"));
        assertEquals("validate(A) both", expected, FloatValidator.getInstance().validate("1.23.45", "0,00,00", Locale.GERMAN));
        assertTrue("isValid(A) default", FloatValidator.getInstance().isValid("12,345"));
        assertTrue("isValid(A) locale ", FloatValidator.getInstance().isValid("12.345", locale));
        assertTrue("isValid(A) pattern", FloatValidator.getInstance().isValid("1,23,45", "0,00,00"));
        assertTrue("isValid(A) both", FloatValidator.getInstance().isValid("1.23.45", "0,00,00", Locale.GERMAN));
        assertNull("validate(B) default", FloatValidator.getInstance().validate("XXXX"));
        assertNull("validate(B) locale ", FloatValidator.getInstance().validate("XXXX", locale));
        assertNull("validate(B) pattern", FloatValidator.getInstance().validate("XXXX", "0,00,00"));
        assertNull("validate(B) both", FloatValidator.getInstance().validate("1,23,45", "0,00,00", Locale.GERMAN));
        assertFalse("isValid(B) default", FloatValidator.getInstance().isValid("XXXX"));
        assertFalse("isValid(B) locale ", FloatValidator.getInstance().isValid("XXXX", locale));
        assertFalse("isValid(B) pattern", FloatValidator.getInstance().isValid("XXXX", "0,00,00"));
        assertFalse("isValid(B) both", FloatValidator.getInstance().isValid("1,23,45", "0,00,00", Locale.GERMAN));
    }

    public void testFloatSmallestValues() {
        DecimalFormat fmt = new DecimalFormat("#.#################################################################");
        Float smallestPositive = Float.valueOf(Float.MIN_VALUE);
        assertEquals("Smallest +ve", smallestPositive, FloatValidator.getInstance().validate(fmt.format(smallestPositive), "#.#################################################################"));
        Float smallestNegative = Float.valueOf(-1.4E-45f);
        assertEquals("Smallest -ve", smallestNegative, FloatValidator.getInstance().validate(fmt.format(smallestNegative), "#.#################################################################"));
        Double tooSmallPositive = Double.valueOf(1.4012984643248171E-46d);
        assertFalse("Too small +ve", FloatValidator.getInstance().isValid(fmt.format(tooSmallPositive), "#.#################################################################"));
        assertFalse("Too small -ve", FloatValidator.getInstance().isValid(fmt.format(Double.valueOf(tooSmallPositive.doubleValue() * -1.0d)), "#.#################################################################"));
    }

    public void testFloatRangeMinMax() {
        FloatValidator validator = (FloatValidator) this.strictValidator;
        Float number9 = validator.validate("9", "#");
        Float number10 = validator.validate("10", "#");
        Float number11 = validator.validate("11", "#");
        Float number19 = validator.validate("19", "#");
        Float number20 = validator.validate("20", "#");
        Float number21 = validator.validate("21", "#");
        assertFalse("isInRange() < min", validator.isInRange(number9, 10.0f, 20.0f));
        assertTrue("isInRange() = min", validator.isInRange(number10, 10.0f, 20.0f));
        assertTrue("isInRange() in range", validator.isInRange(number11, 10.0f, 20.0f));
        assertTrue("isInRange() = max", validator.isInRange(number20, 10.0f, 20.0f));
        assertFalse("isInRange() > max", validator.isInRange(number21, 10.0f, 20.0f));
        assertFalse("minValue() < min", validator.minValue(number9, 10.0f));
        assertTrue("minValue() = min", validator.minValue(number10, 10.0f));
        assertTrue("minValue() > min", validator.minValue(number11, 10.0f));
        assertTrue("maxValue() < max", validator.maxValue(number19, 20.0f));
        assertTrue("maxValue() = max", validator.maxValue(number20, 20.0f));
        assertFalse("maxValue() > max", validator.maxValue(number21, 20.0f));
    }
}
