package org.apache.commons.validator.routines;

import java.util.regex.Pattern;
import junit.framework.TestCase;

public class ISBNValidatorTest extends TestCase {
    private final String[] invalidISBN10Format = {"", "   ", "1", "123456789", "12345678901", "12345678X0", "123456-1234567-123456-X", "12345-12345678-123456-X", "12345-1234567-1234567-X", "12345-1234567-123456-X2", "--1 930110 99 5", "1 930110 99 5--", "1 930110-99 5-", "1.2.3.4", "1=2=3=4", "1_2_3_4", "123456789Y", "dsasdsadsa", "I love sparrows!", "068-556-98-45"};
    private final String[] invalidISBN13Format = {"", "   ", "1", "978123456789", "97812345678901", "978-123456-1234567-123456-1", "978-12345-12345678-123456-1", "978-12345-1234567-1234567-1", "978-12345-1234567-123456-12", "--978 1 930110 99 1", "978 1 930110 99 1--", "978 1 930110-99 1-", "123-4-567890-12-8", "978.1.2.3.4", "978=1=2=3=4", "978_1_2_3_4", "978123456789X", "978-0-201-63385-X", "dsasdsadsadsa", "I love sparrows!", "979-1-234-567-89-6"};
    private final String[] validISBN10Format = {"1234567890", "123456789X", "12345-1234567-123456-X", "12345 1234567 123456 X", "1-2-3-4", "1 2 3 4"};
    private final String[] validISBN13Format = {"9781234567890", "9791234567890", "978-12345-1234567-123456-1", "979-12345-1234567-123456-1", "978 12345 1234567 123456 1", "979 12345 1234567 123456 1", "978-1-2-3-4", "979-1-2-3-4", "978 1 2 3 4", "979 1 2 3 4"};

    public ISBNValidatorTest(String name) {
        super(name);
    }

    public void testValidISBN10Format() {
        Pattern pattern = Pattern.compile("^(?:(\\d{9}[0-9X])|(?:(\\d{1,5})(?:\\-|\\s)(\\d{1,7})(?:\\-|\\s)(\\d{1,6})(?:\\-|\\s)([0-9X])))$");
        for (int i = 0; i < this.validISBN10Format.length; i++) {
            assertTrue("Pattern[" + i + "]=" + this.validISBN10Format[i], pattern.matcher(this.validISBN10Format[i]).matches());
        }
    }

    public void testInvalidISBN10Format() {
        ISBNValidator validator = ISBNValidator.getInstance();
        Pattern pattern = Pattern.compile("^(?:(\\d{9}[0-9X])|(?:(\\d{1,5})(?:\\-|\\s)(\\d{1,7})(?:\\-|\\s)(\\d{1,6})(?:\\-|\\s)([0-9X])))$");
        for (int i = 0; i < this.invalidISBN10Format.length; i++) {
            assertFalse("Pattern[" + i + "]=" + this.invalidISBN10Format[i], pattern.matcher(this.invalidISBN10Format[i]).matches());
            assertFalse("isValidISBN10[" + i + "]=" + this.invalidISBN10Format[i], validator.isValidISBN10(this.invalidISBN10Format[i]));
            assertNull("validateISBN10[" + i + "]=" + this.invalidISBN10Format[i], validator.validateISBN10(this.invalidISBN10Format[i]));
        }
    }

    public void testValidISBN13Format() {
        Pattern pattern = Pattern.compile("^(978|979)(?:(\\d{10})|(?:(?:\\-|\\s)(\\d{1,5})(?:\\-|\\s)(\\d{1,7})(?:\\-|\\s)(\\d{1,6})(?:\\-|\\s)([0-9])))$");
        for (int i = 0; i < this.validISBN13Format.length; i++) {
            assertTrue("Pattern[" + i + "]=" + this.validISBN13Format[i], pattern.matcher(this.validISBN13Format[i]).matches());
        }
    }

    public void testInvalidISBN13Format() {
        Pattern pattern = Pattern.compile("^(978|979)(?:(\\d{10})|(?:(?:\\-|\\s)(\\d{1,5})(?:\\-|\\s)(\\d{1,7})(?:\\-|\\s)(\\d{1,6})(?:\\-|\\s)([0-9])))$");
        ISBNValidator validator = ISBNValidator.getInstance();
        for (int i = 0; i < this.invalidISBN13Format.length; i++) {
            assertFalse("Pattern[" + i + "]=" + this.invalidISBN13Format[i], pattern.matcher(this.invalidISBN13Format[i]).matches());
            assertFalse("isValidISBN13[" + i + "]=" + this.invalidISBN13Format[i], validator.isValidISBN13(this.invalidISBN13Format[i]));
            assertNull("validateISBN13[" + i + "]=" + this.invalidISBN13Format[i], validator.validateISBN13(this.invalidISBN13Format[i]));
        }
    }

    public void testIsValidISBN10() {
        ISBNValidator validator = ISBNValidator.getInstance();
        assertTrue("isValidISBN10-1", validator.isValidISBN10("1930110995"));
        assertTrue("isValidISBN10-2", validator.isValidISBN10("1-930110-99-5"));
        assertTrue("isValidISBN10-3", validator.isValidISBN10("1 930110 99 5"));
        assertTrue("isValidISBN10-4", validator.isValidISBN10("020163385X"));
        assertTrue("isValidISBN10-5", validator.isValidISBN10("0-201-63385-X"));
        assertTrue("isValidISBN10-6", validator.isValidISBN10("0 201 63385 X"));
        assertTrue("isValid-1", validator.isValid("1930110995"));
        assertTrue("isValid-2", validator.isValid("1-930110-99-5"));
        assertTrue("isValid-3", validator.isValid("1 930110 99 5"));
        assertTrue("isValid-4", validator.isValid("020163385X"));
        assertTrue("isValid-5", validator.isValid("0-201-63385-X"));
        assertTrue("isValid-6", validator.isValid("0 201 63385 X"));
    }

    public void testIsValidISBN13() {
        ISBNValidator validator = ISBNValidator.getInstance();
        assertTrue("isValidISBN13-1", validator.isValidISBN13("9781930110991"));
        assertTrue("isValidISBN13-2", validator.isValidISBN13("978-1-930110-99-1"));
        assertTrue("isValidISBN13-3", validator.isValidISBN13("978 1 930110 99 1"));
        assertTrue("isValidISBN13-4", validator.isValidISBN13("9780201633856"));
        assertTrue("isValidISBN13-5", validator.isValidISBN13("978-0-201-63385-6"));
        assertTrue("isValidISBN13-6", validator.isValidISBN13("978 0 201 63385 6"));
        assertTrue("isValid-1", validator.isValid("9781930110991"));
        assertTrue("isValid-2", validator.isValid("978-1-930110-99-1"));
        assertTrue("isValid-3", validator.isValid("978 1 930110 99 1"));
        assertTrue("isValid-4", validator.isValid("9780201633856"));
        assertTrue("isValid-5", validator.isValid("978-0-201-63385-6"));
        assertTrue("isValid-6", validator.isValid("978 0 201 63385 6"));
    }

    public void testValidateISBN10() {
        ISBNValidator validator = ISBNValidator.getInstance(false);
        assertEquals("validateISBN10-1", "1930110995", validator.validateISBN10("1930110995"));
        assertEquals("validateISBN10-2", "1930110995", validator.validateISBN10("1-930110-99-5"));
        assertEquals("validateISBN10-3", "1930110995", validator.validateISBN10("1 930110 99 5"));
        assertEquals("validateISBN10-4", "020163385X", validator.validateISBN10("020163385X"));
        assertEquals("validateISBN10-5", "020163385X", validator.validateISBN10("0-201-63385-X"));
        assertEquals("validateISBN10-6", "020163385X", validator.validateISBN10("0 201 63385 X"));
        assertEquals("validate-1", "1930110995", validator.validate("1930110995"));
        assertEquals("validate-2", "1930110995", validator.validate("1-930110-99-5"));
        assertEquals("validate-3", "1930110995", validator.validate("1 930110 99 5"));
        assertEquals("validate-4", "020163385X", validator.validate("020163385X"));
        assertEquals("validate-5", "020163385X", validator.validate("0-201-63385-X"));
        assertEquals("validate-6", "020163385X", validator.validate("0 201 63385 X"));
    }

    public void testValidateISBN10Convert() {
        ISBNValidator validator = ISBNValidator.getInstance();
        assertEquals("validate-1", "9781930110991", validator.validate("1930110995"));
        assertEquals("validate-2", "9781930110991", validator.validate("1-930110-99-5"));
        assertEquals("validate-3", "9781930110991", validator.validate("1 930110 99 5"));
        assertEquals("validate-4", "9780201633856", validator.validate("020163385X"));
        assertEquals("validate-5", "9780201633856", validator.validate("0-201-63385-X"));
        assertEquals("validate-6", "9780201633856", validator.validate("0 201 63385 X"));
    }

    public void testValidateISBN13() {
        ISBNValidator validator = ISBNValidator.getInstance();
        assertEquals("validateISBN13-1", "9781930110991", validator.validateISBN13("9781930110991"));
        assertEquals("validateISBN13-2", "9781930110991", validator.validateISBN13("978-1-930110-99-1"));
        assertEquals("validateISBN13-3", "9781930110991", validator.validateISBN13("978 1 930110 99 1"));
        assertEquals("validateISBN13-4", "9780201633856", validator.validateISBN13("9780201633856"));
        assertEquals("validateISBN13-5", "9780201633856", validator.validateISBN13("978-0-201-63385-6"));
        assertEquals("validateISBN13-6", "9780201633856", validator.validateISBN13("978 0 201 63385 6"));
        assertEquals("validate-1", "9781930110991", validator.validate("9781930110991"));
        assertEquals("validate-2", "9781930110991", validator.validate("978-1-930110-99-1"));
        assertEquals("validate-3", "9781930110991", validator.validate("978 1 930110 99 1"));
        assertEquals("validate-4", "9780201633856", validator.validate("9780201633856"));
        assertEquals("validate-5", "9780201633856", validator.validate("978-0-201-63385-6"));
        assertEquals("validate-6", "9780201633856", validator.validate("978 0 201 63385 6"));
    }

    public void testNull() {
        ISBNValidator validator = ISBNValidator.getInstance();
        assertFalse("isValid", validator.isValid(null));
        assertFalse("isValidISBN10", validator.isValidISBN10(null));
        assertFalse("isValidISBN13", validator.isValidISBN13(null));
        assertNull("validate", validator.validate(null));
        assertNull("validateISBN10", validator.validateISBN10(null));
        assertNull("validateISBN13", validator.validateISBN13(null));
        assertNull("convertToISBN13", validator.convertToISBN13(null));
    }

    public void testInvalid() {
        ISBNValidator validator = ISBNValidator.getInstance();
        assertFalse("ISBN10-0", validator.isValid("193011099" + "0"));
        assertFalse("ISBN10-1", validator.isValid("193011099" + "1"));
        assertFalse("ISBN10-2", validator.isValid("193011099" + "2"));
        assertFalse("ISBN10-3", validator.isValid("193011099" + "3"));
        assertFalse("ISBN10-4", validator.isValid("193011099" + "4"));
        assertTrue("ISBN10-5", validator.isValid("193011099" + "5"));
        assertFalse("ISBN10-6", validator.isValid("193011099" + "6"));
        assertFalse("ISBN10-7", validator.isValid("193011099" + "7"));
        assertFalse("ISBN10-8", validator.isValid("193011099" + "8"));
        assertFalse("ISBN10-9", validator.isValid("193011099" + "9"));
        assertFalse("ISBN10-X", validator.isValid("193011099" + "X"));
        assertFalse("ISBN13-0", validator.isValid("978193011099" + "0"));
        assertTrue("ISBN13-1", validator.isValid("978193011099" + "1"));
        assertFalse("ISBN13-2", validator.isValid("978193011099" + "2"));
        assertFalse("ISBN13-3", validator.isValid("978193011099" + "3"));
        assertFalse("ISBN13-4", validator.isValid("978193011099" + "4"));
        assertFalse("ISBN13-5", validator.isValid("978193011099" + "5"));
        assertFalse("ISBN13-6", validator.isValid("978193011099" + "6"));
        assertFalse("ISBN13-7", validator.isValid("978193011099" + "7"));
        assertFalse("ISBN13-8", validator.isValid("978193011099" + "8"));
        assertFalse("ISBN13-9", validator.isValid("978193011099" + "9"));
    }

    public void testConversionErrors() {
        ISBNValidator validator = ISBNValidator.getInstance();
        try {
            validator.convertToISBN13("123456789 ");
            fail("Expected IllegalArgumentException for '" + "123456789 " + "'");
        } catch (IllegalArgumentException e) {
        }
        try {
            validator.convertToISBN13("12345678901");
            fail("Expected IllegalArgumentException for '" + "12345678901" + "'");
        } catch (IllegalArgumentException e2) {
        }
        try {
            validator.convertToISBN13("");
            fail("Expected IllegalArgumentException for '" + "" + "'");
        } catch (IllegalArgumentException e3) {
        }
        try {
            validator.convertToISBN13("X234567890");
            fail("Expected IllegalArgumentException for '" + "X234567890" + "'");
        } catch (IllegalArgumentException e4) {
        }
    }
}
