package org.apache.commons.validator.routines;

import java.util.Random;
import junit.framework.TestCase;
import org.apache.commons.validator.routines.checkdigit.CheckDigit;
import org.apache.commons.validator.routines.checkdigit.EAN13CheckDigit;

public class ISSNValidatorTest extends TestCase {
    private static final ISSNValidator VALIDATOR = ISSNValidator.getInstance();
    private final String[] invalidFormat = {"", "   ", "ISBN 0317-8471", "'1050-124X", "ISSN1562-6865", "10637710", "1748-7188'", "ISSN  0264-2875", "1750 0095", "1188_1534", "1911-1478"};
    private final String[] validFormat = {"ISSN 0317-8471", "1050-124X", "ISSN 1562-6865", "1063-7710", "1748-7188", "ISSN 0264-2875", "1750-0095", "1188-1534", "1911-1479", "ISSN 1911-1460", "0001-6772", "1365-201X", "0264-3596", "1144-875X"};

    public ISSNValidatorTest(String name) {
        super(name);
    }

    public void testIsValidISSN() {
        String[] arr$ = this.validFormat;
        for (String f : arr$) {
            assertTrue(f, VALIDATOR.isValid(f));
        }
    }

    public void testNull() {
        assertFalse("isValid", VALIDATOR.isValid(null));
    }

    public void testInvalid() {
        String[] arr$ = this.invalidFormat;
        for (String f : arr$) {
            assertFalse(f, VALIDATOR.isValid(f));
        }
    }

    public void testIsValidISSNConvertNull() {
        assertNull(VALIDATOR.convertToEAN13(null, "00"));
    }

    public void testIsValidISSNConvertSuffix() {
        try {
            assertNull(VALIDATOR.convertToEAN13(null, null));
            fail("Expected IllegalArgumentException");
        } catch (IllegalArgumentException e) {
        }
        try {
            assertNull(VALIDATOR.convertToEAN13(null, ""));
            fail("Expected IllegalArgumentException");
        } catch (IllegalArgumentException e2) {
        }
        try {
            assertNull(VALIDATOR.convertToEAN13(null, "0"));
            fail("Expected IllegalArgumentException");
        } catch (IllegalArgumentException e3) {
        }
        try {
            assertNull(VALIDATOR.convertToEAN13(null, "A"));
            fail("Expected IllegalArgumentException");
        } catch (IllegalArgumentException e4) {
        }
        try {
            assertNull(VALIDATOR.convertToEAN13(null, "AA"));
            fail("Expected IllegalArgumentException");
        } catch (IllegalArgumentException e5) {
        }
        try {
            assertNull(VALIDATOR.convertToEAN13(null, "999"));
            fail("Expected IllegalArgumentException");
        } catch (IllegalArgumentException e6) {
        }
    }

    public void testIsValidISSNConvert() {
        CheckDigit ean13cd = EAN13CheckDigit.EAN13_CHECK_DIGIT;
        Random r = new Random();
        for (String f : this.validFormat) {
            String ean13 = VALIDATOR.convertToEAN13(f, String.format("%02d", Integer.valueOf(r.nextInt(100))));
            assertTrue(ean13, ean13cd.isValid(ean13));
        }
        ISSNValidator iSSNValidator = VALIDATOR;
        assertEquals("9771144875007", iSSNValidator.convertToEAN13("1144-875X", "00"));
        assertEquals("9770264359008", iSSNValidator.convertToEAN13("0264-3596", "00"));
        assertEquals("9771234567003", iSSNValidator.convertToEAN13("1234-5679", "00"));
    }

    public void testConversionErrors() {
        try {
            VALIDATOR.extractFromEAN13("9780072129519");
            fail("Expected IllegalArgumentException for '" + "9780072129519" + "'");
        } catch (IllegalArgumentException e) {
        }
        try {
            VALIDATOR.extractFromEAN13("9791090636071");
            fail("Expected IllegalArgumentException for '" + "9791090636071" + "'");
        } catch (IllegalArgumentException e2) {
        }
        try {
            VALIDATOR.extractFromEAN13("03178471");
            fail("Expected IllegalArgumentException for '" + "03178471" + "'");
        } catch (IllegalArgumentException e3) {
        }
    }

    public void testValidCheckDigitEan13() {
        ISSNValidator iSSNValidator = VALIDATOR;
        assertNull(iSSNValidator.extractFromEAN13("9771234567001"));
        assertNull(iSSNValidator.extractFromEAN13("9771234567002"));
        assertNotNull(iSSNValidator.extractFromEAN13("9771234567003"));
        assertNull(iSSNValidator.extractFromEAN13("9771234567004"));
        assertNull(iSSNValidator.extractFromEAN13("9771234567005"));
        assertNull(iSSNValidator.extractFromEAN13("9771234567006"));
        assertNull(iSSNValidator.extractFromEAN13("9771234567007"));
        assertNull(iSSNValidator.extractFromEAN13("9771234567008"));
        assertNull(iSSNValidator.extractFromEAN13("9771234567009"));
        assertNull(iSSNValidator.extractFromEAN13("9771234567000"));
    }

    public void testIsValidExtract() {
        ISSNValidator iSSNValidator = VALIDATOR;
        assertEquals("12345679", iSSNValidator.extractFromEAN13("9771234567003"));
        assertEquals("00014664", iSSNValidator.extractFromEAN13("9770001466006"));
        assertEquals("03178471", iSSNValidator.extractFromEAN13("9770317847001"));
        assertEquals("1144875X", iSSNValidator.extractFromEAN13("9771144875007"));
    }
}
