package org.apache.commons.validator.routines;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class InetAddressValidator implements Serializable {
    private static final int BASE_16 = 16;
    private static final int IPV4_MAX_OCTET_VALUE = 255;
    private static final String IPV4_REGEX = "^(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})$";
    private static final int IPV6_MAX_HEX_DIGITS_PER_GROUP = 4;
    private static final int IPV6_MAX_HEX_GROUPS = 8;
    private static final int MAX_UNSIGNED_SHORT = 65535;
    private static final InetAddressValidator VALIDATOR = new InetAddressValidator();
    private static final long serialVersionUID = -919201640201914789L;
    private final RegexValidator ipv4Validator = new RegexValidator(IPV4_REGEX);

    public static InetAddressValidator getInstance() {
        return VALIDATOR;
    }

    public boolean isValid(String inetAddress) {
        return isValidInet4Address(inetAddress) || isValidInet6Address(inetAddress);
    }

    public boolean isValidInet4Address(String inet4Address) {
        String[] groups = this.ipv4Validator.match(inet4Address);
        if (groups == null) {
            return false;
        }
        for (String ipSegment : groups) {
            if (ipSegment == null || ipSegment.length() == 0) {
                return false;
            }
            try {
                if (Integer.parseInt(ipSegment) > 255) {
                    return false;
                }
                if (ipSegment.length() > 1 && ipSegment.startsWith("0")) {
                    return false;
                }
            } catch (NumberFormatException e) {
                return false;
            }
        }
        return true;
    }

    public boolean isValidInet6Address(String inet6Address) {
        int bits;
        String[] parts = inet6Address.split("/", -1);
        if (parts.length > 2) {
            return false;
        }
        if (parts.length == 2 && (!parts[1].matches("\\d{1,3}") || (bits = Integer.parseInt(parts[1])) < 0 || bits > 128)) {
            return false;
        }
        String[] parts2 = parts[0].split("%", -1);
        if (parts2.length > 2) {
            return false;
        }
        if (parts2.length == 2 && !parts2[1].matches("[^\\s/%]+")) {
            return false;
        }
        String inet6Address2 = parts2[0];
        boolean containsCompressedZeroes = inet6Address2.contains("::");
        if (containsCompressedZeroes && inet6Address2.indexOf("::") != inet6Address2.lastIndexOf("::")) {
            return false;
        }
        if ((inet6Address2.startsWith(":") && !inet6Address2.startsWith("::")) || (inet6Address2.endsWith(":") && !inet6Address2.endsWith("::"))) {
            return false;
        }
        String[] octets = inet6Address2.split(":");
        if (containsCompressedZeroes) {
            List<String> octetList = new ArrayList<>(Arrays.asList(octets));
            if (inet6Address2.endsWith("::")) {
                octetList.add("");
            } else if (inet6Address2.startsWith("::") && !octetList.isEmpty()) {
                octetList.remove(0);
            }
            octets = (String[]) octetList.toArray(new String[octetList.size()]);
        }
        if (octets.length > 8) {
            return false;
        }
        int validOctets = 0;
        int emptyOctets = 0;
        for (int index = 0; index < octets.length; index++) {
            String octet = octets[index];
            if (octet.length() == 0) {
                emptyOctets++;
                if (emptyOctets > 1) {
                    return false;
                }
            } else {
                emptyOctets = 0;
                if (index != octets.length - 1 || !octet.contains(".")) {
                    if (octet.length() > 4) {
                        return false;
                    }
                    try {
                        int octetInt = Integer.parseInt(octet, 16);
                        if (octetInt < 0 || octetInt > 65535) {
                            return false;
                        }
                    } catch (NumberFormatException e) {
                        return false;
                    }
                } else if (!isValidInet4Address(octet)) {
                    return false;
                } else {
                    validOctets += 2;
                }
            }
            validOctets++;
        }
        if (validOctets > 8 || (validOctets < 8 && !containsCompressedZeroes)) {
            return false;
        }
        return true;
    }
}
