package org.apache.commons.validator.routines;

import java.util.Locale;

public class IntegerValidatorTest extends AbstractNumberValidatorTest {
    private static final String INT_MAX = "2147483647";
    private static final String INT_MAX_0 = "2147483647.99999999999999999999999";
    private static final String INT_MAX_1 = "2147483648";
    private static final Integer INT_MAX_VAL = Integer.MAX_VALUE;
    private static final String INT_MIN = "-2147483648";
    private static final String INT_MIN_0 = "-2147483648.99999999999999999999999";
    private static final String INT_MIN_1 = "-2147483649";
    private static final Integer INT_MIN_VAL = Integer.MIN_VALUE;

    public IntegerValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractNumberValidatorTest
    public void setUp() throws Exception {
        super.setUp();
        this.validator = new IntegerValidator(false, 0);
        this.strictValidator = new IntegerValidator();
        this.testPattern = "#,###";
        this.max = Integer.MAX_VALUE;
        this.maxPlusOne = Long.valueOf(this.max.longValue() + 1);
        this.min = Integer.MIN_VALUE;
        this.minMinusOne = Long.valueOf(this.min.longValue() - 1);
        this.invalidStrict = new String[]{null, "", "X", "X12", "12X", "1X2", "1.2", INT_MAX_1, INT_MIN_1};
        this.invalid = new String[]{null, "", "X", "X12", INT_MAX_1, INT_MIN_1};
        this.testNumber = 1234;
        this.testZero = 0;
        this.validStrict = new String[]{"0", "1234", "1,234", INT_MAX, INT_MIN};
        Integer num = INT_MAX_VAL;
        Integer num2 = INT_MIN_VAL;
        this.validStrictCompare = new Number[]{this.testZero, this.testNumber, this.testNumber, num, num2};
        this.valid = new String[]{"0", "1234", "1,234", "1,234.5", "1234X", INT_MAX, INT_MIN, INT_MAX_0, INT_MIN_0};
        this.validCompare = new Number[]{this.testZero, this.testNumber, this.testNumber, this.testNumber, this.testNumber, num, num2, num, num2};
        this.testStringUS = "1,234";
        this.testStringDE = "1.234";
        this.localeValue = this.testStringDE;
        this.localePattern = "#.###";
        this.testLocale = Locale.GERMANY;
        this.localeExpected = this.testNumber;
    }

    public void testIntegerValidatorMethods() {
        Locale locale = Locale.GERMAN;
        assertEquals("validate(A) default", 12345, IntegerValidator.getInstance().validate("12,345"));
        assertEquals("validate(A) locale ", 12345, IntegerValidator.getInstance().validate("12.345", locale));
        assertEquals("validate(A) pattern", 12345, IntegerValidator.getInstance().validate("1,23,45", "0,00,00"));
        assertEquals("validate(A) both", 12345, IntegerValidator.getInstance().validate("1.23.45", "0,00,00", Locale.GERMAN));
        assertTrue("isValid(A) default", IntegerValidator.getInstance().isValid("12,345"));
        assertTrue("isValid(A) locale ", IntegerValidator.getInstance().isValid("12.345", locale));
        assertTrue("isValid(A) pattern", IntegerValidator.getInstance().isValid("1,23,45", "0,00,00"));
        assertTrue("isValid(A) both", IntegerValidator.getInstance().isValid("1.23.45", "0,00,00", Locale.GERMAN));
        assertNull("validate(B) default", IntegerValidator.getInstance().validate("XXXX"));
        assertNull("validate(B) locale ", IntegerValidator.getInstance().validate("XXXX", locale));
        assertNull("validate(B) pattern", IntegerValidator.getInstance().validate("XXXX", "0,00,00"));
        assertNull("validate(B) both", IntegerValidator.getInstance().validate("1,23,45", "0,00,00", Locale.GERMAN));
        assertFalse("isValid(B) default", IntegerValidator.getInstance().isValid("XXXX"));
        assertFalse("isValid(B) locale ", IntegerValidator.getInstance().isValid("XXXX", locale));
        assertFalse("isValid(B) pattern", IntegerValidator.getInstance().isValid("XXXX", "0,00,00"));
        assertFalse("isValid(B) both", IntegerValidator.getInstance().isValid("1,23,45", "0,00,00", Locale.GERMAN));
    }

    public void testIntegerRangeMinMax() {
        IntegerValidator validator = (IntegerValidator) this.strictValidator;
        Integer number9 = validator.validate("9", "#");
        Integer number10 = validator.validate("10", "#");
        Integer number11 = validator.validate("11", "#");
        Integer number19 = validator.validate("19", "#");
        Integer number20 = validator.validate("20", "#");
        Integer number21 = validator.validate("21", "#");
        assertFalse("isInRange() < min", validator.isInRange(number9, 10, 20));
        assertTrue("isInRange() = min", validator.isInRange(number10, 10, 20));
        assertTrue("isInRange() in range", validator.isInRange(number11, 10, 20));
        assertTrue("isInRange() = max", validator.isInRange(number20, 10, 20));
        assertFalse("isInRange() > max", validator.isInRange(number21, 10, 20));
        assertFalse("minValue() < min", validator.minValue(number9, 10));
        assertTrue("minValue() = min", validator.minValue(number10, 10));
        assertTrue("minValue() > min", validator.minValue(number11, 10));
        assertTrue("maxValue() < max", validator.maxValue(number19, 20));
        assertTrue("maxValue() = max", validator.maxValue(number20, 20));
        assertFalse("maxValue() > max", validator.maxValue(number21, 20));
    }

    public void testMinMaxValues() {
        assertTrue("2147483647 is max integer", this.validator.isValid(INT_MAX));
        assertFalse("2147483648 > max integer", this.validator.isValid(INT_MAX_1));
        assertTrue("-2147483648 is min integer", this.validator.isValid(INT_MIN));
        assertFalse("-2147483649 < min integer", this.validator.isValid(INT_MIN_1));
    }
}
