package org.apache.commons.validator.routines;

import java.util.regex.PatternSyntaxException;
import junit.framework.TestCase;

public class RegexValidatorTest extends TestCase {
    private static final String COMPONENT_1 = "([abc]{3})";
    private static final String COMPONENT_2 = "([DEF]{3})";
    private static final String COMPONENT_3 = "([123]{3})";
    private static final String[] MULTIPLE_REGEX = {REGEX_1, REGEX_2, REGEX_3};
    private static final String REGEX = "^([abc]*)(?:\\-)([DEF]*)(?:\\-)([123]*)$";
    private static final String REGEX_1 = "^([abc]{3})(?:\\-)([DEF]{3})(?:\\-)([123]{3})$";
    private static final String REGEX_2 = "^([abc]{3})(?:\\s)([DEF]{3})(?:\\s)([123]{3})$";
    private static final String REGEX_3 = "^([abc]{3})([DEF]{3})([123]{3})$";
    private static final String SEPARATOR_1 = "(?:\\-)";
    private static final String SEPARATOR_2 = "(?:\\s)";

    public RegexValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws Exception {
        RegexValidatorTest.super.setUp();
    }

    /* access modifiers changed from: protected */
    public void tearDown() throws Exception {
        RegexValidatorTest.super.tearDown();
    }

    public void testSingle() {
        RegexValidator sensitive = new RegexValidator(REGEX);
        RegexValidator insensitive = new RegexValidator(REGEX, false);
        assertEquals("Sensitive isValid() valid", true, sensitive.isValid("ac-DE-1"));
        assertEquals("Sensitive isValid() invalid", false, sensitive.isValid("AB-de-1"));
        assertEquals("Insensitive isValid() valid", true, insensitive.isValid("AB-de-1"));
        assertEquals("Insensitive isValid() invalid", false, insensitive.isValid("ABd-de-1"));
        assertEquals("Sensitive validate() valid", "acDE1", sensitive.validate("ac-DE-1"));
        assertEquals("Sensitive validate() invalid", null, sensitive.validate("AB-de-1"));
        assertEquals("Insensitive validate() valid", "ABde1", insensitive.validate("AB-de-1"));
        assertEquals("Insensitive validate() invalid", null, insensitive.validate("ABd-de-1"));
        checkArray("Sensitive match() valid", new String[]{"ac", "DE", "1"}, sensitive.match("ac-DE-1"));
        checkArray("Sensitive match() invalid", null, sensitive.match("AB-de-1"));
        checkArray("Insensitive match() valid", new String[]{"AB", "de", "1"}, insensitive.match("AB-de-1"));
        checkArray("Insensitive match() invalid", null, insensitive.match("ABd-de-1"));
        assertEquals("validate one", "ABC", new RegexValidator("^([A-Z]*)$").validate("ABC"));
        checkArray("match one", new String[]{"ABC"}, new RegexValidator("^([A-Z]*)$").match("ABC"));
    }

    public void testMultipleSensitive() {
        RegexValidator multiple = new RegexValidator(MULTIPLE_REGEX);
        RegexValidator single1 = new RegexValidator(REGEX_1);
        RegexValidator single2 = new RegexValidator(REGEX_2);
        RegexValidator single3 = new RegexValidator(REGEX_3);
        String[] array = {"aac", "FDE", "321"};
        assertEquals("Sensitive isValid() Multiple", true, multiple.isValid("aac FDE 321"));
        assertEquals("Sensitive isValid() 1st", false, single1.isValid("aac FDE 321"));
        assertEquals("Sensitive isValid() 2nd", true, single2.isValid("aac FDE 321"));
        assertEquals("Sensitive isValid() 3rd", false, single3.isValid("aac FDE 321"));
        assertEquals("Sensitive validate() Multiple", "aacFDE321", multiple.validate("aac FDE 321"));
        assertEquals("Sensitive validate() 1st", null, single1.validate("aac FDE 321"));
        assertEquals("Sensitive validate() 2nd", "aacFDE321", single2.validate("aac FDE 321"));
        assertEquals("Sensitive validate() 3rd", null, single3.validate("aac FDE 321"));
        checkArray("Sensitive match() Multiple", array, multiple.match("aac FDE 321"));
        checkArray("Sensitive match() 1st", null, single1.match("aac FDE 321"));
        checkArray("Sensitive match() 2nd", array, single2.match("aac FDE 321"));
        checkArray("Sensitive match() 3rd", null, single3.match("aac FDE 321"));
        assertEquals("isValid() Invalid", false, multiple.isValid("AAC*FDE*321"));
        assertEquals("validate() Invalid", null, multiple.validate("AAC*FDE*321"));
        assertEquals("match() Multiple", null, multiple.match("AAC*FDE*321"));
    }

    public void testMultipleInsensitive() {
        RegexValidator multiple = new RegexValidator(MULTIPLE_REGEX, false);
        RegexValidator single1 = new RegexValidator(REGEX_1, false);
        RegexValidator single2 = new RegexValidator(REGEX_2, false);
        RegexValidator single3 = new RegexValidator(REGEX_3, false);
        String[] array = {"AAC", "FDE", "321"};
        assertEquals("isValid() Multiple", true, multiple.isValid("AAC FDE 321"));
        assertEquals("isValid() 1st", false, single1.isValid("AAC FDE 321"));
        assertEquals("isValid() 2nd", true, single2.isValid("AAC FDE 321"));
        assertEquals("isValid() 3rd", false, single3.isValid("AAC FDE 321"));
        assertEquals("validate() Multiple", "AACFDE321", multiple.validate("AAC FDE 321"));
        assertEquals("validate() 1st", null, single1.validate("AAC FDE 321"));
        assertEquals("validate() 2nd", "AACFDE321", single2.validate("AAC FDE 321"));
        assertEquals("validate() 3rd", null, single3.validate("AAC FDE 321"));
        checkArray("match() Multiple", array, multiple.match("AAC FDE 321"));
        checkArray("match() 1st", null, single1.match("AAC FDE 321"));
        checkArray("match() 2nd", array, single2.match("AAC FDE 321"));
        checkArray("match() 3rd", null, single3.match("AAC FDE 321"));
        assertEquals("isValid() Invalid", false, multiple.isValid("AAC*FDE*321"));
        assertEquals("validate() Invalid", null, multiple.validate("AAC*FDE*321"));
        assertEquals("match() Multiple", null, multiple.match("AAC*FDE*321"));
    }

    public void testNullValue() {
        RegexValidator validator = new RegexValidator(REGEX);
        assertEquals("Instance isValid()", false, validator.isValid(null));
        assertEquals("Instance validate()", null, validator.validate(null));
        assertEquals("Instance match()", null, validator.match(null));
    }

    public void testMissingRegex() {
        try {
            new RegexValidator((String) null);
            fail("Single Null - expected IllegalArgumentException");
        } catch (IllegalArgumentException e) {
            assertEquals("Single Null", "Regular expression[0] is missing", e.getMessage());
        }
        try {
            new RegexValidator("");
            fail("Single Zero Length - expected IllegalArgumentException");
        } catch (IllegalArgumentException e2) {
            assertEquals("Single Zero Length", "Regular expression[0] is missing", e2.getMessage());
        }
        try {
            new RegexValidator((String[]) null);
            fail("Null Array - expected IllegalArgumentException");
        } catch (IllegalArgumentException e3) {
            assertEquals("Null Array", "Regular expressions are missing", e3.getMessage());
        }
        try {
            new RegexValidator(new String[0]);
            fail("Zero Length Array - expected IllegalArgumentException");
        } catch (IllegalArgumentException e4) {
            assertEquals("Zero Length Array", "Regular expressions are missing", e4.getMessage());
        }
        try {
            new RegexValidator(new String[]{"ABC", null});
            fail("Array has Null - expected IllegalArgumentException");
        } catch (IllegalArgumentException e5) {
            assertEquals("Array has Null", "Regular expression[1] is missing", e5.getMessage());
        }
        try {
            new RegexValidator(new String[]{"", "ABC"});
            fail("Array has Zero Length - expected IllegalArgumentException");
        } catch (IllegalArgumentException e6) {
            assertEquals("Array has Zero Length", "Regular expression[0] is missing", e6.getMessage());
        }
    }

    public void testExceptions() {
        try {
            new RegexValidator("^([abCD12]*$");
        } catch (PatternSyntaxException e) {
        }
    }

    public void testToString() {
        assertEquals("Single", "RegexValidator{^([abc]*)(?:\\-)([DEF]*)(?:\\-)([123]*)$}", new RegexValidator(REGEX).toString());
        assertEquals("Multiple", "RegexValidator{^([abc]*)(?:\\-)([DEF]*)(?:\\-)([123]*)$,^([abc]*)(?:\\-)([DEF]*)(?:\\-)([123]*)$}", new RegexValidator(new String[]{REGEX, REGEX}).toString());
    }

    private void checkArray(String label, String[] expect, String[] result) {
        if (expect != null && result != null) {
            if (expect.length != result.length) {
                fail(label + " Length expect=" + expect.length + " result=" + result.length);
            }
            for (int i = 0; i < expect.length; i++) {
                assertEquals(label + " value[" + i + "]", expect[i], result[i]);
            }
        } else if (expect != null || result != null) {
            fail(label + " Null expect=" + expect + " result=" + result);
        }
    }
}
