package org.apache.commons.validator.routines;

import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;
import junit.framework.TestCase;

public class TimeValidatorTest extends TestCase {
    protected static final TimeZone EST = TimeZone.getTimeZone("EST");
    protected static final TimeZone GMT = TimeZone.getTimeZone("GMT");
    private TimeZone defaultZone;
    protected Date[] localeExpect = {createDate(null, 235900, 0), createDate(null, 0, 0), createDate(null, 100, 0), createDate(null, 0, 0), createDate(null, 11200, 0), createDate(null, 104900, 0), createDate(null, 162300, 0)};
    protected String[] localeInvalid = {"24:00", "24:00", "25:02", "10:61", "05-02", "0X:01", "05:0X", "01-01", "10:", "10::1", "10:1:"};
    protected String[] localeValid = {"23:59", "00:00", "00:01", "0:0", "1:12", "10:49", "16:23"};
    private Locale origDefault;
    protected Date[] patternExpect = {createDate(null, 235959, 0), createDate(null, 0, 0), createDate(null, 1, 0), createDate(null, 0, 0), createDate(null, 11201, 0), createDate(null, 104918, 0), createDate(null, 162346, 0)};
    protected String[] patternInvalid = {"24-00-00", "24-00-01", "25-02-03", "10-61-31", "10-01-61", "05:02-29", "0X-01:01", "05-0X-01", "10-01-0X", "01:01:05", "10-10", "10--10", "10-10-"};
    protected String[] patternValid = {"23-59-59", "00-00-00", "00-00-01", "0-0-0", "1-12-1", "10-49-18", "16-23-46"};
    protected TimeValidator validator;

    public TimeValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws Exception {
        TimeValidatorTest.super.setUp();
        this.validator = new TimeValidator();
        this.defaultZone = TimeZone.getDefault();
        this.origDefault = Locale.getDefault();
    }

    /* access modifiers changed from: protected */
    public void tearDown() throws Exception {
        TimeValidatorTest.super.tearDown();
        this.validator = null;
        Locale.setDefault(this.origDefault);
        TimeZone.setDefault(this.defaultZone);
    }

    public void testPatternValid() {
        for (int i = 0; i < this.patternValid.length; i++) {
            String text = i + " value=[" + this.patternValid[i] + "] failed ";
            Calendar calendar = this.validator.validate(this.patternValid[i], "HH-mm-ss");
            assertNotNull("validateObj() " + text, calendar);
            Date date = calendar.getTime();
            assertTrue("isValid() " + text, this.validator.isValid(this.patternValid[i], "HH-mm-ss"));
            assertEquals("compare " + text, this.patternExpect[i], date);
        }
    }

    public void testPatternInvalid() {
        for (int i = 0; i < this.patternInvalid.length; i++) {
            String text = i + " value=[" + this.patternInvalid[i] + "] passed ";
            Object date = this.validator.validate(this.patternInvalid[i], "HH-mm-ss");
            assertNull("validate() " + text + date, date);
            StringBuilder sb = new StringBuilder();
            sb.append("isValid() ");
            sb.append(text);
            assertFalse(sb.toString(), this.validator.isValid(this.patternInvalid[i], "HH-mm-ss"));
        }
    }

    public void testLocaleValid() {
        for (int i = 0; i < this.localeValid.length; i++) {
            String text = i + " value=[" + this.localeValid[i] + "] failed ";
            Calendar calendar = this.validator.validate(this.localeValid[i], Locale.UK);
            assertNotNull("validate() " + text, calendar);
            Date date = calendar.getTime();
            assertTrue("isValid() " + text, this.validator.isValid(this.localeValid[i], Locale.UK));
            assertEquals("compare " + text, this.localeExpect[i], date);
        }
    }

    public void testLocaleInvalid() {
        for (int i = 0; i < this.localeInvalid.length; i++) {
            String text = i + " value=[" + this.localeInvalid[i] + "] passed ";
            Object date = this.validator.validate(this.localeInvalid[i], Locale.US);
            assertNull("validate() " + text + date, date);
            StringBuilder sb = new StringBuilder();
            sb.append("isValid() ");
            sb.append(text);
            assertFalse(sb.toString(), this.validator.isValid(this.localeInvalid[i], Locale.UK));
        }
    }

    public void testTimeZone() {
        Locale.setDefault(Locale.UK);
        TimeZone timeZone = GMT;
        TimeZone.setDefault(timeZone);
        Calendar result = this.validator.validate("18:01");
        assertNotNull("default result", result);
        assertEquals("default zone", timeZone, result.getTimeZone());
        assertEquals("default hour", 18, result.get(11));
        assertEquals("default minute", 1, result.get(12));
        TimeValidator timeValidator = this.validator;
        TimeZone timeZone2 = EST;
        Calendar result2 = timeValidator.validate("16:49", timeZone2);
        assertNotNull("zone result", result2);
        assertEquals("zone zone", timeZone2, result2.getTimeZone());
        assertEquals("zone hour", 16, result2.get(11));
        assertEquals("zone minute", 49, result2.get(12));
        Calendar result3 = this.validator.validate("14-34", "HH-mm", timeZone2);
        assertNotNull("pattern result", result3);
        assertEquals("pattern zone", timeZone2, result3.getTimeZone());
        assertEquals("pattern hour", 14, result3.get(11));
        assertEquals("pattern minute", 34, result3.get(12));
        Calendar result4 = this.validator.validate("7:18 PM", Locale.US, timeZone2);
        assertNotNull("locale result", result4);
        assertEquals("locale zone", timeZone2, result4.getTimeZone());
        assertEquals("locale hour", 19, result4.get(11));
        assertEquals("locale minute", 18, result4.get(12));
        Calendar result5 = this.validator.validate("31/Dez/05 21-05", "dd/MMM/yy HH-mm", Locale.GERMAN, timeZone2);
        assertNotNull("pattern result", result5);
        assertEquals("pattern zone", timeZone2, result5.getTimeZone());
        assertEquals("pattern day", 2005, result5.get(1));
        assertEquals("pattern day", 11, result5.get(2));
        assertEquals("pattern day", 31, result5.get(5));
        assertEquals("pattern hour", 21, result5.get(11));
        assertEquals("pattern minute", 5, result5.get(12));
        Calendar result6 = this.validator.validate("31/Dez/05 21-05", "dd/MMM/yy HH-mm", Locale.GERMAN);
        assertNotNull("pattern result", result6);
        assertEquals("pattern zone", timeZone, result6.getTimeZone());
        assertEquals("pattern day", 2005, result6.get(1));
        assertEquals("pattern day", 11, result6.get(2));
        assertEquals("pattern day", 31, result6.get(5));
        assertEquals("pattern hour", 21, result6.get(11));
        assertEquals("pattern minute", 5, result6.get(12));
    }

    public void testFormat() {
        Locale.setDefault(Locale.UK);
        Object test = TimeValidator.getInstance().validate("16:49:23", "HH:mm:ss");
        assertNotNull("Test Date ", test);
        assertEquals("Format pattern", "16-49-23", this.validator.format(test, "HH-mm-ss"));
        assertEquals("Format locale", "4:49 PM", this.validator.format(test, Locale.US));
        assertEquals("Format default", "16:49", this.validator.format(test));
    }

    public void testCompare() {
        TimeZone timeZone = GMT;
        Calendar milliGreater = createTime(timeZone, 154523, 500);
        Calendar value = createTime(timeZone, 154523, 400);
        Calendar milliLess = createTime(timeZone, 154523, 300);
        Calendar secGreater = createTime(timeZone, 154523 + 1, 100);
        Calendar secLess = createTime(timeZone, 154523 - 1, 100);
        Calendar minGreater = createTime(timeZone, 154523 + 100, 100);
        Calendar minLess = createTime(timeZone, 154523 - 100, 100);
        Calendar hourGreater = createTime(timeZone, 154523 + 10000, 100);
        Calendar hourLess = createTime(timeZone, 154523 - 10000, 100);
        assertEquals("mili LT", -1, this.validator.compareTime(value, milliGreater));
        assertEquals("mili EQ", 0, this.validator.compareTime(value, value));
        assertEquals("mili GT", 1, this.validator.compareTime(value, milliLess));
        assertEquals("secs LT", -1, this.validator.compareSeconds(value, secGreater));
        assertEquals("secs =1", 0, this.validator.compareSeconds(value, milliGreater));
        assertEquals("secs =2", 0, this.validator.compareSeconds(value, value));
        assertEquals("secs =3", 0, this.validator.compareSeconds(value, milliLess));
        assertEquals("secs GT", 1, this.validator.compareSeconds(value, secLess));
        assertEquals("mins LT", -1, this.validator.compareMinutes(value, minGreater));
        assertEquals("mins =1", 0, this.validator.compareMinutes(value, secGreater));
        assertEquals("mins =2", 0, this.validator.compareMinutes(value, value));
        assertEquals("mins =3", 0, this.validator.compareMinutes(value, secLess));
        assertEquals("mins GT", 1, this.validator.compareMinutes(value, minLess));
        assertEquals("hour LT", -1, this.validator.compareHours(value, hourGreater));
        assertEquals("hour =1", 0, this.validator.compareHours(value, minGreater));
        assertEquals("hour =2", 0, this.validator.compareHours(value, value));
        assertEquals("hour =3", 0, this.validator.compareHours(value, minLess));
        assertEquals("hour GT", 1, this.validator.compareHours(value, hourLess));
    }

    protected static Calendar createTime(TimeZone zone, int time, int millisecond) {
        Calendar calendar = zone == null ? Calendar.getInstance() : Calendar.getInstance(zone);
        int hour = (time / 10000) * 10000;
        int min = ((time / 100) * 100) - hour;
        calendar.set(1, 1970);
        calendar.set(2, 0);
        calendar.set(5, 1);
        calendar.set(11, hour / 10000);
        calendar.set(12, min / 100);
        calendar.set(13, time - (hour + min));
        calendar.set(14, millisecond);
        return calendar;
    }

    protected static Date createDate(TimeZone zone, int time, int millisecond) {
        return createTime(zone, time, millisecond).getTime();
    }
}
