package org.apache.commons.validator.routines;

import java.io.Serializable;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.Collections;
import java.util.HashSet;
import java.util.Locale;
import java.util.Set;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class UrlValidator implements Serializable {
    public static final long ALLOW_2_SLASHES = 2;
    public static final long ALLOW_ALL_SCHEMES = 1;
    public static final long ALLOW_LOCAL_URLS = 8;
    private static final String AUTHORITY_CHARS_REGEX = "\\p{Alnum}\\-\\.";
    private static final Pattern AUTHORITY_PATTERN = Pattern.compile(AUTHORITY_REGEX);
    private static final String AUTHORITY_REGEX = "(?:\\[(::FFFF:(?:\\d{1,3}\\.){3}\\d{1,3}|[0-9a-fA-F:]+)\\]|(?:(?:[a-zA-Z0-9%-._~!$&'()*+,;=]+(?::[a-zA-Z0-9%-._~!$&'()*+,;=]*)?@)?([\\p{Alnum}\\-\\.]*)))(?::(\\d*))?(.*)?";
    private static final String[] DEFAULT_SCHEMES = {"http", "https", "ftp"};
    private static final UrlValidator DEFAULT_URL_VALIDATOR = new UrlValidator();
    private static final String IPV6_REGEX = "::FFFF:(?:\\d{1,3}\\.){3}\\d{1,3}|[0-9a-fA-F:]+";
    private static final int MAX_UNSIGNED_16_BIT_INT = 65535;
    public static final long NO_FRAGMENTS = 4;
    private static final int PARSE_AUTHORITY_EXTRA = 4;
    private static final int PARSE_AUTHORITY_HOST_IP = 2;
    private static final int PARSE_AUTHORITY_IPV6 = 1;
    private static final int PARSE_AUTHORITY_PORT = 3;
    private static final Pattern PATH_PATTERN = Pattern.compile(PATH_REGEX);
    private static final String PATH_REGEX = "^(/[-\\w:@&?=+,.!/~*'%$_;\\(\\)]*)?$";
    private static final Pattern QUERY_PATTERN = Pattern.compile(QUERY_REGEX);
    private static final String QUERY_REGEX = "^(\\S*)$";
    private static final Pattern SCHEME_PATTERN = Pattern.compile(SCHEME_REGEX);
    private static final String SCHEME_REGEX = "^\\p{Alpha}[\\p{Alnum}\\+\\-\\.]*";
    private static final String USERINFO_CHARS_REGEX = "[a-zA-Z0-9%-._~!$&'()*+,;=]";
    private static final String USERINFO_FIELD_REGEX = "[a-zA-Z0-9%-._~!$&'()*+,;=]+(?::[a-zA-Z0-9%-._~!$&'()*+,;=]*)?@";
    private static final long serialVersionUID = 7557161713937335013L;
    private final Set<String> allowedSchemes;
    private final RegexValidator authorityValidator;
    private final DomainValidator domainValidator;
    private final long options;

    public static UrlValidator getInstance() {
        return DEFAULT_URL_VALIDATOR;
    }

    public UrlValidator() {
        this((String[]) null);
    }

    public UrlValidator(String[] schemes) {
        this(schemes, 0);
    }

    public UrlValidator(long options2) {
        this(null, null, options2);
    }

    public UrlValidator(String[] schemes, long options2) {
        this(schemes, null, options2);
    }

    public UrlValidator(RegexValidator authorityValidator2, long options2) {
        this(null, authorityValidator2, options2);
    }

    public UrlValidator(String[] schemes, RegexValidator authorityValidator2, long options2) {
        this(schemes, authorityValidator2, options2, DomainValidator.getInstance(isOn(8, options2)));
    }

    public UrlValidator(String[] schemes, RegexValidator authorityValidator2, long options2, DomainValidator domainValidator2) {
        this.options = options2;
        if (domainValidator2 != null) {
            if (domainValidator2.isAllowLocal() == ((8 & options2) > 0)) {
                this.domainValidator = domainValidator2;
                if (isOn(1)) {
                    this.allowedSchemes = Collections.emptySet();
                } else {
                    schemes = schemes == null ? DEFAULT_SCHEMES : schemes;
                    this.allowedSchemes = new HashSet(schemes.length);
                    for (String str : schemes) {
                        this.allowedSchemes.add(str.toLowerCase(Locale.ENGLISH));
                    }
                }
                this.authorityValidator = authorityValidator2;
                return;
            }
            throw new IllegalArgumentException("DomainValidator disagrees with ALLOW_LOCAL_URLS setting");
        }
        throw new IllegalArgumentException("DomainValidator must not be null");
    }

    public boolean isValid(String value) {
        if (value == null) {
            return false;
        }
        try {
            URI uri = new URI(value);
            String scheme = uri.getScheme();
            if (!isValidScheme(scheme)) {
                return false;
            }
            String authority = uri.getRawAuthority();
            if ("file".equals(scheme) && (authority == null || "".equals(authority))) {
                return true;
            }
            if ((!"file".equals(scheme) || authority == null || !authority.contains(":")) && isValidAuthority(authority) && isValidPath(uri.getRawPath()) && isValidQuery(uri.getRawQuery()) && isValidFragment(uri.getRawFragment())) {
                return true;
            }
            return false;
        } catch (URISyntaxException e) {
            return false;
        }
    }

    /* access modifiers changed from: protected */
    public boolean isValidScheme(String scheme) {
        if (scheme == null || !SCHEME_PATTERN.matcher(scheme).matches()) {
            return false;
        }
        if (!isOff(1) || this.allowedSchemes.contains(scheme.toLowerCase(Locale.ENGLISH))) {
            return true;
        }
        return false;
    }

    /* access modifiers changed from: protected */
    public boolean isValidAuthority(String authority) {
        if (authority == null) {
            return false;
        }
        RegexValidator regexValidator = this.authorityValidator;
        if (regexValidator != null && regexValidator.isValid(authority)) {
            return true;
        }
        Matcher authorityMatcher = AUTHORITY_PATTERN.matcher(DomainValidator.unicodeToASCII(authority));
        if (!authorityMatcher.matches()) {
            return false;
        }
        String ipv6 = authorityMatcher.group(1);
        if (ipv6 == null) {
            String hostLocation = authorityMatcher.group(2);
            if (!this.domainValidator.isValid(hostLocation) && !InetAddressValidator.getInstance().isValidInet4Address(hostLocation)) {
                return false;
            }
            String port = authorityMatcher.group(3);
            if (port != null && port.length() > 0) {
                try {
                    int iPort = Integer.parseInt(port);
                    if (iPort < 0 || iPort > 65535) {
                        return false;
                    }
                } catch (NumberFormatException e) {
                    return false;
                }
            }
        } else if (!InetAddressValidator.getInstance().isValidInet6Address(ipv6)) {
            return false;
        }
        String extra = authorityMatcher.group(4);
        if (extra == null || extra.trim().length() <= 0) {
            return true;
        }
        return false;
    }

    /* access modifiers changed from: protected */
    public boolean isValidPath(String path) {
        if (path == null || !PATH_PATTERN.matcher(path).matches()) {
            return false;
        }
        try {
            String norm = new URI(null, "localhost", path, null).normalize().getPath();
            if (norm.startsWith("/../") || norm.equals("/..")) {
                return false;
            }
            int slash2Count = countToken("//", path);
            if (!isOff(2) || slash2Count <= 0) {
                return true;
            }
            return false;
        } catch (URISyntaxException e) {
            return false;
        }
    }

    /* access modifiers changed from: protected */
    public boolean isValidQuery(String query) {
        if (query == null) {
            return true;
        }
        return QUERY_PATTERN.matcher(query).matches();
    }

    /* access modifiers changed from: protected */
    public boolean isValidFragment(String fragment) {
        if (fragment == null) {
            return true;
        }
        return isOff(4);
    }

    /* access modifiers changed from: protected */
    public int countToken(String token, String target) {
        int tokenIndex = 0;
        int count = 0;
        while (tokenIndex != -1) {
            tokenIndex = target.indexOf(token, tokenIndex);
            if (tokenIndex > -1) {
                tokenIndex++;
                count++;
            }
        }
        return count;
    }

    private boolean isOn(long flag) {
        return (this.options & flag) > 0;
    }

    private static boolean isOn(long flag, long options2) {
        return (options2 & flag) > 0;
    }

    private boolean isOff(long flag) {
        return (this.options & flag) == 0;
    }
}
