package org.apache.commons.validator.routines;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.ArrayList;
import org.apache.commons.validator.ResultPair;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

public class UrlValidatorTest {
    private final boolean printIndex = false;
    private final boolean printStatus = false;
    private final String[] schemes;
    int[] testPartsIndex;
    ResultPair[] testPath = {new ResultPair("/test1", true), new ResultPair("/t123", true), new ResultPair("/$23", true), new ResultPair("/..", false), new ResultPair("/../", false), new ResultPair("/test1/", true), new ResultPair("", true), new ResultPair("/test1/file", true), new ResultPair("/..//file", false), new ResultPair("/test1//file", false)};
    ResultPair[] testScheme;
    ResultPair[] testUrlAuthority = {new ResultPair("www.google.com", true), new ResultPair("www.google.com.", true), new ResultPair("go.com", true), new ResultPair("go.au", true), new ResultPair("0.0.0.0", true), new ResultPair("255.255.255.255", true), new ResultPair("256.256.256.256", false), new ResultPair("255.com", true), new ResultPair("1.2.3.4.5", false), new ResultPair("1.2.3.4.", false), new ResultPair("1.2.3", false), new ResultPair(".1.2.3.4", false), new ResultPair("go.a", false), new ResultPair("go.a1a", false), new ResultPair("go.cc", true), new ResultPair("go.1aa", false), new ResultPair("aaa.", false), new ResultPair(".aaa", false), new ResultPair("aaa", false), new ResultPair("", false)};
    Object[] testUrlParts;
    Object[] testUrlPartsOptions;
    ResultPair[] testUrlPathOptions = {new ResultPair("/test1", true), new ResultPair("/t123", true), new ResultPair("/$23", true), new ResultPair("/..", false), new ResultPair("/../", false), new ResultPair("/test1/", true), new ResultPair("/#", false), new ResultPair("", true), new ResultPair("/test1/file", true), new ResultPair("/t123/file", true), new ResultPair("/$23/file", true), new ResultPair("/../file", false), new ResultPair("/..//file", false), new ResultPair("/test1//file", true), new ResultPair("/#/file", false)};
    ResultPair[] testUrlPort = {new ResultPair(":80", true), new ResultPair(":65535", true), new ResultPair(":65536", false), new ResultPair(":0", true), new ResultPair("", true), new ResultPair(":-1", false), new ResultPair(":65636", false), new ResultPair(":999999999999999999", false), new ResultPair(":65a", false)};
    ResultPair[] testUrlQuery;
    ResultPair[] testUrlScheme = {new ResultPair("http://", true), new ResultPair("ftp://", true), new ResultPair("h3t://", true), new ResultPair("3ht://", false), new ResultPair("http:/", false), new ResultPair("http:", false), new ResultPair("http/", false), new ResultPair("://", false)};

    public UrlValidatorTest() {
        ResultPair[] resultPairArr = {new ResultPair("?action=view", true), new ResultPair("?action=edit&mode=up", true), new ResultPair("", true)};
        this.testUrlQuery = resultPairArr;
        ResultPair[] resultPairArr2 = this.testUrlScheme;
        ResultPair[] resultPairArr3 = this.testUrlAuthority;
        ResultPair[] resultPairArr4 = this.testUrlPort;
        this.testUrlParts = new Object[]{resultPairArr2, resultPairArr3, resultPairArr4, this.testPath, resultPairArr};
        this.testUrlPartsOptions = new Object[]{resultPairArr2, resultPairArr3, resultPairArr4, this.testUrlPathOptions, resultPairArr};
        this.testPartsIndex = new int[]{0, 0, 0, 0, 0};
        this.schemes = new String[]{"http", "gopher", "g0-To+.", "not_valid"};
        this.testScheme = new ResultPair[]{new ResultPair("http", true), new ResultPair("ftp", false), new ResultPair("httpd", false), new ResultPair("gopher", true), new ResultPair("g0-to+.", true), new ResultPair("not_valid", false), new ResultPair("HtTp", true), new ResultPair("telnet", false)};
    }

    @Before
    public void setUp() {
        int index = 0;
        while (true) {
            int[] iArr = this.testPartsIndex;
            if (index < iArr.length - 1) {
                iArr[index] = 0;
                index++;
            } else {
                return;
            }
        }
    }

    @Test
    public void testIsValid() {
        testIsValid(this.testUrlParts, 1);
        setUp();
        testIsValid(this.testUrlPartsOptions, 7);
    }

    @Test
    public void testIsValidScheme() {
        UrlValidator urlVal = new UrlValidator(this.schemes, 0);
        int sIndex = 0;
        while (true) {
            ResultPair[] resultPairArr = this.testScheme;
            if (sIndex < resultPairArr.length) {
                ResultPair testPair = resultPairArr[sIndex];
                Assert.assertEquals(testPair.item, Boolean.valueOf(testPair.valid), Boolean.valueOf(urlVal.isValidScheme(testPair.item)));
                sIndex++;
            } else {
                return;
            }
        }
    }

    public void testIsValid(Object[] testObjects, long options) {
        UrlValidator urlVal = new UrlValidator(null, null, options);
        Assert.assertTrue(urlVal.isValid("http://www.google.com"));
        Assert.assertTrue(urlVal.isValid("http://www.google.com/"));
        do {
            StringBuilder testBuffer = new StringBuilder();
            boolean expected = true;
            int testPartsIndexIndex = 0;
            while (true) {
                int[] iArr = this.testPartsIndex;
                if (testPartsIndexIndex < iArr.length) {
                    int index = iArr[testPartsIndexIndex];
                    ResultPair[] part = (ResultPair[]) testObjects[testPartsIndexIndex];
                    testBuffer.append(part[index].item);
                    expected &= part[index].valid;
                    testPartsIndexIndex++;
                } else {
                    String url = testBuffer.toString();
                    Assert.assertEquals(url, Boolean.valueOf(expected), Boolean.valueOf(urlVal.isValid(url)));
                }
            }
        } while (incrementTestPartsIndex(this.testPartsIndex, testObjects));
    }

    @Test
    public void testValidator202() {
        Assert.assertTrue(new UrlValidator(new String[]{"http", "https"}, 4).isValid("http://l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.org"));
    }

    @Test
    public void testValidator204() {
        Assert.assertTrue(new UrlValidator(new String[]{"http", "https"}).isValid("http://tech.yahoo.com/rc/desktops/102;_ylt=Ao8yevQHlZ4On0O3ZJGXLEQFLZA5"));
    }

    @Test
    public void testValidator218() {
        Assert.assertTrue("parentheses should be valid in URLs", new UrlValidator(2).isValid("http://somewhere.com/pathxyz/file(1).html"));
    }

    @Test
    public void testValidator235() {
        if (System.getProperty("java.version").compareTo("1.6") < 0) {
            System.out.println("Cannot run Unicode IDN tests");
            return;
        }
        UrlValidator validator = new UrlValidator();
        Assert.assertTrue("xn--d1abbgf6aiiy.xn--p1ai should validate", validator.isValid("http://xn--d1abbgf6aiiy.xn--p1ai"));
        Assert.assertTrue("президент.рф should validate", validator.isValid("http://президент.рф"));
        Assert.assertTrue("www.bücher.ch should validate", validator.isValid("http://www.bücher.ch"));
        Assert.assertFalse("www.�.ch FFFD should fail", validator.isValid("http://www.�.ch"));
        Assert.assertTrue("www.bücher.ch should validate", validator.isValid("ftp://www.bücher.ch"));
        Assert.assertFalse("www.�.ch FFFD should fail", validator.isValid("ftp://www.�.ch"));
    }

    @Test
    public void testValidator248() {
        UrlValidator validator = new UrlValidator(new RegexValidator(new String[]{"localhost", ".*\\.my-testing"}), 0);
        Assert.assertTrue("localhost URL should validate", validator.isValid("http://localhost/test/index.html"));
        Assert.assertTrue("first.my-testing should validate", validator.isValid("http://first.my-testing/test/index.html"));
        Assert.assertTrue("sup3r.my-testing should validate", validator.isValid("http://sup3r.my-testing/test/index.html"));
        Assert.assertFalse("broke.my-test should not validate", validator.isValid("http://broke.my-test/test/index.html"));
        Assert.assertTrue("www.apache.org should still validate", validator.isValid("http://www.apache.org/test/index.html"));
        UrlValidator validator2 = new UrlValidator(8);
        Assert.assertTrue("localhost URL should validate", validator2.isValid("http://localhost/test/index.html"));
        Assert.assertTrue("machinename URL should validate", validator2.isValid("http://machinename/test/index.html"));
        Assert.assertTrue("www.apache.org should still validate", validator2.isValid("http://www.apache.org/test/index.html"));
    }

    @Test
    public void testValidator288() {
        UrlValidator validator = new UrlValidator(8);
        Assert.assertTrue("hostname should validate", validator.isValid("http://hostname"));
        Assert.assertTrue("hostname with path should validate", validator.isValid("http://hostname/test/index.html"));
        Assert.assertTrue("localhost URL should validate", validator.isValid("http://localhost/test/index.html"));
        Assert.assertFalse("first.my-testing should not validate", validator.isValid("http://first.my-testing/test/index.html"));
        Assert.assertFalse("broke.hostname should not validate", validator.isValid("http://broke.hostname/test/index.html"));
        Assert.assertTrue("www.apache.org should still validate", validator.isValid("http://www.apache.org/test/index.html"));
        UrlValidator validator2 = new UrlValidator(0);
        Assert.assertFalse("hostname should no longer validate", validator2.isValid("http://hostname"));
        Assert.assertFalse("localhost URL should no longer validate", validator2.isValid("http://localhost/test/index.html"));
        Assert.assertTrue("www.apache.org should still validate", validator2.isValid("http://www.apache.org/test/index.html"));
    }

    @Test
    public void testValidator276() {
        UrlValidator validator = new UrlValidator();
        Assert.assertTrue("http://apache.org/ should be allowed by default", validator.isValid("http://www.apache.org/test/index.html"));
        Assert.assertFalse("file:///c:/ shouldn't be allowed by default", validator.isValid("file:///C:/some.file"));
        Assert.assertFalse("file:///c:\\ shouldn't be allowed by default", validator.isValid("file:///C:\\some.file"));
        Assert.assertFalse("file:///etc/ shouldn't be allowed by default", validator.isValid("file:///etc/hosts"));
        Assert.assertFalse("file://localhost/etc/ shouldn't be allowed by default", validator.isValid("file://localhost/etc/hosts"));
        Assert.assertFalse("file://localhost/c:/ shouldn't be allowed by default", validator.isValid("file://localhost/c:/some.file"));
        UrlValidator validator2 = new UrlValidator(new String[]{"http", "file"}, 8);
        Assert.assertTrue("http://apache.org/ should be allowed by default", validator2.isValid("http://www.apache.org/test/index.html"));
        Assert.assertTrue("file:///c:/ should now be allowed", validator2.isValid("file:///C:/some.file"));
        Assert.assertFalse("file:///c:\\ should not be allowed", validator2.isValid("file:///C:\\some.file"));
        Assert.assertTrue("file:///etc/ should now be allowed", validator2.isValid("file:///etc/hosts"));
        Assert.assertTrue("file://localhost/etc/ should now be allowed", validator2.isValid("file://localhost/etc/hosts"));
        Assert.assertTrue("file://localhost/c:/ should now be allowed", validator2.isValid("file://localhost/c:/some.file"));
        Assert.assertFalse("file://c:/ shouldn't ever be allowed, needs file:///c:/", validator2.isValid("file://C:/some.file"));
        Assert.assertFalse("file://c:\\ shouldn't ever be allowed, needs file:///c:/", validator2.isValid("file://C:\\some.file"));
    }

    @Test
    public void testValidator391OK() {
        Assert.assertTrue(new UrlValidator(new String[]{"file"}).isValid("file:///C:/path/to/dir/"));
    }

    @Test
    public void testValidator391FAILS() {
        Assert.assertTrue(new UrlValidator(new String[]{"file"}).isValid("file:/C:/path/to/dir/"));
    }

    @Test
    public void testValidator309() {
        UrlValidator urlValidator = new UrlValidator();
        Assert.assertTrue(urlValidator.isValid("http://sample.ondemand.com/"));
        Assert.assertTrue(urlValidator.isValid("hTtP://sample.ondemand.CoM/"));
        Assert.assertTrue(urlValidator.isValid("httpS://SAMPLE.ONEMAND.COM/"));
        UrlValidator urlValidator2 = new UrlValidator(new String[]{"HTTP", "HTTPS"});
        Assert.assertTrue(urlValidator2.isValid("http://sample.ondemand.com/"));
        Assert.assertTrue(urlValidator2.isValid("hTtP://sample.ondemand.CoM/"));
        Assert.assertTrue(urlValidator2.isValid("httpS://SAMPLE.ONEMAND.COM/"));
    }

    @Test
    public void testValidator339() {
        UrlValidator urlValidator = new UrlValidator();
        Assert.assertTrue(urlValidator.isValid("http://www.cnn.com/WORLD/?hpt=sitenav"));
        Assert.assertTrue(urlValidator.isValid("http://www.cnn.com./WORLD/?hpt=sitenav"));
        Assert.assertFalse(urlValidator.isValid("http://www.cnn.com../"));
        Assert.assertFalse(urlValidator.isValid("http://www.cnn.invalid/"));
        Assert.assertFalse(urlValidator.isValid("http://www.cnn.invalid./"));
    }

    @Test
    public void testValidator339IDN() {
        UrlValidator urlValidator = new UrlValidator();
        Assert.assertTrue(urlValidator.isValid("http://президент.рф/WORLD/?hpt=sitenav"));
        Assert.assertTrue(urlValidator.isValid("http://президент.рф./WORLD/?hpt=sitenav"));
        Assert.assertFalse(urlValidator.isValid("http://президент.рф..../"));
        Assert.assertFalse(urlValidator.isValid("http://президент.рф.../"));
        Assert.assertFalse(urlValidator.isValid("http://президент.рф../"));
    }

    @Test
    public void testValidator342() {
        UrlValidator urlValidator = new UrlValidator();
        Assert.assertTrue(urlValidator.isValid("http://example.rocks/"));
        Assert.assertTrue(urlValidator.isValid("http://example.rocks"));
    }

    @Test
    public void testValidator411() {
        UrlValidator urlValidator = new UrlValidator();
        Assert.assertTrue(urlValidator.isValid("http://example.rocks:/"));
        Assert.assertTrue(urlValidator.isValid("http://example.rocks:0/"));
        Assert.assertTrue(urlValidator.isValid("http://example.rocks:65535/"));
        Assert.assertFalse(urlValidator.isValid("http://example.rocks:65536/"));
        Assert.assertFalse(urlValidator.isValid("http://example.rocks:100000/"));
    }

    @Test
    public void testValidator464() {
        Assert.assertFalse("file://bad ^ domain.com/label/test", new UrlValidator(new String[]{"file"}).isValid("file://bad ^ domain.com/label/test"));
    }

    @Test
    public void testValidator452() {
        Assert.assertTrue(new UrlValidator().isValid("http://[::FFFF:129.144.52.38]:80/index.html"));
    }

    @Test(expected = IllegalArgumentException.class)
    public void testValidator473_1() {
        new UrlValidator(new String[0], null, 0, null);
    }

    @Test(expected = IllegalArgumentException.class)
    public void testValidator473_2() {
        new UrlValidator(new String[0], null, 0, DomainValidator.getInstance(true, new ArrayList<>()));
    }

    @Test(expected = IllegalArgumentException.class)
    public void testValidator473_3() {
        new UrlValidator(new String[0], null, 8, DomainValidator.getInstance(false, new ArrayList<>()));
    }

    static boolean incrementTestPartsIndex(int[] testPartsIndex2, Object[] testParts) {
        boolean carry = true;
        boolean maxIndex = true;
        for (int testPartsIndexIndex = testPartsIndex2.length - 1; testPartsIndexIndex >= 0; testPartsIndexIndex--) {
            int index = testPartsIndex2[testPartsIndexIndex];
            ResultPair[] part = (ResultPair[]) testParts[testPartsIndexIndex];
            maxIndex &= index == part.length - 1;
            if (carry) {
                if (index < part.length - 1) {
                    testPartsIndex2[testPartsIndexIndex] = index + 1;
                    carry = false;
                } else {
                    testPartsIndex2[testPartsIndexIndex] = 0;
                    carry = true;
                }
            }
        }
        return !maxIndex;
    }

    private String testPartsIndextoString() {
        StringBuilder carryMsg = new StringBuilder("{");
        int testPartsIndexIndex = 0;
        while (true) {
            int[] iArr = this.testPartsIndex;
            if (testPartsIndexIndex >= iArr.length) {
                return carryMsg.toString();
            }
            carryMsg.append(iArr[testPartsIndexIndex]);
            if (testPartsIndexIndex < this.testPartsIndex.length - 1) {
                carryMsg.append(',');
            } else {
                carryMsg.append('}');
            }
            testPartsIndexIndex++;
        }
    }

    @Test
    public void testValidateUrl() {
        Assert.assertTrue(true);
    }

    @Test
    public void testValidator290() {
        UrlValidator validator = new UrlValidator();
        Assert.assertTrue(validator.isValid("http://xn--h1acbxfam.idn.icann.org/"));
        Assert.assertTrue(validator.isValid("http://test.xn--lgbbat1ad8j"));
        Assert.assertTrue(validator.isValid("http://test.xn--fiqs8s"));
        Assert.assertTrue(validator.isValid("http://test.xn--fiqz9s"));
        Assert.assertTrue(validator.isValid("http://test.xn--wgbh1c"));
        Assert.assertTrue(validator.isValid("http://test.xn--j6w193g"));
        Assert.assertTrue(validator.isValid("http://test.xn--h2brj9c"));
        Assert.assertTrue(validator.isValid("http://test.xn--mgbbh1a71e"));
        Assert.assertTrue(validator.isValid("http://test.xn--fpcrj9c3d"));
        Assert.assertTrue(validator.isValid("http://test.xn--gecrj9c"));
        Assert.assertTrue(validator.isValid("http://test.xn--s9brj9c"));
        Assert.assertTrue(validator.isValid("http://test.xn--xkc2dl3a5ee0h"));
        Assert.assertTrue(validator.isValid("http://test.xn--45brj9c"));
        Assert.assertTrue(validator.isValid("http://test.xn--mgba3a4f16a"));
        Assert.assertTrue(validator.isValid("http://test.xn--mgbayh7gpa"));
        Assert.assertTrue(validator.isValid("http://test.xn--mgbc0a9azcg"));
        Assert.assertTrue(validator.isValid("http://test.xn--ygbi2ammx"));
        Assert.assertTrue(validator.isValid("http://test.xn--wgbl6a"));
        Assert.assertTrue(validator.isValid("http://test.xn--p1ai"));
        Assert.assertTrue(validator.isValid("http://test.xn--mgberp4a5d4ar"));
        Assert.assertTrue(validator.isValid("http://test.xn--90a3ac"));
        Assert.assertTrue(validator.isValid("http://test.xn--yfro4i67o"));
        Assert.assertTrue(validator.isValid("http://test.xn--clchc0ea0b2g2a9gcd"));
        Assert.assertTrue(validator.isValid("http://test.xn--3e0b707e"));
        Assert.assertTrue(validator.isValid("http://test.xn--fzc2c9e2c"));
        Assert.assertTrue(validator.isValid("http://test.xn--xkc2al3hye2a"));
        Assert.assertTrue(validator.isValid("http://test.xn--ogbpf8fl"));
        Assert.assertTrue(validator.isValid("http://test.xn--kprw13d"));
        Assert.assertTrue(validator.isValid("http://test.xn--kpry57d"));
        Assert.assertTrue(validator.isValid("http://test.xn--o3cw4h"));
        Assert.assertTrue(validator.isValid("http://test.xn--pgbs0dh"));
        Assert.assertTrue(validator.isValid("http://test.xn--mgbaam7a8h"));
    }

    @Test
    public void testValidator361() {
        Assert.assertTrue(new UrlValidator().isValid("http://hello.tokyo/"));
    }

    @Test
    public void testValidator363() {
        UrlValidator urlValidator = new UrlValidator();
        Assert.assertTrue(urlValidator.isValid("http://www.example.org/a/b/hello..world"));
        Assert.assertTrue(urlValidator.isValid("http://www.example.org/a/hello..world"));
        Assert.assertTrue(urlValidator.isValid("http://www.example.org/hello.world/"));
        Assert.assertTrue(urlValidator.isValid("http://www.example.org/hello..world/"));
        Assert.assertTrue(urlValidator.isValid("http://www.example.org/hello.world"));
        Assert.assertTrue(urlValidator.isValid("http://www.example.org/hello..world"));
        Assert.assertTrue(urlValidator.isValid("http://www.example.org/..world"));
        Assert.assertTrue(urlValidator.isValid("http://www.example.org/.../world"));
        Assert.assertFalse(urlValidator.isValid("http://www.example.org/../world"));
        Assert.assertFalse(urlValidator.isValid("http://www.example.org/.."));
        Assert.assertFalse(urlValidator.isValid("http://www.example.org/../"));
        Assert.assertFalse(urlValidator.isValid("http://www.example.org/./.."));
        Assert.assertFalse(urlValidator.isValid("http://www.example.org/././.."));
        Assert.assertTrue(urlValidator.isValid("http://www.example.org/..."));
        Assert.assertTrue(urlValidator.isValid("http://www.example.org/.../"));
        Assert.assertTrue(urlValidator.isValid("http://www.example.org/.../.."));
    }

    @Test
    public void testValidator375() {
        UrlValidator validator = new UrlValidator();
        Assert.assertTrue("IPv6 address URL should validate: " + "http://[FEDC:BA98:7654:3210:FEDC:BA98:7654:3210]:80/index.html", validator.isValid("http://[FEDC:BA98:7654:3210:FEDC:BA98:7654:3210]:80/index.html"));
        Assert.assertTrue("IPv6 address URL should validate: " + "http://[::1]:80/index.html", validator.isValid("http://[::1]:80/index.html"));
        Assert.assertFalse("IPv6 address without [] should not validate: " + "http://FEDC:BA98:7654:3210:FEDC:BA98:7654:3210:80/index.html", validator.isValid("http://FEDC:BA98:7654:3210:FEDC:BA98:7654:3210:80/index.html"));
    }

    @Test
    public void testValidator353() {
        UrlValidator validator = new UrlValidator();
        Assert.assertTrue(validator.isValid("http://www.apache.org:80/path"));
        Assert.assertTrue(validator.isValid("http://user:pass@www.apache.org:80/path"));
        Assert.assertTrue(validator.isValid("http://user:@www.apache.org:80/path"));
        Assert.assertTrue(validator.isValid("http://user@www.apache.org:80/path"));
        Assert.assertTrue(validator.isValid("http://us%00er:-._~!$&'()*+,;=@www.apache.org:80/path"));
        Assert.assertFalse(validator.isValid("http://:pass@www.apache.org:80/path"));
        Assert.assertFalse(validator.isValid("http://:@www.apache.org:80/path"));
        Assert.assertFalse(validator.isValid("http://user:pa:ss@www.apache.org/path"));
        Assert.assertFalse(validator.isValid("http://user:pa@ss@www.apache.org/path"));
    }

    @Test
    public void testValidator382() {
        Assert.assertTrue(new UrlValidator().isValid("ftp://username:password@example.com:8042/over/there/index.dtb?type=animal&name=narwhal#nose"));
    }

    @Test
    public void testValidator380() {
        UrlValidator validator = new UrlValidator();
        Assert.assertTrue(validator.isValid("http://www.apache.org:80/path"));
        Assert.assertTrue(validator.isValid("http://www.apache.org:8/path"));
        Assert.assertTrue(validator.isValid("http://www.apache.org:/path"));
    }

    @Test
    public void testValidator420() {
        UrlValidator validator = new UrlValidator();
        Assert.assertFalse(validator.isValid("http://example.com/serach?address=Main Avenue"));
        Assert.assertTrue(validator.isValid("http://example.com/serach?address=Main%20Avenue"));
        Assert.assertTrue(validator.isValid("http://example.com/serach?address=Main+Avenue"));
    }

    @Test
    public void testValidator467() {
        UrlValidator validator = new UrlValidator(2);
        Assert.assertTrue(validator.isValid("https://example.com/some_path/path/"));
        Assert.assertTrue(validator.isValid("https://example.com//somepath/path/"));
        Assert.assertTrue(validator.isValid("https://example.com//some_path/path/"));
        Assert.assertTrue(validator.isValid("http://example.com//_test"));
    }

    @Test
    public void testValidator283() {
        UrlValidator validator = new UrlValidator();
        Assert.assertFalse(validator.isValid("http://finance.yahoo.com/news/Owners-54B-NY-housing-apf-2493139299.html?x=0&ap=%fr"));
        Assert.assertTrue(validator.isValid("http://finance.yahoo.com/news/Owners-54B-NY-housing-apf-2493139299.html?x=0&ap=%22"));
    }

    @Test
    public void testFragments() {
        String[] schemes2 = {"http", "https"};
        Assert.assertFalse(new UrlValidator(schemes2, 4).isValid("http://apache.org/a/b/c#frag"));
        Assert.assertTrue(new UrlValidator(schemes2).isValid("http://apache.org/a/b/c#frag"));
    }

    public static void main(String[] args) {
        UrlValidator uv = new UrlValidator();
        for (String arg : args) {
            try {
                URI uri = new URI(arg).normalize();
                System.out.println(uri.toString());
                System.out.printf("URI scheme: %s%n", uri.getScheme());
                System.out.printf("URI scheme specific part: %s%n", uri.getSchemeSpecificPart());
                System.out.printf("URI raw scheme specific part: %s%n", uri.getRawSchemeSpecificPart());
                System.out.printf("URI auth: %s%n", uri.getAuthority());
                System.out.printf("URI raw auth: %s%n", uri.getRawAuthority());
                System.out.printf("URI userInfo: %s%n", uri.getUserInfo());
                System.out.printf("URI raw userInfo: %s%n", uri.getRawUserInfo());
                System.out.printf("URI host: %s%n", uri.getHost());
                System.out.printf("URI port: %s%n", Integer.valueOf(uri.getPort()));
                System.out.printf("URI path: %s%n", uri.getPath());
                System.out.printf("URI raw path: %s%n", uri.getRawPath());
                System.out.printf("URI query: %s%n", uri.getQuery());
                System.out.printf("URI raw query: %s%n", uri.getRawQuery());
                System.out.printf("URI fragment: %s%n", uri.getFragment());
                System.out.printf("URI raw fragment: %s%n", uri.getRawFragment());
            } catch (URISyntaxException e) {
                System.out.println(e.getMessage());
            }
            System.out.printf("isValid: %s%n", Boolean.valueOf(uv.isValid(arg)));
        }
    }
}
