package org.apache.commons.validator.routines.checkdigit;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.ArrayList;
import java.util.List;
import junit.framework.TestCase;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public abstract class AbstractCheckDigitTest extends TestCase {
    private static final String POSSIBLE_CHECK_DIGITS = "0123456789 ABCDEFHIJKLMNOPQRSTUVWXYZ\tabcdefghijklmnopqrstuvwxyz!@£$%^&*()_+";
    protected int checkDigitLth = 1;
    protected String[] invalid = {"12345678A"};
    protected Log log = LogFactory.getLog(getClass());
    protected String missingMessage = "Code is missing";
    protected CheckDigit routine;
    protected String[] valid;
    protected String zeroSum = "0000000000";

    public AbstractCheckDigitTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void tearDown() throws Exception {
        AbstractCheckDigitTest.super.tearDown();
        this.valid = null;
        this.routine = null;
    }

    public void testIsValidTrue() {
        if (this.log.isDebugEnabled()) {
            Log log2 = this.log;
            log2.debug("testIsValidTrue() for " + this.routine.getClass().getName());
        }
        for (int i = 0; i < this.valid.length; i++) {
            if (this.log.isDebugEnabled()) {
                Log log3 = this.log;
                log3.debug("   " + i + " Testing Valid Code=[" + this.valid[i] + "]");
            }
            assertTrue("valid[" + i + "]: " + this.valid[i], this.routine.isValid(this.valid[i]));
        }
    }

    public void testIsValidFalse() {
        if (this.log.isDebugEnabled()) {
            Log log2 = this.log;
            log2.debug("testIsValidFalse() for " + this.routine.getClass().getName());
        }
        for (int i = 0; i < this.invalid.length; i++) {
            if (this.log.isDebugEnabled()) {
                Log log3 = this.log;
                log3.debug("   " + i + " Testing Invalid Code=[" + this.invalid[i] + "]");
            }
            assertFalse("invalid[" + i + "]: " + this.invalid[i], this.routine.isValid(this.invalid[i]));
        }
        String[] invalidCheckDigits = createInvalidCodes(this.valid);
        for (int i2 = 0; i2 < invalidCheckDigits.length; i2++) {
            if (this.log.isDebugEnabled()) {
                Log log4 = this.log;
                log4.debug("   " + i2 + " Testing Invalid Check Digit, Code=[" + invalidCheckDigits[i2] + "]");
            }
            assertFalse("invalid check digit[" + i2 + "]: " + invalidCheckDigits[i2], this.routine.isValid(invalidCheckDigits[i2]));
        }
    }

    public void testCalculateValid() {
        if (this.log.isDebugEnabled()) {
            Log log2 = this.log;
            log2.debug("testCalculateValid() for " + this.routine.getClass().getName());
        }
        int i = 0;
        while (true) {
            String[] strArr = this.valid;
            if (i < strArr.length) {
                String code = removeCheckDigit(strArr[i]);
                String expected = checkDigit(this.valid[i]);
                try {
                    if (this.log.isDebugEnabled()) {
                        Log log3 = this.log;
                        log3.debug("   " + i + " Testing Valid Check Digit, Code=[" + code + "] expected=[" + expected + "]");
                    }
                    assertEquals("valid[" + i + "]: " + this.valid[i], expected, this.routine.calculate(code));
                } catch (Exception e) {
                    fail("valid[" + i + "]=" + this.valid[i] + " threw " + e);
                }
                i++;
            } else {
                return;
            }
        }
    }

    public void testCalculateInvalid() {
        if (this.log.isDebugEnabled()) {
            Log log2 = this.log;
            log2.debug("testCalculateInvalid() for " + this.routine.getClass().getName());
        }
        int i = 0;
        while (true) {
            String[] strArr = this.invalid;
            if (i < strArr.length) {
                try {
                    String code = strArr[i];
                    if (this.log.isDebugEnabled()) {
                        Log log3 = this.log;
                        log3.debug("   " + i + " Testing Invalid Check Digit, Code=[" + code + "]");
                    }
                    String expected = checkDigit(code);
                    String actual = this.routine.calculate(removeCheckDigit(code));
                    if (expected.equals(actual)) {
                        fail("Expected mismatch for " + code + " expected " + expected + " actual " + actual);
                    }
                } catch (CheckDigitException e) {
                    assertTrue("Invalid Character[" + i + "]=" + e.getMessage(), e.getMessage().startsWith("Invalid "));
                }
                i++;
            } else {
                return;
            }
        }
    }

    public void testMissingCode() {
        assertFalse("isValid() Null", this.routine.isValid(null));
        assertFalse("isValid() Zero Length", this.routine.isValid(""));
        assertFalse("isValid() Length 1", this.routine.isValid("9"));
        try {
            this.routine.calculate(null);
            fail("calculate() Null - expected exception");
        } catch (Exception e) {
            assertEquals("calculate() Null", this.missingMessage, e.getMessage());
        }
        try {
            this.routine.calculate("");
            fail("calculate() Zero Length - expected exception");
        } catch (Exception e2) {
            assertEquals("calculate() Zero Length", this.missingMessage, e2.getMessage());
        }
    }

    public void testZeroSum() {
        assertFalse("isValid() Zero Sum", this.routine.isValid(this.zeroSum));
        try {
            this.routine.calculate(this.zeroSum);
            fail("Zero Sum - expected exception");
        } catch (Exception e) {
            assertEquals("isValid() Zero Sum", "Invalid code, sum is zero", e.getMessage());
        }
    }

    public void testSerialization() {
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        try {
            ObjectOutputStream oos = new ObjectOutputStream(baos);
            oos.writeObject(this.routine);
            oos.flush();
            oos.close();
        } catch (Exception e) {
            fail(this.routine.getClass().getName() + " error during serialization: " + e);
        }
        Object result = null;
        try {
            ByteArrayInputStream bais = new ByteArrayInputStream(baos.toByteArray());
            result = new ObjectInputStream(bais).readObject();
            bais.close();
        } catch (Exception e2) {
            fail(this.routine.getClass().getName() + " error during deserialization: " + e2);
        }
        assertNotNull(result);
    }

    /* access modifiers changed from: protected */
    public String[] createInvalidCodes(String[] codes) {
        List<String> list = new ArrayList<>();
        for (String fullCode : codes) {
            String code = removeCheckDigit(fullCode);
            String check = checkDigit(fullCode);
            for (int j = 0; j < POSSIBLE_CHECK_DIGITS.length(); j++) {
                String curr = POSSIBLE_CHECK_DIGITS.substring(j, j + 1);
                if (!curr.equals(check)) {
                    list.add(code + curr);
                }
            }
        }
        return (String[]) list.toArray(new String[list.size()]);
    }

    /* access modifiers changed from: protected */
    public String removeCheckDigit(String code) {
        if (code == null || code.length() <= this.checkDigitLth) {
            return null;
        }
        return code.substring(0, code.length() - this.checkDigitLth);
    }

    /* access modifiers changed from: protected */
    public String checkDigit(String code) {
        if (code == null || code.length() <= this.checkDigitLth) {
            return "";
        }
        return code.substring(code.length() - this.checkDigitLth);
    }
}
